@@ -1,21 +1,17 @@
 from django.utils.translation import ugettext_lazy as _
 
-from rest_framework import serializers
-
 from mayan.apps.common.serializers import ContentTypeSerializer
 from mayan.apps.permissions import Permission
 from mayan.apps.permissions.serializers import RoleSerializer
+from mayan.apps.rest_api import serializers
 from mayan.apps.rest_api.relations import (
     FilteredPrimaryKeyRelatedField, MultiKwargHyperlinkedIdentityField
 )
-from mayan.apps.rest_api.serializer_mixins import CreateOnlyFieldSerializerMixin
 
 from .models import AccessControlList
 
 
-class ACLSerializer(
-    CreateOnlyFieldSerializerMixin, serializers.ModelSerializer
-):
+class ACLSerializer(serializers.ModelSerializer):
     content_type = ContentTypeSerializer(read_only=True)
     permissions_add_url = MultiKwargHyperlinkedIdentityField(
         view_name='rest_api:accesscontrollist-permission-add',
