@@ -20,8 +20,8 @@ class PermissionTestCase(ACLTestMixin, BaseTestCase):
 
         with self.assertRaises(expected_exception=PermissionDenied):
             AccessControlList.objects.check_access(
-                obj=self.test_object,
-                permissions=(self.test_permission,),
+                obj=self._test_object,
+                permissions=(self._test_permission,),
                 user=self._test_case_user,
             )
 
@@ -30,8 +30,8 @@ class PermissionTestCase(ACLTestMixin, BaseTestCase):
 
         self.assertEqual(
             AccessControlList.objects.restrict_queryset(
-                permission=self.test_permission,
-                queryset=self.test_object._meta.model._default_manager.all(),
+                permission=self._test_permission,
+                queryset=self._test_object._meta.model._default_manager.all(),
                 user=self._test_case_user
             ).count(), 0
         )
@@ -40,12 +40,12 @@ class PermissionTestCase(ACLTestMixin, BaseTestCase):
         self._create_acl_test_object()
 
         self.grant_access(
-            obj=self.test_object, permission=self.test_permission
+            obj=self._test_object, permission=self._test_permission
         )
 
         try:
             AccessControlList.objects.check_access(
-                obj=self.test_object, permissions=(self.test_permission,),
+                obj=self._test_object, permissions=(self._test_permission,),
                 user=self._test_case_user,
             )
         except PermissionDenied:
@@ -55,13 +55,13 @@ class PermissionTestCase(ACLTestMixin, BaseTestCase):
         self._create_acl_test_object()
 
         self.grant_access(
-            obj=self.test_object, permission=self.test_permission
+            obj=self._test_object, permission=self._test_permission
         )
 
         self.assertTrue(
-            self.test_object in AccessControlList.objects.restrict_queryset(
-                permission=self.test_permission,
-                queryset=self.test_object._meta.model._default_manager.all(),
+            self._test_object in AccessControlList.objects.restrict_queryset(
+                permission=self._test_permission,
+                queryset=self._test_object._meta.model._default_manager.all(),
                 user=self._test_case_user
             )
         )
@@ -82,34 +82,34 @@ class PermissionTestCase(ACLTestMixin, BaseTestCase):
 
         ModelPermission.register(
             model=self.TestModelParent, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register(
             model=self.TestModelChild, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register_inheritance(
             model=self.TestModelChild, related='parent',
         )
 
-        self.test_object_parent = self.TestModelParent.objects.create()
-        self.test_object_child = self.TestModelChild.objects.create(
-            parent=self.test_object_parent
+        self._test_object_parent = self.TestModelParent.objects.create()
+        self._test_object_child = self.TestModelChild.objects.create(
+            parent=self._test_object_parent
         )
 
     def test_check_access_with_inherited_acl(self):
         self._setup_child_parent_test_objects()
 
         self.grant_access(
-            obj=self.test_object_parent, permission=self.test_permission
+            obj=self._test_object_parent, permission=self._test_permission
         )
 
         try:
             AccessControlList.objects.check_access(
-                obj=self.test_object_child,
-                permissions=(self.test_permission,),
+                obj=self._test_object_child,
+                permissions=(self._test_permission,),
                 user=self._test_case_user
             )
         except PermissionDenied:
@@ -119,16 +119,16 @@ class PermissionTestCase(ACLTestMixin, BaseTestCase):
         self._setup_child_parent_test_objects()
 
         self.grant_access(
-            obj=self.test_object_parent, permission=self.test_permission
+            obj=self._test_object_parent, permission=self._test_permission
         )
         self.grant_access(
-            obj=self.test_object_child, permission=self.test_permission
+            obj=self._test_object_child, permission=self._test_permission
         )
 
         try:
             AccessControlList.objects.check_access(
-                obj=self.test_object_child,
-                permissions=(self.test_permission,),
+                obj=self._test_object_child,
+                permissions=(self._test_permission,),
                 user=self._test_case_user
             )
         except PermissionDenied:
@@ -138,76 +138,76 @@ class PermissionTestCase(ACLTestMixin, BaseTestCase):
         self._setup_child_parent_test_objects()
 
         self.grant_access(
-            obj=self.test_object_parent, permission=self.test_permission
+            obj=self._test_object_parent, permission=self._test_permission
         )
 
         result = AccessControlList.objects.restrict_queryset(
-            permission=self.test_permission,
-            queryset=self.test_object_child._meta.model._default_manager.all(),
+            permission=self._test_permission,
+            queryset=self._test_object_child._meta.model._default_manager.all(),
             user=self._test_case_user
         )
-        self.assertTrue(self.test_object_child in result)
+        self.assertTrue(self._test_object_child in result)
 
     def test_filtering_with_inherited_permissions_and_local_acl(self):
         self._setup_child_parent_test_objects()
 
-        self.grant_permission(permission=self.test_permission)
+        self.grant_permission(permission=self._test_permission)
         self.grant_access(
-            obj=self.test_object_parent, permission=self.test_permission
+            obj=self._test_object_parent, permission=self._test_permission
         )
         self.grant_access(
-            obj=self.test_object_child, permission=self.test_permission
+            obj=self._test_object_child, permission=self._test_permission
         )
 
         result = AccessControlList.objects.restrict_queryset(
-            permission=self.test_permission,
-            queryset=self.test_object_child._meta.model._default_manager.all(),
+            permission=self._test_permission,
+            queryset=self._test_object_child._meta.model._default_manager.all(),
             user=self._test_case_user,
         )
-        self.assertTrue(self.test_object_child in result)
+        self.assertTrue(self._test_object_child in result)
 
     def test_method_get_absolute_url(self):
         self._create_acl_test_object()
         self._create_test_acl()
 
-        self.assertTrue(self.test_acl.get_absolute_url())
+        self.assertTrue(self._test_acl.get_absolute_url())
 
 
 class InheritedPermissionTestCase(ACLTestMixin, BaseTestCase):
     def test_retrieve_inherited_role_permission_not_model_applicable(self):
         self.TestModel = self._create_test_model()
         EventModelRegistry.register(model=self.TestModel)
-        self.test_object = self.TestModel.objects.create()
+        self._test_object = self.TestModel.objects.create()
         self._create_test_acl()
         self._create_test_permission()
 
-        self.test_role.grant(permission=self.test_permission)
+        self._test_role.grant(permission=self._test_permission)
 
         queryset = AccessControlList.objects.get_inherited_permissions(
-            obj=self.test_object, role=self.test_role
+            obj=self._test_object, role=self._test_role
         )
         self.assertTrue(
-            self.test_permission.stored_permission not in queryset
+            self._test_permission.stored_permission not in queryset
         )
 
     def test_retrieve_inherited_role_permission_model_applicable(self):
         self.TestModel = self._create_test_model()
         EventModelRegistry.register(model=self.TestModel)
-        self.test_object = self.TestModel.objects.create()
+        self._test_object = self.TestModel.objects.create()
         self._create_test_acl()
         self._create_test_permission()
 
         ModelPermission.register(
-            model=self.test_object._meta.model, permissions=(
-                self.test_permission,
+            model=self._test_object._meta.model, permissions=(
+                self._test_permission,
             )
         )
-        self.test_role.grant(permission=self.test_permission)
+        self._test_role.grant(permission=self._test_permission)
 
         queryset = AccessControlList.objects.get_inherited_permissions(
-            obj=self.test_object, role=self.test_role
+            obj=self._test_object, role=self._test_role
         )
-        self.assertTrue(self.test_permission.stored_permission in queryset)
+        self.assertTrue(self._test_permission.stored_permission in queryset)
 
     def test_retrieve_inherited_related_parent_child_permission(self):
         self._create_test_permission()
@@ -226,12 +226,12 @@ class InheritedPermissionTestCase(ACLTestMixin, BaseTestCase):
 
         ModelPermission.register(
             model=self.TestModelParent, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register(
             model=self.TestModelChild, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register_inheritance(
@@ -242,13 +242,13 @@ class InheritedPermissionTestCase(ACLTestMixin, BaseTestCase):
         child = self.TestModelChild.objects.create(parent=parent)
 
         AccessControlList.objects.grant(
-            obj=parent, permission=self.test_permission, role=self.test_role
+            obj=parent, permission=self._test_permission, role=self._test_role
         )
         queryset = AccessControlList.objects.get_inherited_permissions(
-            obj=child, role=self.test_role
+            obj=child, role=self._test_role
         )
 
-        self.assertTrue(self.test_permission.stored_permission in queryset)
+        self.assertTrue(self._test_permission.stored_permission in queryset)
 
     def test_retrieve_inherited_related_grandparent_parent_child_permission(
         self
@@ -277,17 +277,17 @@ class InheritedPermissionTestCase(ACLTestMixin, BaseTestCase):
 
         ModelPermission.register(
             model=self.TestModelGrandParent, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register(
             model=self.TestModelParent, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register(
             model=self.TestModelChild, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register_inheritance(
@@ -302,15 +302,15 @@ class InheritedPermissionTestCase(ACLTestMixin, BaseTestCase):
         child = self.TestModelChild.objects.create(parent=parent)
 
         AccessControlList.objects.grant(
-            obj=grandparent, permission=self.test_permission,
-            role=self.test_role
+            obj=grandparent, permission=self._test_permission,
+            role=self._test_role
         )
 
         queryset = AccessControlList.objects.get_inherited_permissions(
-            obj=child, role=self.test_role
+            obj=child, role=self._test_role
         )
 
-        self.assertTrue(self.test_permission.stored_permission in queryset)
+        self.assertTrue(self._test_permission.stored_permission in queryset)
 
     def test_sub_model_with_multiple_inheritance_parent_with_common_super_parent_paths(self):
         self._create_test_permission()
@@ -342,7 +342,7 @@ class InheritedPermissionTestCase(ACLTestMixin, BaseTestCase):
 
         ModelPermission.register(
             model=self.TestModelLevel2, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
 
@@ -365,11 +365,11 @@ class InheritedPermissionTestCase(ACLTestMixin, BaseTestCase):
         level_4 = self.TestModelLevel4.objects.create(level_3=level_3)
 
         self.grant_access(
-            obj=level_2, permission=self.test_permission
+            obj=level_2, permission=self._test_permission
         )
 
         queryset = AccessControlList.objects.restrict_queryset(
-            permission=self.test_permission,
+            permission=self._test_permission,
             queryset=self.TestModelLevel4.objects.all(),
             user=self._test_case_user
         )
@@ -401,12 +401,12 @@ class GenericForeignKeyFieldModelTestCase(ACLTestMixin, BaseTestCase):
 
         ModelPermission.register(
             model=self.TestModelExternal, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register(
             model=self.TestModelChild, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
 
@@ -420,12 +420,12 @@ class GenericForeignKeyFieldModelTestCase(ACLTestMixin, BaseTestCase):
         )
 
         self.grant_access(
-            obj=test_external_object, permission=self.test_permission
+            obj=test_external_object, permission=self._test_permission
         )
 
         queryset = AccessControlList.objects.restrict_queryset(
             queryset=self.TestModelChild.objects.all(),
-            permission=self.test_permission, user=self._test_case_user
+            permission=self._test_permission, user=self._test_case_user
         )
 
         self.assertTrue(test_object in queryset)
@@ -462,12 +462,12 @@ class GenericForeignKeyFieldModelTestCase(ACLTestMixin, BaseTestCase):
 
         ModelPermission.register(
             model=self.TestModelExternal, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register(
             model=self.TestModelChild, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
 
@@ -484,12 +484,12 @@ class GenericForeignKeyFieldModelTestCase(ACLTestMixin, BaseTestCase):
         )
 
         self.grant_access(
-            obj=test_external_object, permission=self.test_permission
+            obj=test_external_object, permission=self._test_permission
         )
 
         queryset = AccessControlList.objects.restrict_queryset(
             queryset=self.TestModelChild.objects.all(),
-            permission=self.test_permission, user=self._test_case_user
+            permission=self._test_permission, user=self._test_case_user
         )
 
         self.assertTrue(test_object in queryset)
@@ -516,12 +516,12 @@ class GenericForeignKeyFieldModelTestCase(ACLTestMixin, BaseTestCase):
 
         ModelPermission.register(
             model=self.TestModelExternal, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register(
             model=self.TestModelChild, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
 
@@ -536,12 +536,12 @@ class GenericForeignKeyFieldModelTestCase(ACLTestMixin, BaseTestCase):
         )
 
         self.grant_access(
-            obj=test_external_object, permission=self.test_permission
+            obj=test_external_object, permission=self._test_permission
         )
 
         queryset = AccessControlList.objects.restrict_queryset(
             queryset=self.TestModelChild.objects.all(),
-            permission=self.test_permission, user=self._test_case_user
+            permission=self._test_permission, user=self._test_case_user
         )
 
         self.assertTrue(test_object in queryset)
@@ -552,11 +552,11 @@ class ProxyModelPermissionTestCase(ACLTestMixin, BaseTestCase):
         self._create_acl_test_object_base()
         self._create_acl_test_object_proxy()
 
-        proxy_object = self.TestModelProxy.objects.get(pk=self.test_object.pk)
+        proxy_object = self.TestModelProxy.objects.get(pk=self._test_object.pk)
 
         self.assertFalse(
             proxy_object in AccessControlList.objects.restrict_queryset(
-                permission=self.test_permission,
+                permission=self._test_permission,
                 queryset=self.TestModelProxy.objects.all(),
                 user=self._test_case_user
             )
@@ -567,14 +567,14 @@ class ProxyModelPermissionTestCase(ACLTestMixin, BaseTestCase):
         self._create_acl_test_object_proxy()
 
         self.grant_access(
-            obj=self.test_object, permission=self.test_permission
+            obj=self._test_object, permission=self._test_permission
         )
 
-        proxy_object = self.TestModelProxy.objects.get(pk=self.test_object.pk)
+        proxy_object = self.TestModelProxy.objects.get(pk=self._test_object.pk)
 
         self.assertTrue(
             proxy_object in AccessControlList.objects.restrict_queryset(
-                permission=self.test_permission,
+                permission=self._test_permission,
                 queryset=self.TestModelProxy.objects.all(),
                 user=self._test_case_user
             )
@@ -603,7 +603,7 @@ class ProxyModelPermissionTestCase(ACLTestMixin, BaseTestCase):
 
         ModelPermission.register(
             model=self.TestModelParent, permissions=(
-                self.test_permission,
+                self._test_permission,
             )
         )
         ModelPermission.register_inheritance(
@@ -614,14 +614,14 @@ class ProxyModelPermissionTestCase(ACLTestMixin, BaseTestCase):
         child = self.TestModelChild.objects.create(parent=parent)
 
         self.grant_access(
-            obj=parent, permission=self.test_permission
+            obj=parent, permission=self._test_permission
         )
 
         proxy_object = self.TestModelProxy.objects.get(pk=child.pk)
 
         self.assertTrue(
             proxy_object in AccessControlList.objects.restrict_queryset(
-                permission=self.test_permission,
+                permission=self._test_permission,
                 queryset=self.TestModelProxy.objects.all(),
                 user=self._test_case_user
             )
