@@ -1,7 +1,7 @@
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.navigation.classes import Link
-from mayan.apps.user_management.links import condition_user_is_not_admin
+from mayan.apps.user_management.link_conditions import condition_user_is_not_superuser
 from mayan.apps.user_management.permissions import permission_user_edit
 
 from .icons import icon_impersonate_start, icon_logout, icon_password_change
@@ -26,7 +26,7 @@ def condition_user_has_usable_password_and_can_change_password(context, resolved
 def condition_user_has_usable_password_and_can_change_password_and_is_not_admin(context, resolved_object):
     return _condition_user_has_usable_password_and_can_change_password(
         user=resolved_object
-    ) and condition_user_is_not_admin(
+    ) and condition_user_is_not_superuser(
         context=context, resolved_object=resolved_object
     )
 
@@ -46,7 +46,7 @@ link_user_impersonate_form_start = Link(
     view='authentication:user_impersonate_form_start'
 )
 link_user_impersonate_start = Link(
-    args='object.id', condition=condition_user_is_not_admin, icon=icon_impersonate_start,
+    args='object.id', condition=condition_user_is_not_superuser, icon=icon_impersonate_start,
     permissions=(permission_users_impersonate,), text=_('Impersonate'),
     view='authentication:user_impersonate_start'
 )
