@@ -1,4 +1,4 @@
-from mayan.apps.documents.tests.literals import TEST_SMALL_DOCUMENT_PATH
+from mayan.apps.documents.tests.literals import TEST_FILE_TEXT_PATH
 
 from ..models import Cabinet
 
@@ -19,28 +19,28 @@ class CabinetAPIViewTestMixin:
 
         response = self.post(viewname='rest_api:cabinet-list', data=data)
 
-        self.test_cabinet = Cabinet.objects.exclude(pk__in=values).first()
+        self._test_cabinet = Cabinet.objects.exclude(pk__in=values).first()
 
         return response
 
     def _request_test_cabinet_delete_api_view(self):
         return self.delete(
             viewname='rest_api:cabinet-detail', kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }
         )
 
     def _request_test_cabinet_edit_api_patch_view(self):
         return self.patch(
             data={'label': TEST_CABINET_LABEL_EDITED}, kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }, viewname='rest_api:cabinet-detail'
         )
 
     def _request_test_cabinet_edit_api_put_view(self):
         return self.put(
             data={'label': TEST_CABINET_LABEL_EDITED}, kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }, viewname='rest_api:cabinet-detail'
         )
 
@@ -52,37 +52,37 @@ class CabinetDocumentAPIViewTestMixin:
     def _request_test_cabinet_document_add_api_view(self):
         return self.post(
             viewname='rest_api:cabinet-document-add', kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }, data={
-                'document': self.test_document.pk
+                'document': self._test_document.pk
             }
         )
 
     def _request_test_cabinet_document_list_api_view(self):
         return self.get(
             viewname='rest_api:cabinet-document-list', kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }
         )
 
     def _request_test_cabinet_document_remove_api_view(self):
         return self.post(
             viewname='rest_api:cabinet-document-remove', kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }, data={
-                'document': self.test_document.pk
+                'document': self._test_document.pk
             }
         )
 
 
 class CabinetDocumentUploadWizardStepTestMixin:
     def _request_upload_interactive_document_create_view(self):
-        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_FILE_TEXT_PATH, mode='rb') as file_object:
             return self.post(
                 viewname='sources:document_upload_interactive', kwargs={
-                    'source_id': self.test_source.pk
+                    'source_id': self._test_source.pk
                 }, data={
-                    'document_type_id': self.test_document_type.pk,
+                    'document_type_id': self._test_document_type.pk,
                     'source-file': file_object,
                     'cabinets': Cabinet.objects.values_list('pk', flat=True)
                 }
@@ -93,30 +93,33 @@ class CabinetDocumentUploadWizardStepTestMixin:
 
 
 class CabinetTestMixin:
+    _test_cabinet_add_test_document = False
     auto_create_test_cabinet = False
-    test_cabinet_add_test_document = False
 
     def setUp(self):
         super().setUp()
         if not hasattr(self, 'test_cabinets'):
-            self.test_cabinets = []
+            self._test_cabinets = []
 
         if self.auto_create_test_cabinet:
             self._create_test_cabinet(
-                add_test_document=self.test_cabinet_add_test_document
+                add_test_document=self._test_cabinet_add_test_document
             )
 
-    def _create_test_cabinet(self, add_test_document=False):
-        self.test_cabinet = Cabinet.objects.create(label=TEST_CABINET_LABEL)
+    def _create_test_cabinet(self, label=None, add_test_document=False):
+        self._test_cabinet = Cabinet.objects.create(
+            label=label or TEST_CABINET_LABEL
+        )
 
         if add_test_document:
-            self.test_cabinet.document_add(document=self.test_document)
+            self._test_cabinet.document_add(document=self._test_document)
 
-        self.test_cabinets.append(self.test_cabinet)
+        self._test_cabinets.append(self._test_cabinet)
 
-    def _create_test_cabinet_child(self):
-        self.test_cabinet_child = Cabinet.objects.create(
-            label=TEST_CABINET_CHILD_LABEL, parent=self.test_cabinet
+    def _create_test_cabinet_child(self, label=None):
+        self._test_cabinet_child = Cabinet.objects.create(
+            label=label or TEST_CABINET_CHILD_LABEL,
+            parent=self._test_cabinet
         )
 
 
@@ -124,7 +127,7 @@ class CabinetViewTestMixin:
     def setUp(self):
         super().setUp()
         if not hasattr(self, 'test_cabinets'):
-            self.test_cabinets = []
+            self._test_cabinets = []
 
     def _request_test_cabinet_create_view(self):
         # Typecast to list to force queryset evaluation
@@ -136,22 +139,22 @@ class CabinetViewTestMixin:
             }
         )
 
-        self.test_cabinet = Cabinet.objects.exclude(pk__in=values).first()
-        self.test_cabinets.append(self.test_cabinet)
+        self._test_cabinet = Cabinet.objects.exclude(pk__in=values).first()
+        self._test_cabinets.append(self._test_cabinet)
 
         return response
 
     def _request_test_cabinet_delete_view(self):
         return self.post(
             viewname='cabinets:cabinet_delete', kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }
         )
 
     def _request_test_cabinet_edit_view(self):
         return self.post(
             viewname='cabinets:cabinet_edit', kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }, data={
                 'label': TEST_CABINET_LABEL_EDITED
             }
@@ -163,26 +166,26 @@ class CabinetViewTestMixin:
 
         response = self.post(
             viewname='cabinets:cabinet_child_add', kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }, data={'label': TEST_CABINET_CHILD_LABEL}
         )
 
-        self.test_cabinet = Cabinet.objects.exclude(pk__in=values).first()
-        self.test_cabinets.append(self.test_cabinet)
+        self._test_cabinet = Cabinet.objects.exclude(pk__in=values).first()
+        self._test_cabinets.append(self._test_cabinet)
 
         return response
 
     def _request_test_cabinet_child_delete_view(self):
         return self.post(
             viewname='cabinets:cabinet_delete', kwargs={
-                'cabinet_id': self.test_cabinet_child.pk
+                'cabinet_id': self._test_cabinet_child.pk
             }
         )
 
     def _request_test_cabinet_document_list_view(self):
         return self.get(
             viewname='cabinets:cabinet_view', kwargs={
-                'cabinet_id': self.test_cabinet.pk
+                'cabinet_id': self._test_cabinet.pk
             }
         )
 
@@ -192,26 +195,26 @@ class CabinetViewTestMixin:
     def _request_test_document_cabinet_add_view(self):
         return self.post(
             viewname='cabinets:document_cabinet_add', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }, data={
-                'cabinets': self.test_cabinet.pk
+                'cabinets': self._test_cabinet.pk
             }
         )
 
     def _request_test_document_cabinet_multiple_remove_view(self):
         return self.post(
             viewname='cabinets:document_cabinet_remove', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }, data={
-                'cabinets': (self.test_cabinet.pk,),
+                'cabinets': (self._test_cabinet.pk,),
             }
         )
 
     def _request_test_document_multiple_cabinet_multiple_add_view_cabinet(self):
         return self.post(
             viewname='cabinets:document_multiple_cabinet_add', data={
-                'id_list': (self.test_document.pk,),
-                'cabinets': self.test_cabinet.pk
+                'id_list': (self._test_document.pk,),
+                'cabinets': self._test_cabinet.pk
             }
         )
 
@@ -220,7 +223,7 @@ class DocumentCabinetAPIViewTestMixin:
     def _request_test_document_cabinet_list_api_view(self):
         return self.get(
             viewname='rest_api:document-cabinet-list', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }
         )
 
@@ -229,6 +232,6 @@ class DocumentCabinetViewTestMixin:
     def _request_test_document_cabinet_list_view(self):
         return self.get(
             viewname='cabinets:document_cabinet_list', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }
         )
