@@ -6,7 +6,7 @@ from mayan.apps.documents.events import (
 from mayan.apps.documents.models import Document
 from mayan.apps.documents.permissions import permission_document_create
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
-from mayan.apps.sources.tests.mixins.web_form_source_mixins import WebFormSourceTestMixin
+from mayan.apps.sources.tests.mixins.web_form_source_mixins import WebFormSourceBackendTestMixin
 from mayan.apps.sources.wizards import DocumentCreateWizardStep
 
 from ..events import event_cabinet_document_added
@@ -19,7 +19,7 @@ from .mixins import (
 
 class CabinetDocumentUploadTestCase(
     CabinetTestMixin, CabinetDocumentUploadWizardStepTestMixin,
-    WebFormSourceTestMixin, GenericDocumentViewTestCase
+    WebFormSourceBackendTestMixin, GenericDocumentViewTestCase
 ):
     auto_upload_test_document = False
 
@@ -32,11 +32,11 @@ class CabinetDocumentUploadTestCase(
         self._create_test_cabinet()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_create
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         self._clear_events()
@@ -45,10 +45,10 @@ class CabinetDocumentUploadTestCase(
 
         self.assertEqual(response.status_code, 302)
         self.assertTrue(
-            self.test_cabinets[0] in Document.objects.first().cabinets.all()
+            self._test_cabinets[0] in Document.objects.first().cabinets.all()
         )
         self.assertTrue(
-            self.test_cabinets[1] in Document.objects.first().cabinets.all()
+            self._test_cabinets[1] in Document.objects.first().cabinets.all()
         )
 
         events = self._get_test_events()
@@ -59,7 +59,7 @@ class CabinetDocumentUploadTestCase(
         test_document_version = test_document.version_active
         test_document_version_page = test_document_version.pages.first()
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, test_document)
         self.assertEqual(events[0].verb, event_document_created.id)
@@ -86,12 +86,12 @@ class CabinetDocumentUploadTestCase(
             events[4].verb, event_document_version_page_created.id
         )
 
-        self.assertEqual(events[5].action_object, self.test_cabinets[0])
+        self.assertEqual(events[5].action_object, self._test_cabinets[0])
         self.assertEqual(events[5].actor, test_document)
         self.assertEqual(events[5].target, test_document)
         self.assertEqual(events[5].verb, event_cabinet_document_added.id)
 
-        self.assertEqual(events[6].action_object, self.test_cabinets[1])
+        self.assertEqual(events[6].action_object, self._test_cabinets[1])
         self.assertEqual(events[6].actor, test_document)
         self.assertEqual(events[6].target, test_document)
         self.assertEqual(events[6].verb, event_cabinet_document_added.id)
@@ -104,7 +104,7 @@ class CabinetDocumentUploadTestCase(
 
         self._create_test_cabinet()
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_create
         )
 
