@@ -26,22 +26,22 @@ class CabinetWorkflowActionTestCase(CabinetTestMixin, ActionTestCase):
 
         self._clear_events()
 
-        action.execute(context={'document': self.test_document})
+        action.execute(context={'document': self._test_document})
 
         self.assertTrue(
-            self.test_document in self.test_cabinet.documents.all()
+            self._test_document in self._test_cabinet.documents.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_cabinet)
-        self.assertEqual(events[0].actor, self.test_document)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_cabinet)
+        self.assertEqual(events[0].actor, self._test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_cabinet_document_added.id)
 
     def test_cabinet_document_remove_action(self):
-        self.test_cabinet.document_add(document=self.test_document)
+        self._test_cabinet.document_add(document=self._test_document)
 
         action = CabinetRemoveAction(
             form_data={'cabinets': Cabinet.objects.all()}
@@ -49,18 +49,18 @@ class CabinetWorkflowActionTestCase(CabinetTestMixin, ActionTestCase):
 
         self._clear_events()
 
-        action.execute(context={'document': self.test_document})
+        action.execute(context={'document': self._test_document})
 
         self.assertFalse(
-            self.test_document in self.test_cabinet.documents.all()
+            self._test_document in self._test_cabinet.documents.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_cabinet)
-        self.assertEqual(events[0].actor, self.test_document)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_cabinet)
+        self.assertEqual(events[0].actor, self._test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_cabinet_document_removed.id)
 
 
