@@ -1,5 +1,5 @@
 from mayan.apps.documents.tests.base import GenericDocumentTestCase
-from mayan.apps.documents.tests.literals import TEST_SMALL_DOCUMENT_PATH
+from mayan.apps.documents.tests.literals import TEST_FILE_SMALL_PATH
 
 from ..exceptions import (
     DocumentAlreadyCheckedOut, DocumentNotCheckedOut,
@@ -24,19 +24,19 @@ class DocumentCheckoutTestCase(
 
         self.assertTrue(
             DocumentCheckout.objects.is_checked_out(
-                document=self.test_document
+                document=self._test_document
             )
         )
 
     def test_document_check_in(self):
         self._check_out_test_document()
 
-        self.test_document.check_in()
+        self._test_document.check_in()
 
-        self.assertFalse(self.test_document.is_checked_out())
+        self.assertFalse(self._test_document.is_checked_out())
         self.assertFalse(
             DocumentCheckout.objects.is_checked_out(
-                document=self.test_document
+                document=self._test_document
             )
         )
 
@@ -46,7 +46,7 @@ class DocumentCheckoutTestCase(
 
         with self.assertRaises(expected_exception=DocumentAlreadyCheckedOut):
             DocumentCheckout.objects.check_out_document(
-                document=self.test_document,
+                document=self._test_document,
                 expiration_datetime=self._check_out_expiration_datetime,
                 user=self._test_case_superuser,
                 block_new_file=True
@@ -54,7 +54,7 @@ class DocumentCheckoutTestCase(
 
     def test_document_check_in_without_check_out(self):
         with self.assertRaises(expected_exception=DocumentNotCheckedOut):
-            self.test_document.check_in()
+            self._test_document.check_in()
 
     def test_document_auto_check_in(self):
         self._check_out_test_document()
@@ -64,12 +64,12 @@ class DocumentCheckoutTestCase(
 
         DocumentCheckout.objects.check_in_expired_check_outs()
 
-        self.assertFalse(self.test_document.is_checked_out())
+        self.assertFalse(self._test_document.is_checked_out())
 
     def test_method_get_absolute_url(self):
         self._check_out_test_document()
 
-        self.assertTrue(self.test_check_out.get_absolute_url())
+        self.assertTrue(self._test_check_out.get_absolute_url())
 
     def test_blocking_new_files(self):
         # Silence unrelated logging.
@@ -77,8 +77,8 @@ class DocumentCheckoutTestCase(
         self._check_out_test_document()
 
         with self.assertRaises(expected_exception=NewDocumentFileNotAllowed):
-            with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
-                self.test_document.file_new(file_object=file_object)
+            with open(file=TEST_FILE_SMALL_PATH, mode='rb') as file_object:
+                self._test_document.file_new(file_object=file_object)
 
     def test_file_creation_blocking(self):
         # Silence unrelated logging.
@@ -89,5 +89,5 @@ class DocumentCheckoutTestCase(
         self._check_out_test_document()
 
         with self.assertRaises(expected_exception=NewDocumentFileNotAllowed):
-            with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
-                self.test_document.file_new(file_object=file_object)
+            with open(file=TEST_FILE_SMALL_PATH, mode='rb') as file_object:
+                self._test_document.file_new(file_object=file_object)
