@@ -2,8 +2,7 @@ from django.utils.encoding import force_text
 
 from mayan.apps.documents.models import DocumentFile
 from mayan.apps.documents.permissions import (
-    permission_document_file_new, permission_document_file_view,
-    permission_document_view
+    permission_document_file_new, permission_document_file_view
 )
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 
@@ -39,7 +38,7 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_in_get_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertTrue(self.test_document.is_checked_out())
+        self.assertTrue(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -48,17 +47,17 @@ class DocumentCheckoutViewTestCase(
         self._check_out_test_document()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_in
+            obj=self._test_document, permission=permission_document_check_in
         )
 
         self._clear_events()
 
         response = self._request_test_document_check_in_get_view()
         self.assertContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
 
-        self.assertTrue(self.test_document.is_checked_out())
+        self.assertTrue(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -67,17 +66,17 @@ class DocumentCheckoutViewTestCase(
         self._check_out_test_document()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_in
+            obj=self._test_document, permission=permission_document_check_in
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_check_in_get_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertTrue(self.test_document.is_checked_out())
+        self.assertTrue(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -90,7 +89,7 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_in_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertTrue(self.test_document.is_checked_out())
+        self.assertTrue(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -99,7 +98,7 @@ class DocumentCheckoutViewTestCase(
         self._check_out_test_document()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_in
+            obj=self._test_document, permission=permission_document_check_in
         )
 
         self._clear_events()
@@ -107,31 +106,31 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_in_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.assertFalse(self.test_document.is_checked_out())
+        self.assertFalse(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_checked_in.id)
 
     def test_trashed_document_check_in_post_view_with_access(self):
         self._check_out_test_document()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_in
+            obj=self._test_document, permission=permission_document_check_in
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_check_in_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertTrue(self.test_document.is_checked_out())
+        self.assertTrue(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -140,16 +139,16 @@ class DocumentCheckoutViewTestCase(
         # Upload second document.
         self._upload_test_document()
 
-        self._check_out_test_document(document=self.test_documents[0])
-        self._check_out_test_document(document=self.test_documents[1])
+        self._check_out_test_document(document=self._test_documents[0])
+        self._check_out_test_document(document=self._test_documents[1])
 
         self._clear_events()
 
         response = self._request_test_document_multiple_check_in_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertTrue(self.test_documents[0].is_checked_out())
-        self.assertTrue(self.test_documents[1].is_checked_out())
+        self.assertTrue(self._test_documents[0].is_checked_out())
+        self.assertTrue(self._test_documents[1].is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -158,11 +157,11 @@ class DocumentCheckoutViewTestCase(
         # Upload second document.
         self._upload_test_document()
 
-        self._check_out_test_document(document=self.test_documents[0])
-        self._check_out_test_document(document=self.test_documents[1])
+        self._check_out_test_document(document=self._test_documents[0])
+        self._check_out_test_document(document=self._test_documents[1])
 
         self.grant_access(
-            obj=self.test_documents[0], permission=permission_document_check_in
+            obj=self._test_documents[0], permission=permission_document_check_in
         )
 
         self._clear_events()
@@ -170,29 +169,29 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_multiple_check_in_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.assertFalse(self.test_documents[0].is_checked_out())
-        self.assertTrue(self.test_documents[1].is_checked_out())
+        self.assertFalse(self._test_documents[0].is_checked_out())
+        self.assertTrue(self._test_documents[1].is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].target, self.test_documents[0])
+        self.assertEqual(events[0].target, self._test_documents[0])
         self.assertEqual(events[0].verb, event_document_checked_in.id)
 
     def test_document_multiple_check_in_post_view_with_access(self):
         # Upload second document.
         self._upload_test_document()
 
-        self._check_out_test_document(document=self.test_documents[0])
-        self._check_out_test_document(document=self.test_documents[1])
+        self._check_out_test_document(document=self._test_documents[0])
+        self._check_out_test_document(document=self._test_documents[1])
 
         self.grant_access(
-            obj=self.test_documents[0], permission=permission_document_check_in
+            obj=self._test_documents[0], permission=permission_document_check_in
         )
         self.grant_access(
-            obj=self.test_documents[1], permission=permission_document_check_in
+            obj=self._test_documents[1], permission=permission_document_check_in
         )
 
         self._clear_events()
@@ -200,20 +199,20 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_multiple_check_in_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.assertFalse(self.test_documents[0].is_checked_out())
-        self.assertFalse(self.test_documents[1].is_checked_out())
+        self.assertFalse(self._test_documents[0].is_checked_out())
+        self.assertFalse(self._test_documents[1].is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].target, self.test_documents[0])
+        self.assertEqual(events[0].target, self._test_documents[0])
         self.assertEqual(events[0].verb, event_document_checked_in.id)
 
         self.assertEqual(events[1].actor, self._test_case_user)
         self.assertEqual(events[1].action_object, None)
-        self.assertEqual(events[1].target, self.test_documents[1])
+        self.assertEqual(events[1].target, self._test_documents[1])
         self.assertEqual(events[1].verb, event_document_checked_in.id)
 
     def test_document_check_out_get_view_no_permission(self):
@@ -222,14 +221,14 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_out_get_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertFalse(self.test_document.is_checked_out())
+        self.assertFalse(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_check_out_get_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_out
+            obj=self._test_document, permission=permission_document_check_out
         )
 
         self._clear_events()
@@ -237,24 +236,24 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_out_get_view()
         self.assertEqual(response.status_code, 200)
 
-        self.assertFalse(self.test_document.is_checked_out())
+        self.assertFalse(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_check_out_get_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_out
+            obj=self._test_document, permission=permission_document_check_out
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_check_out_get_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertFalse(self.test_document.is_checked_out())
+        self.assertFalse(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -265,17 +264,17 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_out_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertFalse(self.test_document.is_checked_out())
+        self.assertFalse(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_check_out_post_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_out
+            obj=self._test_document, permission=permission_document_check_out
         )
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_out_detail_view
         )
 
@@ -284,33 +283,33 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_out_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.assertTrue(self.test_document.is_checked_out())
+        self.assertTrue(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_checked_out.id)
 
     def test_trashed_document_check_out_post_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_out
+            obj=self._test_document, permission=permission_document_check_out
         )
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_out_detail_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_check_out_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertFalse(self.test_document.is_checked_out())
+        self.assertFalse(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -320,11 +319,11 @@ class DocumentCheckoutViewTestCase(
         self._upload_test_document()
 
         self.grant_access(
-            obj=self.test_documents[0],
+            obj=self._test_documents[0],
             permission=permission_document_check_out_detail_view
         )
         self.grant_access(
-            obj=self.test_documents[1],
+            obj=self._test_documents[1],
             permission=permission_document_check_out_detail_view
         )
 
@@ -333,8 +332,8 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_multiple_check_out_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertFalse(self.test_documents[0].is_checked_out())
-        self.assertFalse(self.test_documents[1].is_checked_out())
+        self.assertFalse(self._test_documents[0].is_checked_out())
+        self.assertFalse(self._test_documents[1].is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -344,14 +343,14 @@ class DocumentCheckoutViewTestCase(
         self._upload_test_document()
 
         self.grant_access(
-            obj=self.test_documents[0], permission=permission_document_check_out
+            obj=self._test_documents[0], permission=permission_document_check_out
         )
         self.grant_access(
-            obj=self.test_documents[0],
+            obj=self._test_documents[0],
             permission=permission_document_check_out_detail_view
         )
         self.grant_access(
-            obj=self.test_documents[1],
+            obj=self._test_documents[1],
             permission=permission_document_check_out_detail_view
         )
 
@@ -360,15 +359,15 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_multiple_check_out_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.assertTrue(self.test_documents[0].is_checked_out())
-        self.assertFalse(self.test_documents[1].is_checked_out())
+        self.assertTrue(self._test_documents[0].is_checked_out())
+        self.assertFalse(self._test_documents[1].is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].target, self.test_documents[0])
+        self.assertEqual(events[0].target, self._test_documents[0])
         self.assertEqual(events[0].verb, event_document_checked_out.id)
 
     def test_document_multiple_check_out_post_view_with_access(self):
@@ -376,17 +375,17 @@ class DocumentCheckoutViewTestCase(
         self._upload_test_document()
 
         self.grant_access(
-            obj=self.test_documents[0], permission=permission_document_check_out
+            obj=self._test_documents[0], permission=permission_document_check_out
         )
         self.grant_access(
-            obj=self.test_documents[1], permission=permission_document_check_out
+            obj=self._test_documents[1], permission=permission_document_check_out
         )
         self.grant_access(
-            obj=self.test_documents[0],
+            obj=self._test_documents[0],
             permission=permission_document_check_out_detail_view
         )
         self.grant_access(
-            obj=self.test_documents[1],
+            obj=self._test_documents[1],
             permission=permission_document_check_out_detail_view
         )
 
@@ -395,20 +394,20 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_multiple_check_out_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.assertTrue(self.test_documents[0].is_checked_out())
-        self.assertTrue(self.test_documents[1].is_checked_out())
+        self.assertTrue(self._test_documents[0].is_checked_out())
+        self.assertTrue(self._test_documents[1].is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].target, self.test_documents[0])
+        self.assertEqual(events[0].target, self._test_documents[0])
         self.assertEqual(events[0].verb, event_document_checked_out.id)
 
         self.assertEqual(events[1].actor, self._test_case_user)
         self.assertEqual(events[1].action_object, None)
-        self.assertEqual(events[1].target, self.test_documents[1])
+        self.assertEqual(events[1].target, self._test_documents[1])
         self.assertEqual(events[1].verb, event_document_checked_out.id)
 
     def test_document_check_out_detail_view_no_permission(self):
@@ -429,7 +428,7 @@ class DocumentCheckoutViewTestCase(
         self._check_out_test_document()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_out_detail_view
         )
 
@@ -447,11 +446,11 @@ class DocumentCheckoutViewTestCase(
         self._check_out_test_document()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_out_detail_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -464,16 +463,11 @@ class DocumentCheckoutViewTestCase(
     def test_document_check_out_list_view_no_permission(self):
         self._check_out_test_document()
 
-        self.grant_access(
-            obj=self.test_document,
-            permission=permission_document_view
-        )
-
         self._clear_events()
 
         response = self._request_test_document_check_out_list_view()
         self.assertNotContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
 
         events = self._get_test_events()
@@ -483,19 +477,15 @@ class DocumentCheckoutViewTestCase(
         self._check_out_test_document()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_out_detail_view
         )
-        self.grant_access(
-            obj=self.test_document,
-            permission=permission_document_view
-        )
 
         self._clear_events()
 
         response = self._request_test_document_check_out_list_view()
         self.assertContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
 
         events = self._get_test_events()
@@ -505,21 +495,17 @@ class DocumentCheckoutViewTestCase(
         self._check_out_test_document()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_out_detail_view
         )
-        self.grant_access(
-            obj=self.test_document,
-            permission=permission_document_view
-        )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_check_out_list_view()
         self.assertNotContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
 
         events = self._get_test_events()
@@ -531,10 +517,10 @@ class DocumentCheckoutViewTestCase(
         # permissions throws out an error.
         self._create_test_user()
         # Check out document as test_user.
-        self._check_out_test_document(user=self.test_user)
+        self._check_out_test_document(user=self._test_user)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_in
+            obj=self._test_document, permission=permission_document_check_in
         )
 
         self._clear_events()
@@ -542,7 +528,7 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_in_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.assertTrue(self.test_document.is_checked_out())
+        self.assertTrue(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -550,10 +536,10 @@ class DocumentCheckoutViewTestCase(
     def test_document_check_in_forcefull_view_with_access(self):
         self._create_test_user()
         # Check out document as test_user.
-        self._check_out_test_document(user=self.test_user)
+        self._check_out_test_document(user=self._test_user)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_in_override
         )
 
@@ -563,14 +549,14 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_in_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.assertFalse(self.test_document.is_checked_out())
+        self.assertFalse(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(
             events[0].verb, event_document_forcefully_checked_in.id
         )
@@ -578,14 +564,14 @@ class DocumentCheckoutViewTestCase(
     def test_trashed_document_check_in_forcefull_view_with_access(self):
         self._create_test_user()
         # Check out document as test_user
-        self._check_out_test_document(user=self.test_user)
+        self._check_out_test_document(user=self._test_user)
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_in_override
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -593,14 +579,14 @@ class DocumentCheckoutViewTestCase(
         response = self._request_test_document_check_in_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertTrue(self.test_document.is_checked_out())
+        self.assertTrue(self._test_document.is_checked_out())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_check_in_of_non_checked_out_document_view(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_in
+            obj=self._test_document, permission=permission_document_check_in
         )
 
         self._clear_events()
@@ -616,10 +602,10 @@ class DocumentCheckoutViewTestCase(
 
     def test_check_in_of_non_checked_out_trashed_document_view(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_in
+            obj=self._test_document, permission=permission_document_check_in
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -631,12 +617,12 @@ class DocumentCheckoutViewTestCase(
 
     def test_check_out_of_checked_out_document_view(self):
         self._create_test_user()
-        self._check_out_test_document(user=self.test_user)
+        self._check_out_test_document(user=self._test_user)
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_out
+            obj=self._test_document, permission=permission_document_check_out
         )
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_out_detail_view
         )
 
@@ -653,16 +639,16 @@ class DocumentCheckoutViewTestCase(
 
     def test_check_out_of_checked_out_trashed_document(self):
         self._create_test_user()
-        self._check_out_test_document(user=self.test_user)
+        self._check_out_test_document(user=self._test_user)
         self.grant_access(
-            obj=self.test_document, permission=permission_document_check_out
+            obj=self._test_document, permission=permission_document_check_out
         )
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_check_out_detail_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -687,15 +673,15 @@ class DocumentCheckoutOptionsViewTestCase(
         self._silence_logger(name='mayan.apps.sources.links')
 
         self._create_test_user()
-        self._check_out_test_document(user=self.test_user)
+        self._check_out_test_document(user=self._test_user)
         file_count = DocumentFile.objects.count()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_view
         )
 
@@ -703,7 +689,7 @@ class DocumentCheckoutOptionsViewTestCase(
 
         response = self.post(
             viewname='sources:document_file_upload', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }, follow=True
         )
         self.assertContains(
@@ -721,21 +707,21 @@ class DocumentCheckoutOptionsViewTestCase(
         file_count = DocumentFile.objects.count()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self.post(
             viewname='sources:document_file_upload', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }, follow=True
         )
         self.assertEqual(response.status_code, 404)
