@@ -6,19 +6,12 @@ from django.utils.encoding import force_text
 import mayan
 
 from ..classes import MissingItem
-from ..literals import MESSAGE_SQLITE_WARNING
-from ..utils import check_for_sqlite, return_attrib
+from ..utils import return_attrib
 
 logger = logging.getLogger(name=__name__)
 register = Library()
 
 
-@register.simple_tag
-def common_check_sqlite():
-    if check_for_sqlite():
-        return MESSAGE_SQLITE_WARNING
-
-
 @register.simple_tag
 def common_get_missing_items():
     return MissingItem.get_missing()
@@ -37,7 +30,7 @@ def common_get_object_verbose_name(obj):
 
 @register.filter
 def common_get_type(value):
-    return force_text(type(value))
+    return force_text(s=type(value))
 
 
 @register.filter
