@@ -14,6 +14,12 @@ TEST_LAYER_LABEL = 'Test layer'
 TEST_LAYER_ORDER = 1000
 TEST_LAYER_NAME = 'test_layer'
 
+TEST_TRANSFORMATION_DOCUMENT_FILENAME = 'red_upper_left_corner.png'
+TEST_TRANSFORMATION_DOCUMENT_PATH = os.path.join(
+    settings.BASE_DIR, 'apps', 'converter', 'tests', 'contrib',
+    'sample_documents', TEST_TRANSFORMATION_DOCUMENT_FILENAME
+)
+
 TEST_TRANSFORMATION_ARGUMENT = 'degrees: 180'
 TEST_TRANSFORMATION_ARGUMENT_EDITED = 'degrees: 270'
 TEST_TRANSFORMATION_COMBINED_CACHE_HASH = '384bf78014d2aed7255d9e548a0694c70af0b22545653214bcceb1ac6286b5f7'
