@@ -1,16 +1,25 @@
 import hashlib
 import logging
 
-from PIL import Image, ImageColor, ImageDraw, ImageFilter
+from PIL import Image, ImageColor, ImageFilter
 
-from django.apps import apps
+from django import forms
 from django.utils.encoding import force_bytes, force_text
 from django.utils.text import format_lazy
 from django.utils.translation import ugettext_lazy as _
 
+from mayan.apps.views.forms import Form
 from mayan.apps.views.http import URL
+from mayan.apps.views.widgets import ColorWidget
 
 from .layers import layer_decorations, layer_saved_transformations
+from .transformation_mixins import (
+    AssetTransformationMixin,
+    ImagePasteCoordinatesAbsoluteTransformationMixin,
+    ImagePasteCoordinatesPercentTransformationMixin,
+    ImageWatermarkPercentTransformationMixin,
+    TransformationDrawRectangleMixin
+)
 
 logger = logging.getLogger(name=__name__)
 
@@ -35,7 +44,13 @@ class BaseTransformation(metaclass=BaseTransformationType):
         result = hashlib.sha256()
 
         for transformation in transformations or ():
-            result.update(transformation.cache_hash())
+            try:
+                result.update(transformation.cache_hash())
+            except Exception as exception:
+                logger.error(
+                    'Unable to compute hash for transformation: %s; %s',
+                    transformation, exception
+                )
 
         return result.hexdigest()
 
@@ -68,6 +83,10 @@ class BaseTransformation(metaclass=BaseTransformationType):
             if cls in transformations:
                 return layer
 
+    @classmethod
+    def get_form_class(cls):
+        return getattr(cls, 'Form', None)
+
     @classmethod
     def get_label(cls):
         arguments = cls.get_arguments()
@@ -90,27 +109,27 @@ class BaseTransformation(metaclass=BaseTransformationType):
                 klass for name, klass in transformation_list
             ]
 
-            result = {}
+            layer_transformation_choices = {}
             for layer, transformations in cls._layer_transformations.items():
                 for transformation in transformations:
                     if transformation in flat_transformation_list:
-                        result.setdefault(layer, [])
-                        result[layer].append(
+                        layer_transformation_choices.setdefault(layer, [])
+                        layer_transformation_choices[layer].append(
                             (transformation.name, transformation.get_label())
                         )
 
+                # Sort the transformation for each layer group.
+                layer_transformation_choices[layer].sort(key=lambda x: x[1])
+
             result = [
-                (layer.label, transformations) for layer, transformations in result.items()
+                (layer.label, transformations) for layer, transformations in layer_transformation_choices.items()
             ]
 
-            # Sort by transformation group, then each transformation in the
-            # group.
-            return sorted(result, key=lambda x: (x[0], x[1]))
+            # Finally sort by transformation layer group.
+            return sorted(result, key=lambda x: x[0])
         else:
             return sorted(
-                [
-                    (name, klass.get_label()) for name, klass in transformation_list
-                ]
+                (name, klass.get_label()) for name, klass in transformation_list
             )
 
     @classmethod
@@ -143,255 +162,53 @@ class BaseTransformation(metaclass=BaseTransformationType):
         self.aspect = 1.0 * image.size[0] / image.size[1]
 
 
-class AssetTransformationMixin:
-    @classmethod
-    def get_arguments(cls):
-        arguments = super().get_arguments() + (
-            'asset_name', 'rotation', 'transparency', 'zoom'
-        )
-        return arguments
-
-    def _update_hash(self):
-        result = super()._update_hash()
-        asset = self.get_asset()
-        # Add the asset image hash to the transformation hash. Ensures
-        # that the content object image is updated if the asset image is
-        # updated even if the transformation itself is not updated.
-        result.update(
-            force_bytes(
-                s=asset.get_hash()
-            )
-        )
-
-        return result
-
-    def get_asset(self):
-        asset_name = getattr(self, 'asset_name', None)
-
-        Asset = apps.get_model(app_label='converter', model_name='Asset')
-
-        try:
-            asset = Asset.objects.get(internal_name=asset_name)
-        except Asset.DoesNotExist:
-            logger.error('Asset "%s" not found.', asset_name)
-            raise
-        else:
-            return asset
-
-    def get_asset_images(self):
-        try:
-            transparency = float(self.transparency or '100.0')
-        except ValueError:
-            transparency = 100
-
-        if transparency < 0:
-            transparency = 0
-        elif transparency > 100:
-            transparency = 100
-
-        try:
-            rotation = int(self.rotation or '0') % 360
-        except ValueError:
-            rotation = 0
-
-        try:
-            zoom = float(self.zoom or '100.0')
-        except ValueError:
-            zoom = 100.0
-
-        asset = self.get_asset()
-
-        image_asset = asset.get_image()
-
-        if image_asset.mode != 'RGBA':
-            image_asset.putalpha(alpha=255)
-
-        image_asset = image_asset.rotate(
-            angle=360 - rotation, resample=Image.BICUBIC,
-            expand=True
-        )
-
-        if zoom != 100.0:
-            decimal_value = zoom / 100.0
-            image_asset = image_asset.resize(
-                size=(
-                    int(image_asset.size[0] * decimal_value),
-                    int(image_asset.size[1] * decimal_value)
-                ), resample=Image.ANTIALIAS
-            )
-
-        paste_mask = image_asset.getchannel(channel='A').point(
-            lut=lambda pixel: int(pixel * transparency / 100)
-        )
-
-        return {
-            'image_asset': image_asset, 'paste_mask': paste_mask
-        }
-
-
-class TransformationAssetPaste(AssetTransformationMixin, BaseTransformation):
-    arguments = ('left', 'top')
-    label = _('Paste an asset')
+class TransformationAssetPaste(
+    ImagePasteCoordinatesAbsoluteTransformationMixin,
+    AssetTransformationMixin, BaseTransformation
+):
+    label = _('Paste an asset (absolute coordinates)')
     name = 'paste_asset'
 
-    def _execute_on(self, *args, **kwargs):
-        try:
-            left = int(self.left or '0')
-        except ValueError:
-            left = 0
 
-        try:
-            top = int(self.top or '0')
-        except ValueError:
-            top = 0
-
-        asset_name = getattr(self, 'asset_name', None)
-
-        if asset_name:
-            align_horizontal = getattr(self, 'align_horizontal', 'left')
-            align_vertical = getattr(self, 'align_vertical', 'top')
-
-            result = self.get_asset_images()
-            if result:
-                if align_horizontal == 'left':
-                    left = left
-                elif align_horizontal == 'center':
-                    left = int(left - result['image_asset'].size[0] / 2)
-                elif align_horizontal == 'right':
-                    left = int(left - result['image_asset'].size[0])
-
-                if align_vertical == 'top':
-                    top = top
-                elif align_vertical == 'middle':
-                    top = int(top - result['image_asset'].size[1] / 2)
-                elif align_vertical == 'bottom':
-                    top = int(top - result['image_asset'].size[1])
-
-                self.image.paste(
-                    im=result['image_asset'], box=(left, top),
-                    mask=result['paste_mask']
-                )
-        else:
-            logger.error('No asset name specified.')
-
-        return self.image
-
-    def execute_on(self, *args, **kwargs):
-        super().execute_on(*args, **kwargs)
-        return self._execute_on(self, *args, **kwargs)
-
-
-class TransformationAssetPastePercent(TransformationAssetPaste):
+class TransformationAssetPastePercent(
+    ImagePasteCoordinatesPercentTransformationMixin,
+    AssetTransformationMixin, BaseTransformation
+):
     label = _('Paste an asset (percents coordinates)')
     name = 'paste_asset_percent'
 
-    def _execute_on(self, *args, **kwargs):
-        try:
-            left = float(self.left or '0')
-        except ValueError:
-            left = 0
-
-        try:
-            top = float(self.top or '0')
-        except ValueError:
-            top = 0
-
-        if left < 0:
-            left = 0
-
-        if left > 100:
-            left = 100
-
-        if top < 0:
-            top = 0
-
-        if top > 100:
-            top = 100
-
-        result = self.get_asset_images()
-
-        self.left = left / 100.0 * (
-            self.image.size[0] - result['image_asset'].size[0]
-        )
-        self.top = top / 100.0 * (
-            self.image.size[1] - result['image_asset'].size[1]
-        )
-        self.align_horizontal = 'left'
-        self.align_vertical = 'top'
-
-        return super()._execute_on(self, *args, **kwargs)
-
 
 class TransformationAssetWatermark(
-    AssetTransformationMixin, BaseTransformation
+    ImageWatermarkPercentTransformationMixin, AssetTransformationMixin,
+    BaseTransformation
 ):
-    arguments = (
-        'left', 'top', 'right', 'bottom', 'horizontal_increment',
-        'vertical_increment'
-    )
     label = _('Paste an asset as watermark')
     name = 'paste_asset_watermark'
 
-    def execute_on(self, *args, **kwargs):
-        super().execute_on(*args, **kwargs)
-        try:
-            left = int(self.left or '0')
-        except ValueError:
-            left = 0
-
-        try:
-            top = int(self.top or '0')
-        except ValueError:
-            top = 0
-
-        try:
-            right = int(self.right or '0')
-        except ValueError:
-            right = 0
-
-        try:
-            bottom = int(self.bottom or '0')
-        except ValueError:
-            bottom = 0
-
-        asset_name = getattr(self, 'asset_name', None)
-
-        if asset_name:
-            result = self.get_asset_images()
-            if result:
-                try:
-                    horizontal_increment = int(self.horizontal_increment or '0')
-                except ValueError:
-                    horizontal_increment = 0
-
-                try:
-                    vertical_increment = int(self.vertical_increment or '0')
-                except ValueError:
-                    vertical_increment = 0
-
-                if horizontal_increment == 0:
-                    horizontal_increment = result['paste_mask'].size[0]
-
-                if vertical_increment == 0:
-                    vertical_increment = result['paste_mask'].size[1]
-
-                for x in range(left, right or self.image.size[0], horizontal_increment):
-                    for y in range(top, bottom or self.image.size[1], vertical_increment):
-                        self.image.paste(
-                            im=result['image_asset'], box=(x, y),
-                            mask=result['paste_mask']
-                        )
-        else:
-            logger.error('No asset name specified.')
-
-        return self.image
-
 
 class TransformationCrop(BaseTransformation):
     arguments = ('left', 'top', 'right', 'bottom',)
     label = _('Crop')
     name = 'crop'
 
+    class Form(Form):
+        left = forms.IntegerField(
+            help_text=_('Number of pixels to remove from the left.'),
+            label=_('Left'), required=False
+        )
+        top = forms.IntegerField(
+            help_text=_('Number of pixels to remove from the top.'),
+            label=_('Top'), required=False
+        )
+        right = forms.IntegerField(
+            help_text=_('Number of pixels to remove from the right.'),
+            label=_('Right'), required=False
+        )
+        bottom = forms.IntegerField(
+            help_text=_('Number of pixels to remove from the bottom.'),
+            label=_('Bottom'), required=False
+        )
+
     def execute_on(self, *args, **kwargs):
         super().execute_on(*args, **kwargs)
 
@@ -462,14 +279,34 @@ class TransformationCrop(BaseTransformation):
         return self.image.crop(box=(left, top, right, bottom))
 
 
-class TransformationDrawRectangle(BaseTransformation):
+class TransformationDrawRectangle(
+    TransformationDrawRectangleMixin, BaseTransformation
+):
     arguments = (
-        'left', 'top', 'right', 'bottom', 'fillcolor', 'outlinecolor',
-        'outlinewidth'
+        'left', 'top', 'right', 'bottom', 'fillcolor', 'fill_transparency',
+        'outlinecolor', 'outlinewidth'
     )
     label = _('Draw rectangle')
     name = 'draw_rectangle'
 
+    class Form(TransformationDrawRectangleMixin.Form):
+        left = forms.IntegerField(
+            help_text=_('Left side location in pixels.'), label=_('Left'),
+            required=False
+        )
+        top = forms.IntegerField(
+            help_text=_('Top side location in pixels.'), label=_('Top'),
+            required=False
+        )
+        right = forms.IntegerField(
+            help_text=_('Right side location in pixels.'), label=_('Right'),
+            required=False
+        )
+        bottom = forms.IntegerField(
+            help_text=_('Bottom side location in pixels.'),
+            label=_('Bottom'), required=False
+        )
+
     def execute_on(self, *args, **kwargs):
         super().execute_on(*args, **kwargs)
 
@@ -532,46 +369,42 @@ class TransformationDrawRectangle(BaseTransformation):
         if top > bottom:
             top = bottom - 1
 
-        logger.debug(
-            'left: %f, top: %f, right: %f, bottom: %f', left, top, right,
-            bottom
-        )
+        self.bottom = bottom
+        self.left = left
+        self.top = top
+        self.right = right
 
-        fillcolor_value = getattr(self, 'fillcolor', None)
-        if fillcolor_value:
-            fill_color = ImageColor.getrgb(color=fillcolor_value)
-        else:
-            fill_color = 0
-
-        outlinecolor_value = getattr(self, 'outlinecolor', None)
-        if outlinecolor_value:
-            outline_color = ImageColor.getrgb(color=outlinecolor_value)
-        else:
-            outline_color = None
-
-        outlinewidth_value = getattr(self, 'outlinewidth', None)
-        if outlinewidth_value:
-            outline_width = int(outlinewidth_value)
-        else:
-            outline_width = 0
-
-        draw = ImageDraw.Draw(im=self.image)
-        draw.rectangle(
-            xy=(left, top, right, bottom), fill=fill_color,
-            outline=outline_color, width=outline_width
-        )
-
-        return self.image
+        return super()._execute_on(self, *args, **kwargs)
 
 
-class TransformationDrawRectanglePercent(BaseTransformation):
+class TransformationDrawRectanglePercent(
+    TransformationDrawRectangleMixin, BaseTransformation
+):
     arguments = (
-        'left', 'top', 'right', 'bottom', 'fillcolor', 'outlinecolor',
-        'outlinewidth'
+        'left', 'top', 'right', 'bottom', 'fillcolor', 'fill_transparency',
+        'outlinecolor', 'outlinewidth'
     )
     label = _('Draw rectangle (percents coordinates)')
     name = 'draw_rectangle_percent'
 
+    class Form(TransformationDrawRectangleMixin.Form):
+        left = forms.FloatField(
+            help_text=_('Left side location in percent.'),
+            label=_('Left'), required=False
+        )
+        top = forms.FloatField(
+            help_text=_('Top side location in percent.'),
+            label=_('Top'), required=False
+        )
+        right = forms.FloatField(
+            help_text=_('Right side location in percent.'),
+            label=_('Right'), required=False
+        )
+        bottom = forms.FloatField(
+            help_text=_('Bottom side location in percent.'),
+            label=_('Bottom'), required=False
+        )
+
     def execute_on(self, *args, **kwargs):
         super().execute_on(*args, **kwargs)
 
@@ -624,24 +457,6 @@ class TransformationDrawRectanglePercent(BaseTransformation):
             bottom
         )
 
-        fillcolor_value = getattr(self, 'fillcolor', None)
-        if fillcolor_value:
-            fill_color = ImageColor.getrgb(color=fillcolor_value)
-        else:
-            fill_color = 0
-
-        outlinecolor_value = getattr(self, 'outlinecolor', None)
-        if outlinecolor_value:
-            outline_color = ImageColor.getrgb(color=outlinecolor_value)
-        else:
-            outline_color = None
-
-        outlinewidth_value = getattr(self, 'outlinewidth', None)
-        if outlinewidth_value:
-            outline_width = int(outlinewidth_value)
-        else:
-            outline_width = 0
-
         left = left / 100.0 * self.image.size[0]
         top = top / 100.0 * self.image.size[1]
 
@@ -655,13 +470,12 @@ class TransformationDrawRectanglePercent(BaseTransformation):
         right = self.image.size[0] - (right / 100.0 * self.image.size[0])
         bottom = self.image.size[1] - (bottom / 100.0 * self.image.size[1])
 
-        draw = ImageDraw.Draw(im=self.image)
-        draw.rectangle(
-            xy=(left, top, right, bottom), fill=fill_color, outline=outline_color,
-            width=outline_width
-        )
+        self.bottom = bottom
+        self.left = left
+        self.top = top
+        self.right = right
 
-        return self.image
+        return super()._execute_on(self, *args, **kwargs)
 
 
 class TransformationFlip(BaseTransformation):
@@ -680,6 +494,11 @@ class TransformationGaussianBlur(BaseTransformation):
     label = _('Gaussian blur')
     name = 'gaussianblur'
 
+    class Form(Form):
+        radius = forms.IntegerField(
+            initial=2, label=_('Radius'), required=True
+        )
+
     def execute_on(self, *args, **kwargs):
         super().execute_on(*args, **kwargs)
 
@@ -717,6 +536,18 @@ class TransformationResize(BaseTransformation):
     label = _('Resize')
     name = 'resize'
 
+    class Form(Form):
+        width = forms.IntegerField(
+            help_text=_(
+                'New width in pixels.'
+            ), label=_('Width'), required=True
+        )
+        height = forms.IntegerField(
+            help_text=_(
+                'New height in pixels.'
+            ), label=_('Height'), required=False
+        )
+
     def execute_on(self, *args, **kwargs):
         super().execute_on(*args, **kwargs)
 
@@ -729,8 +560,10 @@ class TransformationResize(BaseTransformation):
 
         if factor > 1:
             self.image.thumbnail(
-                size=(self.image.size[0] / factor, self.image.size[1] / factor),
-                resample=Image.NEAREST
+                size=(
+                    self.image.size[0] / factor,
+                    self.image.size[1] / factor
+                ), resample=Image.NEAREST
             )
 
         # Resize the image with best quality algorithm ANTIALIAS.
@@ -744,6 +577,19 @@ class TransformationRotate(BaseTransformation):
     label = _('Rotate')
     name = 'rotate'
 
+    class Form(Form):
+        degrees = forms.IntegerField(
+            help_text=_(
+                'Number of degrees to rotate the image counter clockwise '
+                'around its center.'
+            ), label=_('Degrees'), required=True
+        )
+        fillcolor = forms.CharField(
+            help_text=_(
+                'Color to be used for area outside of the rotated image.'
+            ), label=_('Fill color'), required=False, widget=ColorWidget()
+        )
+
     def execute_on(self, *args, **kwargs):
         super().execute_on(*args, **kwargs)
 
@@ -806,6 +652,21 @@ class TransformationUnsharpMask(BaseTransformation):
     label = _('Unsharp masking')
     name = 'unsharpmask'
 
+    class Form(Form):
+        radius = forms.IntegerField(
+            initial=2, help_text=_('The blur radius in pixels.'),
+            label=_('Radius'), required=True
+        )
+        percent = forms.FloatField(
+            initial=150, help_text=_('Unsharp strength in percent.'),
+            label=_('Percent'), required=True
+        )
+        threshold = forms.IntegerField(
+            initial=3, help_text=_(
+                'Minimum brightness change that will be sharpened.'
+            ), label=_('Tthreshold'), required=True
+        )
+
     def execute_on(self, *args, **kwargs):
         super().execute_on(*args, **kwargs)
 
@@ -822,6 +683,12 @@ class TransformationZoom(BaseTransformation):
     label = _('Zoom')
     name = 'zoom'
 
+    class Form(Form):
+        percent = forms.FloatField(
+            help_text=_('Zoom level in percent.'),
+            label=_('Percent'), required=True
+        )
+
     def execute_on(self, *args, **kwargs):
         super().execute_on(*args, **kwargs)
 
@@ -858,11 +725,11 @@ BaseTransformation.register(
     layer=layer_saved_transformations, transformation=TransformationCrop
 )
 BaseTransformation.register(
-    layer=layer_saved_transformations,
+    layer=layer_decorations,
     transformation=TransformationDrawRectangle
 )
 BaseTransformation.register(
-    layer=layer_saved_transformations,
+    layer=layer_decorations,
     transformation=TransformationDrawRectanglePercent
 )
 BaseTransformation.register(
