@@ -1,6 +1,5 @@
-from rest_framework import serializers
-
 from mayan.apps.user_management.serializers import UserSerializer
+from mayan.apps.rest_api import serializers
 from mayan.apps.rest_api.relations import MultiKwargHyperlinkedIdentityField
 
 from .models import Comment
