@@ -27,25 +27,25 @@ class CommentAPIViewTestCase(
         self._create_test_document_stub()
 
     def test_comment_create_api_view_no_permission(self):
-        comment_count = self.test_document.comments.count()
+        comment_count = self._test_document.comments.count()
 
         self._clear_events()
 
         response = self._request_test_comment_create_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertEqual(self.test_document.comments.count(), comment_count)
+        self.assertEqual(self._test_document.comments.count(), comment_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_comment_create_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_create
         )
 
-        comment_count = self.test_document.comments.count()
+        comment_count = self._test_document.comments.count()
 
         self._clear_events()
 
@@ -53,33 +53,33 @@ class CommentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         self.assertEqual(
-            self.test_document.comments.count(), comment_count + 1
+            self._test_document.comments.count(), comment_count + 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_comment)
+        self.assertEqual(events[0].target, self._test_document_comment)
         self.assertEqual(events[0].verb, event_document_comment_created.id)
 
     def test_trashed_document_comment_create_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_create
         )
 
-        comment_count = self.test_document.comments.count()
+        comment_count = self._test_document.comments.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_comment_create_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertEqual(self.test_document.comments.count(), comment_count)
+        self.assertEqual(self._test_document.comments.count(), comment_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -87,14 +87,14 @@ class CommentAPIViewTestCase(
     def test_comment_delete_api_view_no_permission(self):
         self._create_test_comment()
 
-        comment_count = self.test_document.comments.count()
+        comment_count = self._test_document.comments.count()
 
         self._clear_events()
 
         response = self._request_test_comment_delete_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertEqual(self.test_document.comments.count(), comment_count)
+        self.assertEqual(self._test_document.comments.count(), comment_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -102,11 +102,11 @@ class CommentAPIViewTestCase(
     def test_comment_delete_api_view_with_access(self):
         self._create_test_comment()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_delete
         )
 
-        comment_count = self.test_document.comments.count()
+        comment_count = self._test_document.comments.count()
 
         self._clear_events()
 
@@ -114,7 +114,7 @@ class CommentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
         self.assertEqual(
-            self.test_document.comments.count(), comment_count - 1
+            self._test_document.comments.count(), comment_count - 1
         )
 
         events = self._get_test_events()
@@ -122,26 +122,26 @@ class CommentAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_comment_deleted.id)
 
     def test_trashed_document_comment_delete_api_view_with_access(self):
         self._create_test_comment()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_delete
         )
 
-        comment_count = self.test_document.comments.count()
+        comment_count = self._test_document.comments.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_comment_delete_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertEqual(self.test_document.comments.count(), comment_count)
+        self.assertEqual(self._test_document.comments.count(), comment_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -160,7 +160,7 @@ class CommentAPIViewTestCase(
     def test_comment_detail_api_view_with_access(self):
         self._create_test_comment()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_view
         )
 
@@ -170,7 +170,7 @@ class CommentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
         self.assertEqual(
-            response.data['text'], self.test_document_comment.text
+            response.data['text'], self._test_document_comment.text
         )
 
         events = self._get_test_events()
@@ -179,11 +179,11 @@ class CommentAPIViewTestCase(
     def test_trashed_document_comment_detail_api_view_with_access(self):
         self._create_test_comment()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -196,16 +196,16 @@ class CommentAPIViewTestCase(
     def test_comment_edit_via_patch_api_view_no_permission(self):
         self._create_test_comment()
 
-        comment_text = self.test_document_comment.text
+        comment_text = self._test_document_comment.text
 
         self._clear_events()
 
         response = self._request_test_comment_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_comment.refresh_from_db()
-        self.assertEqual(self.test_document_comment.text, comment_text)
-        self.assertEqual(self.test_document_comment.user, self.test_user)
+        self._test_document_comment.refresh_from_db()
+        self.assertEqual(self._test_document_comment.text, comment_text)
+        self.assertEqual(self._test_document_comment.user, self._test_user)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -214,49 +214,49 @@ class CommentAPIViewTestCase(
         self._create_test_comment()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_edit
         )
 
-        comment_text = self.test_document_comment.text
+        comment_text = self._test_document_comment.text
 
         self._clear_events()
 
         response = self._request_test_comment_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document_comment.refresh_from_db()
-        self.assertNotEqual(self.test_document_comment.text, comment_text)
-        self.assertEqual(self.test_document_comment.user, self.test_user)
+        self._test_document_comment.refresh_from_db()
+        self.assertNotEqual(self._test_document_comment.text, comment_text)
+        self.assertEqual(self._test_document_comment.user, self._test_user)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_comment)
+        self.assertEqual(events[0].target, self._test_document_comment)
         self.assertEqual(events[0].verb, event_document_comment_edited.id)
 
     def test_trashed_document_comment_edit_via_patch_api_view_with_access(self):
         self._create_test_comment()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_edit
         )
 
-        comment_text = self.test_document_comment.text
+        comment_text = self._test_document_comment.text
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_comment_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_comment.refresh_from_db()
-        self.assertEqual(self.test_document_comment.text, comment_text)
-        self.assertEqual(self.test_document_comment.user, self.test_user)
+        self._test_document_comment.refresh_from_db()
+        self.assertEqual(self._test_document_comment.text, comment_text)
+        self.assertEqual(self._test_document_comment.user, self._test_user)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -264,16 +264,16 @@ class CommentAPIViewTestCase(
     def test_comment_edit_via_put_api_view_no_permission(self):
         self._create_test_comment()
 
-        comment_text = self.test_document_comment.text
+        comment_text = self._test_document_comment.text
 
         self._clear_events()
 
         response = self._request_test_comment_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_comment.refresh_from_db()
-        self.assertEqual(self.test_document_comment.text, comment_text)
-        self.assertEqual(self.test_document_comment.user, self.test_user)
+        self._test_document_comment.refresh_from_db()
+        self.assertEqual(self._test_document_comment.text, comment_text)
+        self.assertEqual(self._test_document_comment.user, self._test_user)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -282,49 +282,49 @@ class CommentAPIViewTestCase(
         self._create_test_comment()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_edit
         )
 
-        comment_text = self.test_document_comment.text
+        comment_text = self._test_document_comment.text
 
         self._clear_events()
 
         response = self._request_test_comment_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document_comment.refresh_from_db()
-        self.assertNotEqual(self.test_document_comment.text, comment_text)
-        self.assertEqual(self.test_document_comment.user, self.test_user)
+        self._test_document_comment.refresh_from_db()
+        self.assertNotEqual(self._test_document_comment.text, comment_text)
+        self.assertEqual(self._test_document_comment.user, self._test_user)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_comment)
+        self.assertEqual(events[0].target, self._test_document_comment)
         self.assertEqual(events[0].verb, event_document_comment_edited.id)
 
     def test_trashed_document_comment_edit_via_put_api_view_with_access(self):
         self._create_test_comment()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_edit
         )
 
-        comment_text = self.test_document_comment.text
+        comment_text = self._test_document_comment.text
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_comment_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_comment.refresh_from_db()
-        self.assertEqual(self.test_document_comment.text, comment_text)
-        self.assertEqual(self.test_document_comment.user, self.test_user)
+        self._test_document_comment.refresh_from_db()
+        self.assertEqual(self._test_document_comment.text, comment_text)
+        self.assertEqual(self._test_document_comment.user, self._test_user)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -343,7 +343,7 @@ class CommentAPIViewTestCase(
     def test_comment_list_api_view_with_access(self):
         self._create_test_comment()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_view
         )
 
@@ -353,7 +353,7 @@ class CommentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
             response.data['results'][0]['text'],
-            self.test_document_comment.text
+            self._test_document_comment.text
         )
 
         events = self._get_test_events()
@@ -362,11 +362,11 @@ class CommentAPIViewTestCase(
     def test_trashed_document_comment_list_api_view_with_access(self):
         self._create_test_comment()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_comment_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
