@@ -13,35 +13,35 @@ def transformation_format_uuid(term_string):
         return term_string
 
 
-index_instance_node_search = SearchModel(
+search_model_index_instance_node = SearchModel(
     app_label='document_indexing', model_name='IndexInstanceNodeSearchResult',
     permission=permission_index_instance_view,
     serializer_path='mayan.apps.document_indexing.serializers.IndexInstanceNodeSerializer'
 )
-index_instance_node_search.add_proxy_model(
+search_model_index_instance_node.add_proxy_model(
     app_label='document_indexing', model_name='IndexInstanceNode'
 )
 
-index_instance_node_search.add_model_field(
+search_model_index_instance_node.add_model_field(
     field='value', label=_('Value')
 )
 
-index_instance_node_search.add_model_field(
+search_model_index_instance_node.add_model_field(
     field='documents__document_type__label', label=_('Document type')
 )
-index_instance_node_search.add_model_field(
+search_model_index_instance_node.add_model_field(
     field='documents__files__mimetype', label=_('Document MIME type')
 )
-index_instance_node_search.add_model_field(
+search_model_index_instance_node.add_model_field(
     field='documents__label', label=_('Document label')
 )
-index_instance_node_search.add_model_field(
+search_model_index_instance_node.add_model_field(
     field='documents__description', label=_('Document description')
 )
-index_instance_node_search.add_model_field(
+search_model_index_instance_node.add_model_field(
     field='documents__uuid', label=_('Document UUID'),
     transformation_function=transformation_format_uuid
 )
-index_instance_node_search.add_model_field(
+search_model_index_instance_node.add_model_field(
     field='documents__files__checksum', label=_('Document checksum')
 )
