@@ -1,3 +1,4 @@
+from django.conf import settings
 from django.contrib import messages
 from django.shortcuts import get_object_or_404
 from django.template import RequestContext
@@ -5,8 +6,10 @@ from django.urls import reverse, reverse_lazy
 from django.utils.translation import ugettext_lazy as _, ungettext
 
 from mayan.apps.acls.models import AccessControlList
-from mayan.apps.documents.models import DocumentType
+from mayan.apps.documents.models.document_models import Document
+from mayan.apps.documents.models.document_type_models import DocumentType
 from mayan.apps.documents.permissions import permission_document_type_edit
+from mayan.apps.events.classes import EventType, ModelEventType
 from mayan.apps.views.generics import (
     AddRemoveView, ConfirmView, FormView, SingleObjectCreateView,
     SingleObjectDeleteView, SingleObjectEditView, SingleObjectListView
@@ -14,10 +17,24 @@ from mayan.apps.views.generics import (
 from mayan.apps.views.mixins import ExternalObjectViewMixin
 
 from ..events import event_index_template_edited
-from ..forms import IndexTemplateFilteredForm, IndexTemplateNodeForm
-from ..icons import icon_index
+from ..forms import (
+    IndexTemplateEventTriggerRelationshipFormSet, IndexTemplateFilteredForm,
+    IndexTemplateNodeForm
+)
+from ..icons import (
+    icon_document_type_index_templates, icon_index,
+    icon_index_instances_rebuild, icon_index_instances_reset,
+    icon_index_template_create, icon_index_template_delete,
+    icon_index_template_document_types, icon_index_template_edit,
+    icon_index_template_event_triggers, icon_index_template_list,
+    icon_index_template_node_create, icon_index_template_node_delete,
+    icon_index_template_node_edit, icon_index_template_node_tree_view
+)
 from ..links import link_index_template_create
-from ..models import IndexTemplate, IndexTemplateNode
+from ..literals import RELATIONSHIP_NO, RELATIONSHIP_YES
+from ..models.index_template_models import (
+    IndexTemplate, IndexTemplateEventTrigger, IndexTemplateNode
+)
 from ..permissions import (
     permission_index_template_create, permission_index_template_delete,
     permission_index_template_edit, permission_index_template_rebuild,
@@ -26,9 +43,9 @@ from ..permissions import (
 from ..tasks import task_index_template_rebuild
 
 __all__ = (
-    'DocumentTypeIndexTemplateListView', 'IndexTemplateListView',
+    'DocumentTypeIndexTemplateAddRemoveView', 'IndexTemplateListView',
     'IndexTemplateCreateView', 'IndexTemplateDeleteView',
-    'IndexTemplateDocumentTypesView', 'IndexTemplateEditView',
+    'IndexTemplateDocumentTypeAddRemoveView', 'IndexTemplateEditView',
     'IndexTemplateNodeListView', 'IndexTemplateNodeCreateView',
     'IndexTemplateNodeDeleteView', 'IndexTemplateNodeEditView',
     'IndexTemplateAllRebuildView', 'IndexTemplateRebuildView',
@@ -36,7 +53,7 @@ __all__ = (
 )
 
 
-class DocumentTypeIndexTemplateListView(AddRemoveView):
+class DocumentTypeIndexTemplateAddRemoveView(AddRemoveView):
     main_object_permission = permission_document_type_edit
     main_object_model = DocumentType
     main_object_pk_url_kwarg = 'document_type_id'
@@ -45,6 +62,7 @@ class DocumentTypeIndexTemplateListView(AddRemoveView):
     list_available_title = _('Available indexes')
     list_added_title = _('Indexes linked')
     related_field = 'index_templates'
+    view_icon = icon_document_type_index_templates
 
     def action_add(self, queryset, _event_actor):
         for obj in queryset:
@@ -78,6 +96,7 @@ class DocumentTypeIndexTemplateListView(AddRemoveView):
 class IndexTemplateListView(SingleObjectListView):
     model = IndexTemplate
     object_permission = permission_index_template_view
+    view_icon = icon_index_template_list
 
     def get_extra_context(self):
         return {
@@ -104,6 +123,7 @@ class IndexTemplateCreateView(SingleObjectCreateView):
     post_action_redirect = reverse_lazy(
         viewname='indexing:index_template_list'
     )
+    view_icon = icon_index_template_create
     view_permission = permission_index_template_create
 
     def get_instance_extra_data(self):
@@ -117,6 +137,7 @@ class IndexTemplateDeleteView(SingleObjectDeleteView):
     post_action_redirect = reverse_lazy(
         viewname='indexing:index_template_list'
     )
+    view_icon = icon_index_template_delete
 
     def get_extra_context(self):
         return {
@@ -125,7 +146,7 @@ class IndexTemplateDeleteView(SingleObjectDeleteView):
         }
 
 
-class IndexTemplateDocumentTypesView(AddRemoveView):
+class IndexTemplateDocumentTypeAddRemoveView(AddRemoveView):
     main_object_method_add_name = 'document_types_add'
     main_object_method_remove_name = 'document_types_remove'
     main_object_permission = permission_index_template_edit
@@ -136,6 +157,7 @@ class IndexTemplateDocumentTypesView(AddRemoveView):
     list_available_title = _('Available document types')
     list_added_title = _('Document types linked')
     related_field = 'document_types'
+    view_icon = icon_index_template_document_types
 
     def get_actions_extra_kwargs(self):
         return {'_event_actor': self.request.user}
@@ -160,6 +182,7 @@ class IndexTemplateEditView(SingleObjectEditView):
     post_action_redirect = reverse_lazy(
         viewname='indexing:index_template_list'
     )
+    view_icon = icon_index_template_edit
 
     def get_extra_context(self):
         return {
@@ -171,12 +194,106 @@ class IndexTemplateEditView(SingleObjectEditView):
         return {'_event_actor': self.request.user}
 
 
+class IndexTemplateEventTriggerListView(ExternalObjectViewMixin, FormView):
+    external_object_class = IndexTemplate
+    external_object_permission = permission_index_template_edit
+    external_object_pk_url_kwarg = 'index_template_id'
+    form_class = IndexTemplateEventTriggerRelationshipFormSet
+    view_icon = icon_index_template_event_triggers
+
+    def dispatch(self, *args, **kwargs):
+        EventType.refresh()
+        return super().dispatch(*args, **kwargs)
+
+    def form_valid(self, form):
+        try:
+            for instance in form:
+                if instance.cleaned_data['relationship'] == RELATIONSHIP_NO:
+                    try:
+                        index_template_event_trigger = self.external_object.event_triggers.get(
+                            stored_event_type_id=instance.cleaned_data['stored_event_type_id']
+                        )
+                    except self.external_object.event_triggers.model.DoesNotExist:
+                        """Ignore non existing entries."""
+                    else:
+                        index_template_event_trigger._event_actor = self.request.user
+                        index_template_event_trigger.delete()
+                elif instance.cleaned_data['relationship'] == RELATIONSHIP_YES:
+                    if not self.external_object.event_triggers.filter(
+                        stored_event_type_id=instance.cleaned_data['stored_event_type_id']
+                    ).exists():
+                        index_template_event_trigger = IndexTemplateEventTrigger(
+                            index_template=self.external_object,
+                            stored_event_type_id=instance.cleaned_data['stored_event_type_id']
+                        )
+                        index_template_event_trigger._event_actor = self.request.user
+                        index_template_event_trigger.save()
+        except Exception as exception:
+            messages.error(
+                message=_(
+                    'Error updating index template event trigger; %s'
+                ) % exception, request=self.request
+
+            )
+            if settings.DEBUG or settings.TESTING:
+                raise
+        else:
+            messages.success(
+                message=_(
+                    'Index template event triggers updated successfully.'
+                ), request=self.request
+            )
+
+        return super().form_valid(form=form)
+
+    def get_extra_context(self):
+        return {
+            'form_display_mode_table': True,
+            'subtitle': _(
+                'Triggers are document events that cause instances of this '
+                'index template to be updated.'
+            ),
+            'object': self.external_object,
+            'title': _(
+                'Index template event triggers for: %s'
+            ) % self.external_object
+        }
+
+    def get_initial(self):
+        initial = []
+
+        queryset = IndexTemplateEventTrigger.objects.filter(
+            index_template=self.external_object
+        )
+
+        for stored_event_type in self.get_stored_event_types():
+            if queryset.filter(stored_event_type=stored_event_type).exists():
+                relationship = RELATIONSHIP_YES
+            else:
+                relationship = RELATIONSHIP_NO
+
+            initial.append(
+                {
+                    'label': stored_event_type.label,
+                    'namespace': stored_event_type.namespace,
+                    'relationship': relationship,
+                    'stored_event_type_id': stored_event_type.id
+                }
+            )
+        return initial
+
+    def get_stored_event_types(self):
+        for event_type in ModelEventType.get_for_class(klass=Document):
+            yield event_type.get_stored_event_type()
+
+
 class IndexTemplateNodeListView(
     ExternalObjectViewMixin, SingleObjectListView
 ):
     external_object_class = IndexTemplate
     external_object_permission = permission_index_template_edit
     external_object_pk_url_kwarg = 'index_template_id'
+    view_icon = icon_index_template_node_tree_view
 
     def get_extra_context(self):
         return {
@@ -196,6 +313,7 @@ class IndexTemplateNodeListView(
 class IndexTemplateNodeCreateView(SingleObjectCreateView):
     form_class = IndexTemplateNodeForm
     model = IndexTemplateNode
+    view_icon = icon_index_template_node_create
 
     def dispatch(self, request, *args, **kwargs):
         AccessControlList.objects.check_access(
@@ -227,6 +345,7 @@ class IndexTemplateNodeDeleteView(SingleObjectDeleteView):
     model = IndexTemplateNode
     object_permission = permission_index_template_edit
     pk_url_kwarg = 'index_template_node_id'
+    view_icon = icon_index_template_node_delete
 
     def get_extra_context(self):
         return {
@@ -251,6 +370,7 @@ class IndexTemplateNodeEditView(SingleObjectEditView):
     model = IndexTemplateNode
     object_permission = permission_index_template_edit
     pk_url_kwarg = 'index_template_node_id'
+    view_icon = icon_index_template_node_edit
 
     def get_extra_context(self):
         return {
@@ -274,6 +394,7 @@ class IndexTemplateRebuildView(ConfirmView):
     post_action_redirect = reverse_lazy(
         viewname='indexing:index_template_list'
     )
+    view_icon = icon_index_instances_rebuild
 
     def get_extra_context(self):
         return {
@@ -310,6 +431,7 @@ class IndexTemplateAllRebuildView(FormView):
         'title': _('Rebuild index templates'),
     }
     form_class = IndexTemplateFilteredForm
+    view_icon = icon_index_instances_rebuild
 
     def form_valid(self, form):
         count = 0
@@ -347,6 +469,7 @@ class IndexTemplateResetView(FormView):
         'title': _('Reset indexes'),
     }
     form_class = IndexTemplateFilteredForm
+    view_icon = icon_index_instances_reset
 
     def form_valid(self, form):
         count = 0
