@@ -11,13 +11,21 @@ from mayan.apps.documents.models.document_file_page_models import DocumentFilePa
 from mayan.apps.documents.models.document_type_models import DocumentType
 from mayan.apps.views.generics import (
     FormView, MultipleObjectConfirmActionView, MultipleObjectDeleteView,
-    SingleObjectDetailView, SingleObjectDownloadView, SingleObjectEditView,
-    SingleObjectListView
+    SingleObjectDetailView, SingleObjectDownloadView, SingleObjectEditView
 )
 from mayan.apps.views.mixins import ExternalObjectViewMixin
 
 from .forms import DocumentFileContentForm, DocumentFilePageContentForm
-from .models import DocumentFileParseError, DocumentFilePageContent
+from .icons import (
+    icon_document_file_content_single_delete,
+    icon_document_file_content_detail,
+    icon_document_file_content_download,
+    icon_document_file_parsing_single_submit,
+    icon_document_file_page_content_detail,
+    icon_document_type_parsing_settings,
+    icon_document_type_parsing_submit
+)
+from .models import DocumentFilePageContent
 from .permissions import (
     permission_document_file_content_view, permission_document_type_parsing_setup,
     permission_document_file_parse
@@ -47,6 +55,7 @@ class DocumentFileContentDeleteView(MultipleObjectDeleteView):
     title_plural = _(
         'Delete the content of the %(count)d selected document versions.'
     )
+    view_icon = icon_document_file_content_single_delete
 
     def object_action(self, form, instance):
         DocumentFilePageContent.objects.delete_content_for(
@@ -58,6 +67,7 @@ class DocumentFileContentDownloadView(SingleObjectDownloadView):
     object_permission = permission_document_file_content_view
     pk_url_kwarg = 'document_file_id'
     source_queryset = DocumentFile.valid.all()
+    view_icon = icon_document_file_content_download
 
     def get_download_file_object(self):
         return self.object.content()
@@ -71,6 +81,7 @@ class DocumentFileContentView(SingleObjectDetailView):
     object_permission = permission_document_file_content_view
     pk_url_kwarg = 'document_file_id'
     source_queryset = DocumentFile.valid.all()
+    view_icon = icon_document_file_content_detail
 
     def dispatch(self, request, *args, **kwargs):
         result = super().dispatch(request=request, *args, **kwargs)
@@ -92,6 +103,7 @@ class DocumentFilePageContentView(SingleObjectDetailView):
     object_permission = permission_document_file_content_view
     pk_url_kwarg = 'document_file_page_id'
     source_queryset = DocumentFilePage.valid.all()
+    view_icon = icon_document_file_page_content_detail
 
     def dispatch(self, request, *args, **kwargs):
         result = super().dispatch(request=request, *args, **kwargs)
@@ -114,26 +126,6 @@ class DocumentFilePageContentView(SingleObjectDetailView):
         )
 
 
-class DocumentFileParsingErrorsListView(
-    ExternalObjectViewMixin, SingleObjectListView
-):
-    external_object_permission = permission_document_file_parse
-    external_object_pk_url_kwarg = 'document_file_id'
-    external_object_queryset = DocumentFile.valid.all()
-
-    def get_extra_context(self):
-        return {
-            'hide_object': True,
-            'object': self.external_object,
-            'title': _(
-                'Parsing errors for document file: %s'
-            ) % self.external_object,
-        }
-
-    def get_source_queryset(self):
-        return self.external_object.parsing_errors.all()
-
-
 class DocumentFileSubmitView(MultipleObjectConfirmActionView):
     object_permission = permission_document_file_parse
     pk_url_kwarg = 'document_file_id'
@@ -144,6 +136,7 @@ class DocumentFileSubmitView(MultipleObjectConfirmActionView):
     success_message_plural = _(
         '%(count)d documents files added to the parsing queue'
     )
+    view_icon = icon_document_file_parsing_single_submit
 
     def get_extra_context(self):
         queryset = self.object_list
@@ -182,6 +175,7 @@ class DocumentTypeSettingsEditView(ExternalObjectViewMixin, SingleObjectEditView
     post_action_redirect = reverse_lazy(
         viewname='documents:document_type_list'
     )
+    view_icon = icon_document_type_parsing_settings
 
     def get_document_type(self):
         return self.external_object
@@ -204,6 +198,7 @@ class DocumentTypeSubmitView(FormView):
     }
     form_class = DocumentTypeFilteredSelectForm
     post_action_redirect = reverse_lazy(viewname='common:tools_list')
+    view_icon = icon_document_type_parsing_submit
 
     def get_form_extra_kwargs(self):
         return {
@@ -228,14 +223,3 @@ class DocumentTypeSubmitView(FormView):
         )
 
         return HttpResponseRedirect(redirect_to=self.get_success_url())
-
-
-class ParseErrorListView(SingleObjectListView):
-    extra_context = {
-        'hide_object': True,
-        'title': _('Parsing errors'),
-    }
-    view_permission = permission_document_file_parse
-
-    def get_source_queryset(self):
-        return DocumentFileParseError.objects.all()
