@@ -77,7 +77,7 @@ class SignatureBaseModel(models.Model):
 
     def get_absolute_url(self):
         return reverse(
-            viewname='signatures:document_file_signature_details',
+            viewname='signatures:document_file_signature_detail',
             kwargs={'signature_id': self.pk}
         )
 
