@@ -16,10 +16,19 @@ from mayan.apps.views.generics import (
 from mayan.apps.views.mixins import ExternalObjectViewMixin
 
 from .forms import (
-    DocumentFileSignatureCreateForm,
-    DocumentFileSignatureDetailForm
+    DocumentFileSignatureCreateForm, DocumentFileSignatureDetailForm
+)
+from .icons import (
+    icon_document_file_all_signature_refresh,
+    icon_document_file_all_signature_verify,
+    icon_document_file_signature_detached_delete,
+    icon_document_file_signature_detached_create,
+    icon_document_file_signature_detail,
+    icon_document_file_signature_detached_download,
+    icon_document_file_signature_detached_upload,
+    icon_document_file_signature_embedded_create,
+    icon_document_file_signature_list
 )
-from .icons import icon_document_file_signature_list
 from .links import (
     link_document_file_signature_detached_create,
     link_document_file_signature_embedded_create,
@@ -36,17 +45,21 @@ from .permissions import (
     permission_document_file_signature_view,
 )
 from .tasks import (
-    task_refresh_signature_information, task_verify_missing_embedded_signature
+    task_refresh_signature_information,
+    task_verify_missing_embedded_signature
 )
 
 logger = logging.getLogger(name=__name__)
 
 
-class DocumentFileDetachedSignatureCreateView(ExternalObjectViewMixin, FormView):
+class DocumentFileDetachedSignatureCreateView(
+    ExternalObjectViewMixin, FormView
+):
     external_object_permission = permission_document_file_sign_detached
     external_object_pk_url_kwarg = 'document_file_id'
     external_object_queryset = DocumentFile.valid.all()
     form_class = DocumentFileSignatureCreateForm
+    view_icon = icon_document_file_signature_detached_create
 
     def form_valid(self, form):
         key = form.cleaned_data['key']
@@ -109,11 +122,14 @@ class DocumentFileDetachedSignatureCreateView(ExternalObjectViewMixin, FormView)
         )
 
 
-class DocumentFileEmbeddedSignatureCreateView(ExternalObjectViewMixin, FormView):
+class DocumentFileEmbeddedSignatureCreateView(
+    ExternalObjectViewMixin, FormView
+):
     external_object_permission = permission_document_file_sign_embedded
     external_object_pk_url_kwarg = 'document_file_id'
     external_object_queryset = DocumentFile.valid.all()
     form_class = DocumentFileSignatureCreateForm
+    view_icon = icon_document_file_signature_embedded_create
 
     def form_valid(self, form):
         key = form.cleaned_data['key']
@@ -180,6 +196,7 @@ class DocumentFileEmbeddedSignatureCreateView(ExternalObjectViewMixin, FormView)
 class DocumentFileDetachedSignatureDeleteView(SingleObjectDeleteView):
     object_permission = permission_document_file_signature_delete
     pk_url_kwarg = 'signature_id'
+    view_icon = icon_document_file_signature_detached_delete
 
     def get_extra_context(self):
         return {
@@ -207,6 +224,7 @@ class DocumentFileDetachedSignatureDeleteView(SingleObjectDeleteView):
 class DocumentFileDetachedSignatureDownloadView(SingleObjectDownloadView):
     object_permission = permission_document_file_signature_download
     pk_url_kwarg = 'signature_id'
+    view_icon = icon_document_file_signature_detached_download
 
     def get_download_file_object(self):
         return self.object.signature_file
@@ -230,6 +248,7 @@ class DocumentFileDetachedSignatureUploadView(
     external_object_queryset = DocumentFile.valid.all()
     fields = ('signature_file',)
     model = DetachedSignature
+    view_icon = icon_document_file_signature_detached_upload
 
     def get_extra_context(self):
         return {
@@ -257,6 +276,7 @@ class DocumentFileSignatureDetailView(SingleObjectDetailView):
     form_class = DocumentFileSignatureDetailForm
     object_permission = permission_document_file_signature_view
     pk_url_kwarg = 'signature_id'
+    view_icon = icon_document_file_signature_detail
 
     def get_extra_context(self):
         return {
@@ -282,6 +302,7 @@ class DocumentFileSignatureListView(
     external_object_permission = permission_document_file_signature_view
     external_object_pk_url_kwarg = 'document_file_id'
     external_object_queryset = DocumentFile.valid.all()
+    view_icon = icon_document_file_signature_list
 
     def get_extra_context(self):
         return {
@@ -332,16 +353,18 @@ class DocumentFileSignatureListView(
 class AllDocumentSignatureRefreshView(ConfirmView):
     extra_context = {
         'message': _(
-            'On large databases this operation may take some time to execute.'
+            'On large databases this operation may take some time '
+            'to execute.'
         ), 'title': _('Refresh all signatures information?'),
     }
+    view_icon = icon_document_file_all_signature_refresh
     view_permission = permission_document_file_signature_verify
 
     def get_post_action_redirect(self):
         return reverse(viewname='common:tools_list')
 
     def view_action(self):
-        task_refresh_signature_information.delay()
+        task_refresh_signature_information.apply_async()
         messages.success(
             message=_('Signature information refresh queued successfully.'),
             request=self.request
@@ -351,16 +374,18 @@ class AllDocumentSignatureRefreshView(ConfirmView):
 class AllDocumentSignatureVerifyView(ConfirmView):
     extra_context = {
         'message': _(
-            'On large databases this operation may take some time to execute.'
+            'On large databases this operation may take some time to '
+            'execute.'
         ), 'title': _('Verify all document for signatures?'),
     }
+    view_icon = icon_document_file_all_signature_verify
     view_permission = permission_document_file_signature_verify
 
     def get_post_action_redirect(self):
         return reverse(viewname='common:tools_list')
 
     def view_action(self):
-        task_verify_missing_embedded_signature.delay()
+        task_verify_missing_embedded_signature.apply_async()
         messages.success(
             message=_('Signature verification queued successfully.'),
             request=self.request
