@@ -1,5 +1,6 @@
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 
+from ..events import event_workflow_instance_transitioned
 from ..literals import WIDGET_CLASS_TEXTAREA
 from ..permissions import (
     permission_workflow_instance_transition, permission_workflow_template_view
@@ -25,7 +26,7 @@ class WorkflowInstanceTransitionViewTestCase(
         self._create_test_workflow_template_state()
         self._create_test_workflow_template_transition()
         self._create_test_document_stub()
-        self._test_workflow_instance = self.test_document.workflows.first()
+        self._test_workflow_instance = self._test_document.workflows.first()
 
     def test_document_workflow_instance_list_view_no_permission(self):
         self._clear_events()
@@ -38,7 +39,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_document_workflow_instance_list_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_template_view
         )
 
@@ -69,7 +70,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_document_workflow_instance_list_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_template_view
         )
         self.grant_access(
@@ -90,7 +91,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_trashed_document_workflow_instance_list_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_template_view
         )
         self.grant_access(
@@ -98,7 +99,7 @@ class WorkflowInstanceTransitionViewTestCase(
             permission=permission_workflow_template_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -119,7 +120,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_detail_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_template_view
         )
 
@@ -147,7 +148,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_detail_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_template_view
         )
         self.grant_access(
@@ -168,7 +169,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_trashed_document_workflow_instance_detail_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_template_view
         )
         self.grant_access(
@@ -176,7 +177,7 @@ class WorkflowInstanceTransitionViewTestCase(
             permission=permission_workflow_template_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -202,7 +203,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_transition_selection_get_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
 
@@ -210,7 +211,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
         response = self._request_test_workflow_instance_transition_selection_get_view()
         self.assertContains(
-            response=response, text=str(self.test_document), status_code=200
+            response=response, text=str(self._test_document), status_code=200
         )
         self.assertNotContains(
             response=response,
@@ -247,7 +248,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_transition_selection_get_view_with_document_and_transition_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -259,7 +260,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
         response = self._request_test_workflow_instance_transition_selection_get_view()
         self.assertContains(
-            response=response, text=str(self.test_document), status_code=200
+            response=response, text=str(self._test_document), status_code=200
         )
         self.assertContains(
             response=response,
@@ -296,7 +297,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_transition_selection_get_view_with_document_and_workflow_template_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -308,7 +309,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
         response = self._request_test_workflow_instance_transition_selection_get_view()
         self.assertContains(
-            response=response, text=str(self.test_document), status_code=200
+            response=response, text=str(self._test_document), status_code=200
         )
         self.assertContains(
             response=response,
@@ -326,7 +327,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_trashed_document_workflow_instance_transition_selection_get_view_with_document_and_workflow_template_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -334,7 +335,7 @@ class WorkflowInstanceTransitionViewTestCase(
             permission=permission_workflow_instance_transition
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -365,7 +366,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_transition_selection_post_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
 
@@ -384,7 +385,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_transition_selection_post_view_with_document_and_transition_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -426,7 +427,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_transition_selection_post_view_with_document_and_workflow_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -449,7 +450,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_trashed_document_workflow_instance_transition_selection_post_view_with_document_and_workflow_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -457,7 +458,7 @@ class WorkflowInstanceTransitionViewTestCase(
             permission=permission_workflow_instance_transition
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -488,7 +489,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_transition_execute_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
 
@@ -526,7 +527,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_transition_execute_view_with_document_and_transition_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -545,7 +546,16 @@ class WorkflowInstanceTransitionViewTestCase(
         )
 
         events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
+        self.assertEqual(events.count(), 1)
+
+        self.assertEqual(events[0].action_object, self._test_document)
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(
+            events[0].target, self._test_document.workflows.first()
+        )
+        self.assertEqual(
+            events[0].verb, event_workflow_instance_transitioned.id
+        )
 
     def test_workflow_instance_transition_execute_view_with_workflow_access(self):
         self.grant_access(
@@ -568,7 +578,7 @@ class WorkflowInstanceTransitionViewTestCase(
 
     def test_workflow_instance_transition_execute_view_with_document_and_workflow_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -587,11 +597,20 @@ class WorkflowInstanceTransitionViewTestCase(
         )
 
         events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
+        self.assertEqual(events.count(), 1)
+
+        self.assertEqual(events[0].action_object, self._test_document)
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(
+            events[0].target, self._test_document.workflows.first()
+        )
+        self.assertEqual(
+            events[0].verb, event_workflow_instance_transitioned.id
+        )
 
     def test_trashed_document_workflow_instance_transition_execute_view_with_document_and_workflow_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -599,7 +618,7 @@ class WorkflowInstanceTransitionViewTestCase(
             permission=permission_workflow_instance_transition
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -634,11 +653,11 @@ class WorkflowInstanceTransitionFieldViewTestCase(
         )
         self._create_test_document_stub()
 
-        self._test_workflow_instance = self.test_document.workflows.first()
+        self._test_workflow_instance = self._test_document.workflows.first()
 
     def test_workflow_instance_transition_text_area_widget_execute_view_with_document_and_transition_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -657,11 +676,20 @@ class WorkflowInstanceTransitionFieldViewTestCase(
         )
 
         events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
+        self.assertEqual(events.count(), 1)
+
+        self.assertEqual(events[0].action_object, self._test_document)
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(
+            events[0].target, self._test_document.workflows.first()
+        )
+        self.assertEqual(
+            events[0].verb, event_workflow_instance_transitioned.id
+        )
 
     def test_trashed_document_workflow_instance_transition_text_area_widget_execute_view_with_document_and_transition_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_workflow_instance_transition
         )
         self.grant_access(
@@ -669,7 +697,7 @@ class WorkflowInstanceTransitionFieldViewTestCase(
             permission=permission_workflow_instance_transition
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
