@@ -6,4 +6,4 @@ from .mixins.workflow_template_mixins import WorkflowTemplateTestMixin
 class WorkflowModelTestCase(WorkflowTemplateTestMixin, BaseTestCase):
     def test_workflow_template_preview(self):
         self._create_test_workflow_template()
-        self.assertTrue(self.test_workflow_template.get_api_image_url())
+        self.assertTrue(self._test_workflow_template.get_api_image_url())
