@@ -30,15 +30,15 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         response = self._request_test_workflow_template_state_action_create_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_workflow_template.refresh_from_db()
-        self.assertEqual(self.test_workflow_template_state.actions.count(), 0)
+        self._test_workflow_template.refresh_from_db()
+        self.assertEqual(self._test_workflow_template_state.actions.count(), 0)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_workflow_template_state_action_create_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_workflow_template,
+            obj=self._test_workflow_template,
             permission=permission_workflow_template_edit
         )
 
@@ -47,16 +47,16 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         response = self._request_test_workflow_template_state_action_create_api_view()
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
-        self.test_workflow_template.refresh_from_db()
+        self._test_workflow_template.refresh_from_db()
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(
-            events[0].action_object, self.test_workflow_template_state_action
+            events[0].action_object, self._test_workflow_template_state_action
         )
-        self.assertEqual(events[0].target, self.test_workflow_template)
+        self.assertEqual(events[0].target, self._test_workflow_template)
         self.assertEqual(events[0].verb, event_workflow_template_edited.id)
 
     def test_workflow_template_state_action_delete_api_view_no_permission(self):
@@ -67,8 +67,8 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         response = self._request_test_workflow_template_state_action_delete_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_workflow_template.refresh_from_db()
-        self.assertEqual(self.test_workflow_template_state.actions.count(), 1)
+        self._test_workflow_template.refresh_from_db()
+        self.assertEqual(self._test_workflow_template_state.actions.count(), 1)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -77,7 +77,7 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         self._create_test_workflow_template_state_action()
 
         self.grant_access(
-            obj=self.test_workflow_template,
+            obj=self._test_workflow_template,
             permission=permission_workflow_template_edit
         )
 
@@ -86,15 +86,15 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         response = self._request_test_workflow_template_state_action_delete_api_view()
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
-        self.test_workflow_template.refresh_from_db()
-        self.assertEqual(self.test_workflow_template_state.actions.count(), 0)
+        self._test_workflow_template.refresh_from_db()
+        self.assertEqual(self._test_workflow_template_state.actions.count(), 0)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].action_object, None)
-        self.assertEqual(events[0].target, self.test_workflow_template)
+        self.assertEqual(events[0].target, self._test_workflow_template)
         self.assertEqual(events[0].verb, event_workflow_template_edited.id)
 
     def test_workflow_template_state_action_detail_api_view_no_permission(self):
@@ -113,7 +113,7 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         self._create_test_workflow_template_state_action()
 
         self.grant_access(
-            obj=self.test_workflow_template,
+            obj=self._test_workflow_template,
             permission=permission_workflow_template_view
         )
 
@@ -122,7 +122,7 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         response = self._request_test_workflow_template_state_action_detail_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
-            response.data['id'], self.test_workflow_template_state_action.pk
+            response.data['id'], self._test_workflow_template_state_action.pk
         )
 
         events = self._get_test_events()
@@ -143,7 +143,7 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         self._create_test_workflow_template_state_action()
 
         self.grant_access(
-            obj=self.test_workflow_template,
+            obj=self._test_workflow_template,
             permission=permission_workflow_template_view
         )
 
@@ -153,7 +153,7 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
             response.data['results'][0]['id'],
-            self.test_workflow_template_state_action.pk
+            self._test_workflow_template_state_action.pk
         )
 
         events = self._get_test_events()
@@ -162,16 +162,16 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
     def test_workflow_template_state_action_edit_api_view_via_patch_no_permission(self):
         self._create_test_workflow_template_state_action()
 
-        test_workflow_template_state_action_label = self.test_workflow_template_state_action.label
+        test_workflow_template_state_action_label = self._test_workflow_template_state_action.label
 
         self._clear_events()
 
         response = self._request_test_workflow_template_state_action_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_workflow_template_state_action.refresh_from_db()
+        self._test_workflow_template_state_action.refresh_from_db()
         self.assertEqual(
-            self.test_workflow_template_state_action.label,
+            self._test_workflow_template_state_action.label,
             test_workflow_template_state_action_label
         )
 
@@ -181,10 +181,10 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
     def test_workflow_template_state_action_edit_api_view_via_patch_with_access(self):
         self._create_test_workflow_template_state_action()
 
-        test_workflow_template_state_action_label = self.test_workflow_template_state_action.label
+        test_workflow_template_state_action_label = self._test_workflow_template_state_action.label
 
         self.grant_access(
-            obj=self.test_workflow_template,
+            obj=self._test_workflow_template,
             permission=permission_workflow_template_edit
         )
 
@@ -193,9 +193,9 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         response = self._request_test_workflow_template_state_action_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_workflow_template_state_action.refresh_from_db()
+        self._test_workflow_template_state_action.refresh_from_db()
         self.assertNotEqual(
-            self.test_workflow_template_state_action.label,
+            self._test_workflow_template_state_action.label,
             test_workflow_template_state_action_label
         )
 
@@ -204,24 +204,24 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(
-            events[0].action_object, self.test_workflow_template_state_action
+            events[0].action_object, self._test_workflow_template_state_action
         )
-        self.assertEqual(events[0].target, self.test_workflow_template)
+        self.assertEqual(events[0].target, self._test_workflow_template)
         self.assertEqual(events[0].verb, event_workflow_template_edited.id)
 
     def test_workflow_template_state_action_edit_api_view_via_put_no_permission(self):
         self._create_test_workflow_template_state_action()
 
-        test_workflow_template_state_action_label = self.test_workflow_template_state_action.label
+        test_workflow_template_state_action_label = self._test_workflow_template_state_action.label
 
         self._clear_events()
 
         response = self._request_test_workflow_template_state_action_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_workflow_template_state_action.refresh_from_db()
+        self._test_workflow_template_state_action.refresh_from_db()
         self.assertEqual(
-            self.test_workflow_template_state_action.label,
+            self._test_workflow_template_state_action.label,
             test_workflow_template_state_action_label
         )
 
@@ -231,10 +231,10 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
     def test_workflow_template_state_action_edit_api_view_via_put_with_access(self):
         self._create_test_workflow_template_state_action()
 
-        test_workflow_template_state_action_label = self.test_workflow_template_state_action.label
+        test_workflow_template_state_action_label = self._test_workflow_template_state_action.label
 
         self.grant_access(
-            obj=self.test_workflow_template,
+            obj=self._test_workflow_template,
             permission=permission_workflow_template_edit
         )
 
@@ -243,9 +243,9 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
         response = self._request_test_workflow_template_state_action_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_workflow_template_state_action.refresh_from_db()
+        self._test_workflow_template_state_action.refresh_from_db()
         self.assertNotEqual(
-            self.test_workflow_template_state_action.label,
+            self._test_workflow_template_state_action.label,
             test_workflow_template_state_action_label
         )
 
@@ -254,7 +254,7 @@ class WorkflowTemplateStateActionsAPIViewTestCase(
 
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(
-            events[0].action_object, self.test_workflow_template_state_action
+            events[0].action_object, self._test_workflow_template_state_action
         )
-        self.assertEqual(events[0].target, self.test_workflow_template)
+        self.assertEqual(events[0].target, self._test_workflow_template)
         self.assertEqual(events[0].verb, event_workflow_template_edited.id)
