@@ -3,7 +3,7 @@ import pycountry
 from django.db import migrations
 
 
-def operation_change_bibliographic_to_terminology(apps, schema_editor):
+def code_change_bibliographic_to_terminology(apps, schema_editor):
     Document = apps.get_model(app_label='documents', model_name='Document')
 
     for document in Document.objects.using(alias=schema_editor.connection.alias).all():
@@ -23,9 +23,9 @@ def operation_change_bibliographic_to_terminology(apps, schema_editor):
 
 class Migration(migrations.Migration):
     dependencies = [
-        ('documents', '0024_auto_20150715_0714'),
+        ('documents', '0024_auto_20150715_0714')
     ]
 
     operations = [
-        migrations.RunPython(code=operation_change_bibliographic_to_terminology),
+        migrations.RunPython(code=code_change_bibliographic_to_terminology)
     ]
