@@ -3,7 +3,7 @@ from django.utils.translation import ugettext_lazy as _
 from mayan.apps.rest_api import serializers
 from mayan.apps.rest_api.relations import MultiKwargHyperlinkedIdentityField
 
-from ..literals import DOCUMENT_FILE_ACTION_PAGE_CHOICES
+from ..classes import DocumentFileAction
 from ..models.document_file_models import DocumentFile
 from ..models.document_file_page_models import DocumentFilePage
 
@@ -70,7 +70,7 @@ class DocumentFilePageSerializer(serializers.HyperlinkedModelSerializer):
 
 class DocumentFileSerializer(serializers.HyperlinkedModelSerializer):
     action = serializers.ChoiceField(
-        choices=DOCUMENT_FILE_ACTION_PAGE_CHOICES, write_only=True
+        choices=DocumentFileAction.get_choices(), write_only=True
     )
     document_url = serializers.HyperlinkedIdentityField(
         lookup_field='document_id',
@@ -108,7 +108,6 @@ class DocumentFileSerializer(serializers.HyperlinkedModelSerializer):
         view_name='rest_api:documentfilepage-list'
     )
     pages_first = DocumentFilePageSerializer(many=False, read_only=True)
-    size = serializers.SerializerMethodField()
     url = MultiKwargHyperlinkedIdentityField(
         view_kwargs=(
             {
@@ -140,6 +139,3 @@ class DocumentFileSerializer(serializers.HyperlinkedModelSerializer):
             'encoding', 'file', 'id', 'mimetype', 'page_list_url',
             'pages_first', 'size', 'timestamp', 'url'
         )
-
-    def get_size(self, instance):
-        return instance.size
