@@ -13,6 +13,13 @@ from .document_type_serializers import DocumentTypeSerializer
 from .document_version_serializers import DocumentVersionSerializer
 
 
+class DocumentFileActionSerializer(serializers.Serializer):
+    id = serializers.CharField(
+        label=_('ID'), read_only=True, source='backend_id'
+    )
+    label = serializers.CharField(label=_('Label'), read_only=True)
+
+
 class DocumentSerializer(serializers.HyperlinkedModelSerializer):
     document_type = DocumentTypeSerializer(read_only=True)
     document_type_id = serializers.IntegerField(
