@@ -41,7 +41,7 @@ class DocumentAPIViewTestCase(
 
     def test_document_create_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_create
         )
 
@@ -59,9 +59,9 @@ class DocumentAPIViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_created.id)
 
     def test_document_change_type_api_view_no_permission(self):
@@ -69,15 +69,15 @@ class DocumentAPIViewTestCase(
 
         self._create_test_document_type()
 
-        document_type = self.test_document.document_type
+        document_type = self._test_document.document_type
 
         self._clear_events()
 
         response = self._request_test_document_change_type_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.document_type, document_type)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.document_type, document_type)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -86,51 +86,51 @@ class DocumentAPIViewTestCase(
         self._create_test_document_stub()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_properties_edit
         )
         self._create_test_document_type()
 
-        document_type = self.test_document.document_type
+        document_type = self._test_document.document_type
 
         self._clear_events()
 
         response = self._request_test_document_change_type_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document.refresh_from_db()
-        self.assertNotEqual(self.test_document.document_type, document_type)
+        self._test_document.refresh_from_db()
+        self.assertNotEqual(self._test_document.document_type, document_type)
 
         events = self._get_test_events()
         # Only the change event, should not have an event for the first
         # .save() method call.
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_types[1])
+        self.assertEqual(events[0].action_object, self._test_document_types[1])
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_type_changed.id)
 
     def test_trashed_document_change_type_api_view_with_access(self):
         self._create_test_document_stub()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_properties_edit
         )
         self._create_test_document_type()
 
-        document_type = self.test_document.document_type
+        document_type = self._test_document.document_type
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_change_type_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.document_type, document_type)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.document_type, document_type)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -150,7 +150,7 @@ class DocumentAPIViewTestCase(
         self._create_test_document_stub()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_view
         )
 
@@ -160,7 +160,7 @@ class DocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
         self.assertEqual(
-            response.data['id'], self.test_document.pk
+            response.data['id'], self._test_document.pk
         )
 
         events = self._get_test_events()
@@ -170,11 +170,11 @@ class DocumentAPIViewTestCase(
         self._create_test_document_stub()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -187,16 +187,16 @@ class DocumentAPIViewTestCase(
     def test_document_edit_via_patch_api_view_no_permission(self):
         self._create_test_document_stub()
 
-        document_description = self.test_document.description
+        document_description = self._test_document.description
 
         self._clear_events()
 
         response = self._request_test_document_edit_via_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.description, document_description
+            self._test_document.description, document_description
         )
 
         events = self._get_test_events()
@@ -205,10 +205,10 @@ class DocumentAPIViewTestCase(
     def test_document_edit_via_patch_api_view_with_access(self):
         self._create_test_document_stub()
 
-        document_description = self.test_document.description
+        document_description = self._test_document.description
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_properties_edit
         )
 
@@ -217,9 +217,9 @@ class DocumentAPIViewTestCase(
         response = self._request_test_document_edit_via_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertNotEqual(
-            self.test_document.description, document_description
+            self._test_document.description, document_description
         )
 
         events = self._get_test_events()
@@ -227,29 +227,29 @@ class DocumentAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_edited.id)
 
     def test_trashed_document_edit_via_patch_api_view_with_access(self):
         self._create_test_document_stub()
 
-        document_description = self.test_document.description
+        document_description = self._test_document.description
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_properties_edit
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_edit_via_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.description, document_description
+            self._test_document.description, document_description
         )
 
         events = self._get_test_events()
@@ -258,16 +258,16 @@ class DocumentAPIViewTestCase(
     def test_document_edit_via_put_api_view_no_permission(self):
         self._create_test_document_stub()
 
-        document_description = self.test_document.description
+        document_description = self._test_document.description
 
         self._clear_events()
 
         response = self._request_test_document_edit_via_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.description, document_description
+            self._test_document.description, document_description
         )
 
         events = self._get_test_events()
@@ -276,10 +276,10 @@ class DocumentAPIViewTestCase(
     def test_document_edit_via_put_api_view_with_access(self):
         self._create_test_document_stub()
 
-        document_description = self.test_document.description
+        document_description = self._test_document.description
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_properties_edit
         )
 
@@ -288,9 +288,9 @@ class DocumentAPIViewTestCase(
         response = self._request_test_document_edit_via_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertNotEqual(
-            self.test_document.description, document_description
+            self._test_document.description, document_description
         )
 
         events = self._get_test_events()
@@ -298,29 +298,29 @@ class DocumentAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_edited.id)
 
     def test_trashed_document_edit_via_put_api_view_with_access(self):
         self._create_test_document_stub()
 
-        document_description = self.test_document.description
+        document_description = self._test_document.description
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_properties_edit
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_edit_via_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.description, document_description
+            self._test_document.description, document_description
         )
 
         events = self._get_test_events()
@@ -343,7 +343,7 @@ class DocumentAPIViewTestCase(
         self._create_test_document_stub()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         self._clear_events()
@@ -352,7 +352,7 @@ class DocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
         self.assertEqual(
-            response.data['results'][0]['id'], self.test_document.pk
+            response.data['results'][0]['id'], self._test_document.pk
         )
 
         events = self._get_test_events()
@@ -362,10 +362,10 @@ class DocumentAPIViewTestCase(
         self._create_test_document_stub()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -393,7 +393,7 @@ class DocumentAPIViewTestCase(
 
     def test_document_upload_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
 
         document_count = Document.objects.count()
@@ -407,21 +407,21 @@ class DocumentAPIViewTestCase(
             Document.objects.count(), document_count + 1
         )
 
-        self.assertEqual(self.test_document.pk, response.data['id'])
+        self.assertEqual(self._test_document.pk, response.data['id'])
         self.assertEqual(
-            self.test_document.label, self.test_document.file_latest.filename
+            self._test_document.label, self._test_document.file_latest.filename
         )
-        self.assertEqual(self.test_document.pages.count(), 1)
+        self.assertEqual(self._test_document.pages.count(), 1)
 
-        self.assertEqual(self.test_document.files.count(), 1)
-        self.assertEqual(self.test_document.file_latest.exists(), True)
-        self.assertEqual(self.test_document.file_latest.size, 17436)
+        self.assertEqual(self._test_document.files.count(), 1)
+        self.assertEqual(self._test_document.file_latest.exists(), True)
+        self.assertEqual(self._test_document.file_latest.size, 17436)
         self.assertEqual(
-            self.test_document.file_latest.mimetype, 'image/png'
+            self._test_document.file_latest.mimetype, 'image/png'
         )
-        self.assertEqual(self.test_document.file_latest.encoding, 'binary')
+        self.assertEqual(self._test_document.file_latest.encoding, 'binary')
         self.assertEqual(
-            self.test_document.file_latest.checksum,
+            self._test_document.file_latest.checksum,
             'efa10e6cc21f83078aaa94d5cbe51de67b51af706143bafc7fd6d4c02124879a'
         )
 
@@ -430,30 +430,30 @@ class DocumentAPIViewTestCase(
 
         # Document created
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_created.id)
 
         # Document file created
 
-        self.assertEqual(events[1].action_object, self.test_document)
+        self.assertEqual(events[1].action_object, self._test_document)
         self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(events[1].target, self.test_document.file_latest)
+        self.assertEqual(events[1].target, self._test_document.file_latest)
         self.assertEqual(events[1].verb, event_document_file_created.id)
 
         # Document file edited (MIME type, page count update)
 
-        self.assertEqual(events[2].action_object, self.test_document)
+        self.assertEqual(events[2].action_object, self._test_document)
         self.assertEqual(events[2].actor, self._test_case_user)
-        self.assertEqual(events[2].target, self.test_document.file_latest)
+        self.assertEqual(events[2].target, self._test_document.file_latest)
         self.assertEqual(events[2].verb, event_document_file_edited.id)
 
         # Document version created
 
-        self.assertEqual(events[3].action_object, self.test_document)
+        self.assertEqual(events[3].action_object, self._test_document)
         self.assertEqual(events[3].actor, self._test_case_user)
-        self.assertEqual(events[3].target, self.test_document.version_active)
+        self.assertEqual(events[3].target, self._test_document.version_active)
         self.assertEqual(events[3].verb, event_document_version_created.id)
 
         # Document version page created
@@ -462,10 +462,10 @@ class DocumentAPIViewTestCase(
             events[4].actor, self._test_case_user
         )
         self.assertEqual(
-            events[4].action_object, self.test_document.version_active
+            events[4].action_object, self._test_document.version_active
         )
         self.assertEqual(
-            events[4].target, self.test_document.version_active.pages.first()
+            events[4].target, self._test_document.version_active.pages.first()
         )
         self.assertEqual(
             events[4].verb, event_document_version_page_created.id
