@@ -13,25 +13,25 @@ class DocumentFilePageViewTestCase(
     DocumentFilePageViewTestMixin, GenericDocumentViewTestCase
 ):
     def test_document_file_page_count_update_view_no_permission(self):
-        self.test_document_file.pages.all().delete()
-        page_count = self.test_document_file.pages.count()
+        self._test_document_file.pages.all().delete()
+        page_count = self._test_document_file.pages.count()
 
         self._clear_events()
 
         response = self._request_test_document_file_page_count_update_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertEqual(self.test_document_file.pages.count(), page_count)
+        self.assertEqual(self._test_document_file.pages.count(), page_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_page_count_update_view_with_access(self):
-        self.test_document_file.pages.all().delete()
-        page_count = self.test_document_file.pages.count()
+        self._test_document_file.pages.all().delete()
+        page_count = self._test_document_file.pages.count()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_tools
+            obj=self._test_document, permission=permission_document_file_tools
         )
 
         self._clear_events()
@@ -40,57 +40,57 @@ class DocumentFilePageViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(
-            self.test_document_file.pages.count(), page_count + 1
+            self._test_document_file.pages.count(), page_count + 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(events[0].target, self._test_document_file)
         self.assertEqual(events[0].verb, event_document_file_edited.id)
 
     def test_trashed_document_file_page_count_update_view_with_access(self):
-        self.test_document_file.pages.all().delete()
-        page_count = self.test_document_file.pages.count()
+        self._test_document_file.pages.all().delete()
+        page_count = self._test_document_file.pages.count()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_tools
+            obj=self._test_document, permission=permission_document_file_tools
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_file_page_count_update_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertEqual(self.test_document_file.pages.count(), page_count)
+        self.assertEqual(self._test_document_file.pages.count(), page_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_multiple_page_count_update_view_no_permission(self):
-        self.test_document_file.pages.all().delete()
-        page_count = self.test_document_file.pages.count()
+        self._test_document_file.pages.all().delete()
+        page_count = self._test_document_file.pages.count()
 
         self._clear_events()
 
         response = self._request_test_document_file_multiple_page_count_update_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertEqual(self.test_document_file.pages.count(), page_count)
+        self.assertEqual(self._test_document_file.pages.count(), page_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_multiple_page_count_update_view_with_access(self):
-        self.test_document_file.pages.all().delete()
-        page_count = self.test_document_file.pages.count()
+        self._test_document_file.pages.all().delete()
+        page_count = self._test_document_file.pages.count()
 
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_tools
         )
 
@@ -100,34 +100,34 @@ class DocumentFilePageViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(
-            self.test_document_file.pages.count(), page_count + 1
+            self._test_document_file.pages.count(), page_count + 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(events[0].target, self._test_document_file)
         self.assertEqual(events[0].verb, event_document_file_edited.id)
 
     def test_trashed_document_file_multiple_page_count_update_view_with_access(self):
-        self.test_document_file.pages.all().delete()
-        page_count = self.test_document_file.pages.count()
+        self._test_document_file.pages.all().delete()
+        page_count = self._test_document_file.pages.count()
 
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_tools
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_file_multiple_page_count_update_view()
         self.assertEqual(response.status_code, 404)
 
-        self.assertEqual(self.test_document_file.pages.count(), page_count)
+        self.assertEqual(self._test_document_file.pages.count(), page_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -143,7 +143,7 @@ class DocumentFilePageViewTestCase(
 
     def test_document_file_page_list_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
         self._clear_events()
@@ -151,7 +151,7 @@ class DocumentFilePageViewTestCase(
         response = self._request_test_document_file_page_list_view()
         self.assertContains(
             response=response, status_code=200,
-            text=str(self.test_document_file)
+            text=str(self._test_document_file)
         )
 
         events = self._get_test_events()
@@ -159,10 +159,10 @@ class DocumentFilePageViewTestCase(
 
     def test_trashed_document_file_page_list_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -183,7 +183,7 @@ class DocumentFilePageViewTestCase(
 
     def test_document_file_page_rotate_left_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
         self._clear_events()
@@ -196,10 +196,10 @@ class DocumentFilePageViewTestCase(
 
     def test_trashed_document_file_page_rotate_left_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -220,7 +220,7 @@ class DocumentFilePageViewTestCase(
 
     def test_document_file_page_rotate_right_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
         self._clear_events()
@@ -233,10 +233,10 @@ class DocumentFilePageViewTestCase(
 
     def test_trashed_document_file_page_rotate_right_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -250,7 +250,7 @@ class DocumentFilePageViewTestCase(
         self._clear_events()
 
         response = self._request_test_document_file_page_view(
-            document_file_page=self.test_document_file.pages.first()
+            document_file_page=self._test_document_file.pages.first()
         )
         self.assertEqual(response.status_code, 404)
 
@@ -259,17 +259,17 @@ class DocumentFilePageViewTestCase(
 
     def test_document_file_page_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
         self._clear_events()
 
         response = self._request_test_document_file_page_view(
-            document_file_page=self.test_document_file.pages.first()
+            document_file_page=self._test_document_file.pages.first()
         )
         self.assertContains(
             response=response, status_code=200, text=force_text(
-                s=self.test_document_file.pages.first()
+                s=self._test_document_file.pages.first()
             )
         )
 
@@ -278,15 +278,15 @@ class DocumentFilePageViewTestCase(
 
     def test_trashed_document_file_page_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_file_page_view(
-            document_file_page=self.test_document_file.pages.first()
+            document_file_page=self._test_document_file.pages.first()
         )
         self.assertEqual(response.status_code, 404)
 
@@ -304,7 +304,7 @@ class DocumentFilePageViewTestCase(
 
     def test_document_file_page_zoom_in_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
         self._clear_events()
@@ -317,10 +317,10 @@ class DocumentFilePageViewTestCase(
 
     def test_trashed_document_file_page_zoom_in_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -341,7 +341,7 @@ class DocumentFilePageViewTestCase(
 
     def test_document_file_page_zoom_out_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
         self._clear_events()
@@ -354,10 +354,10 @@ class DocumentFilePageViewTestCase(
 
     def test_trashed_document_file_page_zoom_out_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_view
+            obj=self._test_document, permission=permission_document_file_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
