@@ -3,7 +3,7 @@ from mayan.apps.converter.permissions import (
     permission_transformation_delete, permission_transformation_edit
 )
 from mayan.apps.converter.tests.mixins import LayerTestMixin
-from mayan.apps.documents.tests.literals import TEST_MULTI_PAGE_TIFF
+from mayan.apps.documents.tests.literals import TEST_FILE_MULTI_PAGE_TIFF_FILENAME
 from mayan.apps.file_caching.events import event_cache_partition_purged
 from mayan.apps.file_caching.models import CachePartitionFile
 from mayan.apps.file_caching.permissions import permission_cache_partition_purge
@@ -31,10 +31,10 @@ class DocumentFileViewTestCase(
     GenericDocumentViewTestCase
 ):
     def test_document_file_delete_no_permission(self):
-        first_file = self.test_document.file_latest
-        self._upload_new_file()
+        first_file = self._test_document.file_latest
+        self._upload_test_document_file()
 
-        test_document_file_count = self.test_document.files.count()
+        test_document_file_count = self._test_document.files.count()
 
         self._clear_events()
 
@@ -44,22 +44,22 @@ class DocumentFileViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(
-            self.test_document.files.count(), test_document_file_count
+            self._test_document.files.count(), test_document_file_count
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_delete_with_access(self):
-        first_file = self.test_document.file_latest
-        self._upload_new_file()
+        first_file = self._test_document.file_latest
+        self._upload_test_document_file()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_delete
         )
 
-        test_document_file_count = self.test_document.files.count()
+        test_document_file_count = self._test_document.files.count()
 
         self._clear_events()
 
@@ -69,7 +69,7 @@ class DocumentFileViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(
-            self.test_document.files.count(), test_document_file_count - 1
+            self._test_document.files.count(), test_document_file_count - 1
         )
 
         events = self._get_test_events()
@@ -77,21 +77,21 @@ class DocumentFileViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_file_deleted.id)
 
     def test_trashed_document_file_delete_with_access(self):
-        first_file = self.test_document.file_latest
-        self._upload_new_file()
+        first_file = self._test_document.file_latest
+        self._upload_test_document_file()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_delete
         )
 
-        test_document_file_count = self.test_document.files.count()
+        test_document_file_count = self._test_document.files.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -101,48 +101,48 @@ class DocumentFileViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(
-            self.test_document.files.count(), test_document_file_count
+            self._test_document.files.count(), test_document_file_count
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_file_delete_multiple_no_permission(self):
-        self._upload_new_file()
+    def test_document_file_multiple_delete_no_permission(self):
+        self._upload_test_document_file()
 
-        test_document_file_count = self.test_document.files.count()
+        test_document_file_count = self._test_document.files.count()
 
         self._clear_events()
 
-        response = self._request_test_document_file_delete_multiple_view()
+        response = self._request_test_document_file_multiple_delete_view()
 
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(
-            self.test_document.files.count(), test_document_file_count
+            self._test_document.files.count(), test_document_file_count
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_file_delete_multiple_with_access(self):
-        self._upload_new_file()
+    def test_document_file_multiple_delete_with_access(self):
+        self._upload_test_document_file()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_delete
         )
 
-        test_document_file_count = self.test_document.files.count()
+        test_document_file_count = self._test_document.files.count()
 
         self._clear_events()
 
-        response = self._request_test_document_file_delete_multiple_view()
+        response = self._request_test_document_file_multiple_delete_view()
 
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(
-            self.test_document.files.count(), test_document_file_count - 1
+            self._test_document.files.count(), test_document_file_count - 1
         )
 
         events = self._get_test_events()
@@ -150,20 +150,20 @@ class DocumentFileViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_file_deleted.id)
 
     def test_document_file_edit_view_no_permission(self):
-        document_file_comment = self.test_document_file.comment
+        document_file_comment = self._test_document_file.comment
 
         self._clear_events()
 
         response = self._request_test_document_file_edit_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_file.refresh_from_db()
+        self._test_document_file.refresh_from_db()
         self.assertEqual(
-            self.test_document_file.comment,
+            self._test_document_file.comment,
             document_file_comment
         )
 
@@ -172,59 +172,59 @@ class DocumentFileViewTestCase(
 
     def test_document_file_edit_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_edit
         )
 
-        document_file_comment = self.test_document_file.comment
-        document_file_filename = self.test_document_file.filename
+        document_file_comment = self._test_document_file.comment
+        document_file_filename = self._test_document_file.filename
 
         self._clear_events()
 
         response = self._request_test_document_file_edit_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_document_file.refresh_from_db()
+        self._test_document_file.refresh_from_db()
         self.assertNotEqual(
-            self.test_document_file.comment,
+            self._test_document_file.comment,
             document_file_comment
         )
         self.assertNotEqual(
-            self.test_document_file.filename,
+            self._test_document_file.filename,
             document_file_filename
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(events[0].target, self._test_document_file)
         self.assertEqual(events[0].verb, event_document_file_edited.id)
 
     def test_trashed_document_file_edit_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_edit
         )
 
-        document_file_comment = self.test_document_file.comment
-        document_file_filename = self.test_document_file.filename
+        document_file_comment = self._test_document_file.comment
+        document_file_filename = self._test_document_file.filename
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_file_edit_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_file.refresh_from_db()
+        self._test_document_file.refresh_from_db()
         self.assertEqual(
-            self.test_document_file.comment,
+            self._test_document_file.comment,
             document_file_comment
         )
         self.assertEqual(
-            self.test_document_file.filename,
+            self._test_document_file.filename,
             document_file_filename
         )
 
@@ -242,7 +242,7 @@ class DocumentFileViewTestCase(
 
     def test_document_file_list_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_view
         )
 
@@ -251,7 +251,7 @@ class DocumentFileViewTestCase(
         response = self._request_test_document_file_list_view()
         self.assertContains(
             response=response, status_code=200,
-            text=str(self.test_document_file)
+            text=str(self._test_document_file)
         )
 
         events = self._get_test_events()
@@ -259,11 +259,11 @@ class DocumentFileViewTestCase(
 
     def test_trashed_document_file_list_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -284,7 +284,7 @@ class DocumentFileViewTestCase(
 
     def test_document_file_print_form_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_print
         )
 
@@ -298,11 +298,11 @@ class DocumentFileViewTestCase(
 
     def test_trashed_document_file_print_form_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_print
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -323,7 +323,7 @@ class DocumentFileViewTestCase(
 
     def test_document_file_print_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_print
         )
 
@@ -337,11 +337,11 @@ class DocumentFileViewTestCase(
 
     def test_trashed_document_file_print_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_print
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_file_print_view()
@@ -361,7 +361,7 @@ class DocumentFileViewTestCase(
 
     def test_document_file_properties_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_view
         )
 
@@ -369,7 +369,7 @@ class DocumentFileViewTestCase(
 
         response = self._request_test_document_file_properties_view()
         self.assertContains(
-            response=response, text=self.test_document_file.filename,
+            response=response, text=self._test_document_file.filename,
             status_code=200
         )
 
@@ -378,11 +378,11 @@ class DocumentFileViewTestCase(
 
     def test_trashed_document_file_properties_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_file_properties_view()
@@ -408,11 +408,11 @@ class DocumentFileDownloadViewTestCase(
         # Set the expected_content_types for
         # common.tests.mixins.ContentTypeCheckMixin
         self.expected_content_types = (
-            self.test_document.file_latest.mimetype,
+            self._test_document.file_latest.mimetype,
         )
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_download
         )
 
@@ -421,28 +421,28 @@ class DocumentFileDownloadViewTestCase(
         response = self._request_test_document_file_download_view()
         self.assertEqual(response.status_code, 200)
 
-        with self.test_document.file_latest.open() as file_object:
+        with self._test_document.file_latest.open() as file_object:
             self.assert_download_response(
                 response=response, content=file_object.read(),
-                filename=self.test_document.file_latest.filename,
-                mime_type=self.test_document.file_latest.mimetype
+                filename=self._test_document.file_latest.filename,
+                mime_type=self._test_document.file_latest.mimetype
             )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_file)
+        self.assertEqual(events[0].target, self._test_document_file)
         self.assertEqual(events[0].verb, event_document_file_downloaded.id)
 
     def test_trashed_document_file_download_view_with_permission(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_file_download
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -457,13 +457,13 @@ class DocumentFileTransformationViewTestCase(
     LayerTestMixin, DocumentFileTransformationTestMixin,
     DocumentFileTransformationViewTestMixin, GenericDocumentViewTestCase
 ):
-    test_document_filename = TEST_MULTI_PAGE_TIFF
+    _test_document_filename = TEST_FILE_MULTI_PAGE_TIFF_FILENAME
 
     def test_document_file_transformations_clear_view_no_permission(self):
         self._create_document_file_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_file.pages.first()
+            obj=self._test_document_file.pages.first()
         ).count()
 
         self._clear_events()
@@ -473,7 +473,7 @@ class DocumentFileTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_file.pages.first()
+                obj=self._test_document_file.pages.first()
             ).count(), transformation_count
         )
 
@@ -484,11 +484,11 @@ class DocumentFileTransformationViewTestCase(
         self._create_document_file_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_file.pages.first()
+            obj=self._test_document_file.pages.first()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_transformation_delete
         )
 
@@ -499,7 +499,7 @@ class DocumentFileTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_file.pages.first()
+                obj=self._test_document_file.pages.first()
             ).count(), transformation_count - 1
         )
 
@@ -510,15 +510,15 @@ class DocumentFileTransformationViewTestCase(
         self._create_document_file_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_file.pages.first()
+            obj=self._test_document_file.pages.first()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_transformation_delete
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -527,7 +527,7 @@ class DocumentFileTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_file.pages.first()
+                obj=self._test_document_file.pages.first()
             ).count(), transformation_count
         )
 
@@ -538,7 +538,7 @@ class DocumentFileTransformationViewTestCase(
         self._create_document_file_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_file.pages.first()
+            obj=self._test_document_file.pages.first()
         ).count()
 
         self._clear_events()
@@ -548,7 +548,7 @@ class DocumentFileTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_file.pages.first()
+                obj=self._test_document_file.pages.first()
             ).count(), transformation_count
         )
 
@@ -559,15 +559,15 @@ class DocumentFileTransformationViewTestCase(
         self._create_document_file_transformation()
 
         transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_file.pages.first()
+            obj=self._test_document_file.pages.first()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_document_file_view
         )
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_transformation_delete
         )
 
@@ -578,7 +578,7 @@ class DocumentFileTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_file.pages.first()
+                obj=self._test_document_file.pages.first()
             ).count(), transformation_count - 1,
         )
 
@@ -589,10 +589,10 @@ class DocumentFileTransformationViewTestCase(
         self._create_document_file_transformation()
 
         page_first_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_file.pages.first()
+            obj=self._test_document_file.pages.first()
         ).count()
         page_last_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_file.pages.last()
+            obj=self._test_document_file.pages.last()
         ).count()
 
         self._clear_events()
@@ -602,12 +602,12 @@ class DocumentFileTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_file.pages.first()
+                obj=self._test_document_file.pages.first()
             ).count(), page_first_transformation_count
         )
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_file.pages.last()
+                obj=self._test_document_file.pages.last()
             ).count(), page_last_transformation_count
         )
 
@@ -618,14 +618,14 @@ class DocumentFileTransformationViewTestCase(
         self._create_document_file_transformation()
 
         page_first_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_file.pages.first()
+            obj=self._test_document_file.pages.first()
         ).count()
         page_last_transformation_count = layer_saved_transformations.get_transformations_for(
-            obj=self.test_document_file.pages.last()
+            obj=self._test_document_file.pages.last()
         ).count()
 
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_transformation_edit
         )
 
@@ -636,12 +636,12 @@ class DocumentFileTransformationViewTestCase(
 
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_file.pages.first()
+                obj=self._test_document_file.pages.first()
             ).count(), page_first_transformation_count
         )
         self.assertEqual(
             layer_saved_transformations.get_transformations_for(
-                obj=self.test_document_file.pages.last()
+                obj=self._test_document_file.pages.last()
             ).count(), page_last_transformation_count + 1
         )
 
@@ -653,12 +653,12 @@ class DocumentFileCachePurgeViewTestCase(
     CachePartitionViewTestMixin, GenericDocumentViewTestCase
 ):
     def test_document_file_cache_purge_no_permission(self):
-        self.test_object = self.test_document_file
+        self._test_object = self._test_document_file
         self._inject_test_object_content_type()
 
-        self.test_document_file.file_pages.first().generate_image()
+        self._test_document_file.file_pages.first().generate_image()
 
-        test_document_file_cache_partitions = self.test_document_file.get_cache_partitions()
+        test_document_file_cache_partitions = self._test_document_file.get_cache_partitions()
 
         cache_partition_file_count = CachePartitionFile.objects.filter(
             partition__in=test_document_file_cache_partitions
@@ -679,17 +679,17 @@ class DocumentFileCachePurgeViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_file_cache_purge_with_access(self):
-        self.test_object = self.test_document_file
+        self._test_object = self._test_document_file
         self._inject_test_object_content_type()
 
         self.grant_access(
-            obj=self.test_document_file,
+            obj=self._test_document_file,
             permission=permission_cache_partition_purge
         )
 
-        self.test_document_file.file_pages.first().generate_image()
+        self._test_document_file.file_pages.first().generate_image()
 
-        test_document_file_cache_partitions = self.test_document_file.get_cache_partitions()
+        test_document_file_cache_partitions = self._test_document_file.get_cache_partitions()
 
         cache_partition_file_count = CachePartitionFile.objects.filter(
             partition__in=test_document_file_cache_partitions
@@ -697,7 +697,7 @@ class DocumentFileCachePurgeViewTestCase(
 
         self._clear_events()
 
-        cache_partitions = self.test_document_file.get_cache_partitions()
+        cache_partitions = self._test_document_file.get_cache_partitions()
 
         response = self._request_test_object_file_cache_partition_purge_view()
         self.assertEqual(response.status_code, 302)
@@ -711,12 +711,12 @@ class DocumentFileCachePurgeViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
-        self.assertEqual(events[0].action_object, self.test_document_file)
+        self.assertEqual(events[0].action_object, self._test_document_file)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, cache_partitions[0])
         self.assertEqual(events[0].verb, event_cache_partition_purged.id)
 
-        self.assertEqual(events[1].action_object, self.test_document_file)
+        self.assertEqual(events[1].action_object, self._test_document_file)
         self.assertEqual(events[1].actor, self._test_case_user)
         self.assertEqual(events[1].target, cache_partitions[1])
         self.assertEqual(events[1].verb, event_cache_partition_purged.id)
