@@ -8,9 +8,13 @@ from mayan.apps.rest_api.tests.base import (
 from mayan.apps.storage.events import event_download_file_created
 from mayan.apps.storage.models import DownloadFile
 
+from ..document_file_actions import (
+    DocumentFileActionAppendNewPages, DocumentFileActionNothing
+)
 from ..events import (
     event_document_version_created, event_document_version_deleted,
-    event_document_version_edited, event_document_version_exported
+    event_document_version_edited, event_document_version_exported,
+    event_document_version_page_created, event_document_version_page_deleted
 )
 from ..permissions import (
     permission_document_version_create, permission_document_version_delete,
@@ -19,17 +23,231 @@ from ..permissions import (
 )
 
 from .mixins.document_mixins import DocumentTestMixin
+from .mixins.document_file_mixins import DocumentFileTestMixin
 from .mixins.document_version_mixins import (
-    DocumentVersionAPIViewTestMixin, DocumentVersionTestMixin
+    DocumentVersionModificationAPIViewTestMixin, DocumentVersionAPIViewTestMixin,
+    DocumentVersionTestMixin
 )
 
 
+class DocumentVersionModificationAPIViewTestCase(
+    DocumentFileTestMixin, DocumentTestMixin,
+    DocumentVersionModificationAPIViewTestMixin, DocumentVersionTestMixin,
+    BaseAPITestCase
+):
+    def test_document_version_action_page_append_api_view_no_permission(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionNothing.backend_id
+        )
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_append_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count()
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_document_version_action_page_append_api_view_with_access(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionNothing.backend_id
+        )
+
+        self.grant_access(
+            obj=self._test_document_version,
+            permission=permission_document_version_edit
+        )
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_append_api_view()
+        self.assertEqual(response.status_code, status.HTTP_202_ACCEPTED)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count() + self._test_document_files[1].pages.count()
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 3)
+
+        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(events[0].target, self._test_document_version)
+        self.assertEqual(
+            events[0].verb, event_document_version_page_deleted.id
+        )
+
+        self.assertEqual(events[1].action_object, self._test_document_version)
+        self.assertEqual(events[1].actor, self._test_case_user)
+        self.assertEqual(
+            events[1].target, self._test_document_version.pages[0]
+        )
+        self.assertEqual(
+            events[1].verb, event_document_version_page_created.id
+        )
+        self.assertEqual(events[2].action_object, self._test_document_version)
+        self.assertEqual(events[2].actor, self._test_case_user)
+        self.assertEqual(
+            events[2].target, self._test_document_version.pages[1]
+        )
+        self.assertEqual(
+            events[2].verb, event_document_version_page_created.id
+        )
+
+    def test_trashed_document_version_action_page_append_api_view_with_access(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionNothing.backend_id
+        )
+
+        self.grant_access(
+            obj=self._test_document_version,
+            permission=permission_document_version_edit
+        )
+
+        self._test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_append_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count()
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_document_version_action_page_reset_api_view_no_permission(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionAppendNewPages.backend_id
+        )
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_reset_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count() + self._test_document_files[1].pages.count()
+        )
+
+        self.assertEqual(
+            self._test_document_version.pages.all()[0].content_object,
+            self._test_document_file_pages[0]
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_document_version_action_page_reset_api_view_with_access(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionAppendNewPages.backend_id
+        )
+
+        self.grant_access(
+            obj=self._test_document_version,
+            permission=permission_document_version_edit
+        )
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_reset_api_view()
+        self.assertEqual(response.status_code, status.HTTP_202_ACCEPTED)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count()
+        )
+
+        self.assertEqual(
+            self._test_document_version.pages.all()[0].content_object,
+            self._test_document_file_pages[1]
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 3)
+
+        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(events[0].target, self._test_document_version)
+        self.assertEqual(
+            events[0].verb, event_document_version_page_deleted.id
+        )
+
+        self.assertEqual(events[1].action_object, None)
+        self.assertEqual(events[1].actor, self._test_case_user)
+        self.assertEqual(events[1].target, self._test_document_version)
+        self.assertEqual(
+            events[1].verb, event_document_version_page_deleted.id
+        )
+
+        self.assertEqual(events[2].action_object, self._test_document_version)
+        self.assertEqual(events[2].actor, self._test_case_user)
+        self.assertEqual(
+            events[2].target, self._test_document_version.pages[0]
+        )
+        self.assertEqual(
+            events[2].verb, event_document_version_page_created.id
+        )
+
+    def test_trashed_document_version_action_page_reset_api_view_with_access(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionAppendNewPages.backend_id
+        )
+
+        self.grant_access(
+            obj=self._test_document_version,
+            permission=permission_document_version_edit
+        )
+
+        self._test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_reset_api_view()
+        self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count() + self._test_document_files[1].pages.count()
+        )
+
+        self.assertEqual(
+            self._test_document_version.pages.all()[0].content_object,
+            self._test_document_file_pages[0]
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+
 class DocumentVersionAPIViewTestCase(
     DocumentVersionAPIViewTestMixin, DocumentTestMixin,
     DocumentVersionTestMixin, BaseAPITestCase
 ):
     def test_document_version_create_api_view_no_permission(self):
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
         self._clear_events()
 
@@ -37,7 +255,7 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count
+            self._test_document.versions.count(), document_version_count
         )
 
         events = self._get_test_events()
@@ -45,11 +263,11 @@ class DocumentVersionAPIViewTestCase(
 
     def test_document_version_create_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_create
         )
 
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
         self._clear_events()
 
@@ -57,25 +275,25 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count + 1
+            self._test_document.versions.count(), document_version_count + 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(events[0].verb, event_document_version_created.id)
 
     def test_trashed_document_version_create_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_create
         )
 
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -83,14 +301,14 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count
+            self._test_document.versions.count(), document_version_count
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_version_delete_api_view_no_permission(self):
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
         self._clear_events()
 
@@ -98,7 +316,7 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count
+            self._test_document.versions.count(), document_version_count
         )
 
         events = self._get_test_events()
@@ -106,11 +324,11 @@ class DocumentVersionAPIViewTestCase(
 
     def test_document_version_delete_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_delete
         )
 
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
         self._clear_events()
 
@@ -118,25 +336,25 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count - 1
+            self._test_document.versions.count(), document_version_count - 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_version_deleted.id)
 
     def test_trashed_document_version_delete_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_delete
         )
 
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -144,7 +362,7 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count
+            self._test_document.versions.count(), document_version_count
         )
 
         events = self._get_test_events()
@@ -161,7 +379,7 @@ class DocumentVersionAPIViewTestCase(
 
     def test_document_version_detail_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
@@ -171,7 +389,7 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
         self.assertEqual(
-            response.data['id'], self.test_document.version_active.id
+            response.data['id'], self._test_document.version_active.id
         )
 
         events = self._get_test_events()
@@ -179,11 +397,11 @@ class DocumentVersionAPIViewTestCase(
 
     def test_trashed_document_version_detail_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -194,16 +412,16 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_version_edit_via_patch_api_view_no_permission(self):
-        document_version_comment = self.test_document.version_active.comment
+        document_version_comment = self._test_document.version_active.comment
 
         self._clear_events()
 
         response = self._request_test_document_version_edit_via_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.version_active.refresh_from_db()
+        self._test_document.version_active.refresh_from_db()
         self.assertEqual(
-            self.test_document.version_active.comment,
+            self._test_document.version_active.comment,
             document_version_comment
         )
 
@@ -212,49 +430,49 @@ class DocumentVersionAPIViewTestCase(
 
     def test_document_version_edit_via_patch_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_edit
         )
 
-        document_version_comment = self.test_document.version_active.comment
+        document_version_comment = self._test_document.version_active.comment
 
         self._clear_events()
 
         response = self._request_test_document_version_edit_via_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document.version_active.refresh_from_db()
+        self._test_document.version_active.refresh_from_db()
         self.assertNotEqual(
-            self.test_document.version_active.comment,
+            self._test_document.version_active.comment,
             document_version_comment
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(events[0].verb, event_document_version_edited.id)
 
     def test_trashed_document_version_edit_via_patch_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_edit
         )
 
-        document_version_comment = self.test_document.version_active.comment
+        document_version_comment = self._test_document.version_active.comment
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_version_edit_via_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.version_active.refresh_from_db()
+        self._test_document.version_active.refresh_from_db()
         self.assertEqual(
-            self.test_document.version_active.comment,
+            self._test_document.version_active.comment,
             document_version_comment
         )
 
@@ -262,16 +480,16 @@ class DocumentVersionAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_version_edit_via_put_api_view_no_permission(self):
-        document_version_comment = self.test_document.version_active.comment
+        document_version_comment = self._test_document.version_active.comment
 
         self._clear_events()
 
         response = self._request_test_document_version_edit_via_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.version_active.refresh_from_db()
+        self._test_document.version_active.refresh_from_db()
         self.assertEqual(
-            self.test_document.version_active.comment,
+            self._test_document.version_active.comment,
             document_version_comment
         )
 
@@ -280,48 +498,48 @@ class DocumentVersionAPIViewTestCase(
 
     def test_document_version_edit_via_put_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_edit
         )
 
-        document_version_comment = self.test_document.version_active.comment
+        document_version_comment = self._test_document.version_active.comment
 
         self._clear_events()
 
         response = self._request_test_document_version_edit_via_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document.version_active.refresh_from_db()
+        self._test_document.version_active.refresh_from_db()
         self.assertNotEqual(
-            self.test_document.version_active.comment,
+            self._test_document.version_active.comment,
             document_version_comment
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(events[0].verb, event_document_version_edited.id)
 
     def test_trashed_document_version_edit_via_put_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_edit
         )
 
-        document_version_comment = self.test_document.version_active.comment
+        document_version_comment = self._test_document.version_active.comment
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_version_edit_via_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document.version_active.refresh_from_db()
+        self._test_document.version_active.refresh_from_db()
         self.assertEqual(
-            self.test_document.version_active.comment,
+            self._test_document.version_active.comment,
             document_version_comment
         )
 
@@ -339,7 +557,7 @@ class DocumentVersionAPIViewTestCase(
 
     def test_document_version_list_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
@@ -350,7 +568,7 @@ class DocumentVersionAPIViewTestCase(
 
         self.assertEqual(
             response.data['results'][0]['id'],
-            self.test_document.version_active.id
+            self._test_document.version_active.id
         )
 
         events = self._get_test_events()
@@ -358,11 +576,11 @@ class DocumentVersionAPIViewTestCase(
 
     def test_trashed_document_version_list_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -398,7 +616,7 @@ class DocumentVersionExportAPIViewTestCase(
 
     def test_document_version_export_api_view_via_get_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_export
         )
         download_file_count = DownloadFile.objects.count()
@@ -421,13 +639,13 @@ class DocumentVersionExportAPIViewTestCase(
 
     def test_trashed_document_version_export_api_view_via_get_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_export
         )
         download_file_count = DownloadFile.objects.count()
         message_count = Message.objects.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -463,7 +681,7 @@ class DocumentVersionExportAPIViewTestCase(
 
     def test_document_version_export_api_view_via_post_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_export
         )
         download_file_count = DownloadFile.objects.count()
@@ -485,14 +703,14 @@ class DocumentVersionExportAPIViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 3)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, test_download_file)
         self.assertEqual(events[0].verb, event_download_file_created.id)
 
         self.assertEqual(events[1].action_object, test_download_file)
         self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(events[1].target, self.test_document_version)
+        self.assertEqual(events[1].target, self._test_document_version)
         self.assertEqual(events[1].verb, event_document_version_exported.id)
 
         self.assertEqual(events[2].action_object, None)
@@ -502,12 +720,12 @@ class DocumentVersionExportAPIViewTestCase(
 
     def test_trashed_document_version_export_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_export
         )
         download_file_count = DownloadFile.objects.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
