@@ -20,7 +20,7 @@ class DocumentVersionPageAPIViewTestCase(
     DocumentVersionPageAPIViewTestMixin, DocumentTestMixin, BaseAPITestCase
 ):
     def test_document_version_page_create_api_view_no_permission(self):
-        document_version_count_page = self.test_document.version_active.version_pages.count()
+        document_version_count_page = self._test_document.version_active.version_pages.count()
 
         self._clear_events()
 
@@ -28,7 +28,7 @@ class DocumentVersionPageAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.version_active.version_pages.count(),
+            self._test_document.version_active.version_pages.count(),
             document_version_count_page
         )
 
@@ -37,11 +37,11 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_document_version_page_create_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_count_page = self.test_document.version_active.version_pages.count()
+        document_version_count_page = self._test_document.version_active.version_pages.count()
 
         self._clear_events()
 
@@ -49,27 +49,27 @@ class DocumentVersionPageAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         self.assertEqual(
-            self.test_document.version_active.version_pages.count(),
+            self._test_document.version_active.version_pages.count(),
             document_version_count_page + 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version_page)
+        self.assertEqual(events[0].target, self._test_document_version_page)
         self.assertEqual(events[0].verb, event_document_version_page_created.id)
 
     def test_trashed_document_version_page_create_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_count_page = self.test_document.version_active.version_pages.count()
+        document_version_count_page = self._test_document.version_active.version_pages.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -77,7 +77,7 @@ class DocumentVersionPageAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.version_active.version_pages.count(),
+            self._test_document.version_active.version_pages.count(),
             document_version_count_page
         )
 
@@ -85,7 +85,7 @@ class DocumentVersionPageAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_version_page_delete_api_view_no_permission(self):
-        document_version_count_page = self.test_document.version_active.version_pages.count()
+        document_version_count_page = self._test_document.version_active.version_pages.count()
 
         self._clear_events()
 
@@ -93,7 +93,7 @@ class DocumentVersionPageAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.version_active.version_pages.count(),
+            self._test_document.version_active.version_pages.count(),
             document_version_count_page
         )
 
@@ -102,11 +102,11 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_document_version_page_delete_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_count_page = self.test_document.version_active.version_pages.count()
+        document_version_count_page = self._test_document.version_active.version_pages.count()
 
         self._clear_events()
 
@@ -114,7 +114,7 @@ class DocumentVersionPageAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
         self.assertEqual(
-            self.test_document.version_active.version_pages.count(),
+            self._test_document.version_active.version_pages.count(),
             document_version_count_page - 1
         )
 
@@ -123,18 +123,18 @@ class DocumentVersionPageAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(events[0].verb, event_document_version_page_deleted.id)
 
     def test_trashed_document_version_page_delete_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_count_page = self.test_document.version_active.version_pages.count()
+        document_version_count_page = self._test_document.version_active.version_pages.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -142,7 +142,7 @@ class DocumentVersionPageAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.version_active.version_pages.count(),
+            self._test_document.version_active.version_pages.count(),
             document_version_count_page
         )
 
@@ -160,7 +160,7 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_document_version_page_detail_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
 
@@ -174,11 +174,11 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_trashed_document_version_page_detail_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -189,16 +189,16 @@ class DocumentVersionPageAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_version_page_edit_via_patch_api_view_no_permission(self):
-        document_version_page_number = self.test_document_version_page.page_number
+        document_version_page_number = self._test_document_version_page.page_number
 
         self._clear_events()
 
         response = self._request_test_document_version_page_edit_via_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_version_page.refresh_from_db()
+        self._test_document_version_page.refresh_from_db()
         self.assertEqual(
-            self.test_document_version_page.page_number,
+            self._test_document_version_page.page_number,
             document_version_page_number
         )
 
@@ -207,49 +207,49 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_document_version_page_edit_via_patch_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_page_number = self.test_document_version_page.page_number
+        document_version_page_number = self._test_document_version_page.page_number
 
         self._clear_events()
 
         response = self._request_test_document_version_page_edit_via_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document_version_page.refresh_from_db()
+        self._test_document_version_page.refresh_from_db()
         self.assertNotEqual(
-            self.test_document_version_page.page_number,
+            self._test_document_version_page.page_number,
             document_version_page_number
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version_page)
+        self.assertEqual(events[0].target, self._test_document_version_page)
         self.assertEqual(events[0].verb, event_document_version_page_edited.id)
 
     def test_trashed_document_version_page_edit_via_patch_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_page_number = self.test_document_version_page.page_number
+        document_version_page_number = self._test_document_version_page.page_number
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_version_page_edit_via_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_version_page.refresh_from_db()
+        self._test_document_version_page.refresh_from_db()
         self.assertEqual(
-            self.test_document_version_page.page_number,
+            self._test_document_version_page.page_number,
             document_version_page_number
         )
 
@@ -257,16 +257,16 @@ class DocumentVersionPageAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_version_page_edit_via_put_api_view_no_permission(self):
-        document_version_page_number = self.test_document_version_page.page_number
+        document_version_page_number = self._test_document_version_page.page_number
 
         self._clear_events()
 
         response = self._request_test_document_version_page_edit_via_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_version_page.refresh_from_db()
+        self._test_document_version_page.refresh_from_db()
         self.assertEqual(
-            self.test_document_version_page.page_number,
+            self._test_document_version_page.page_number,
             document_version_page_number
         )
 
@@ -275,48 +275,48 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_document_version_page_edit_via_put_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_page_number = self.test_document_version_page.page_number
+        document_version_page_number = self._test_document_version_page.page_number
 
         self._clear_events()
 
         response = self._request_test_document_version_page_edit_via_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document_version_page.refresh_from_db()
+        self._test_document_version_page.refresh_from_db()
         self.assertNotEqual(
-            self.test_document_version_page.page_number,
+            self._test_document_version_page.page_number,
             document_version_page_number
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version_page)
+        self.assertEqual(events[0].target, self._test_document_version_page)
         self.assertEqual(events[0].verb, event_document_version_page_edited.id)
 
     def test_trashed_document_version_page_edit_via_put_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_page_number = self.test_document_version_page.page_number
+        document_version_page_number = self._test_document_version_page.page_number
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_version_page_edit_via_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_version_page.refresh_from_db()
+        self._test_document_version_page.refresh_from_db()
         self.assertEqual(
-            self.test_document_version_page.page_number,
+            self._test_document_version_page.page_number,
             document_version_page_number
         )
 
@@ -334,7 +334,7 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_document_version_page_image_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
 
@@ -348,11 +348,11 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_trashed_document_version_page_image_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -373,7 +373,7 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_document_version_page_list_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
 
@@ -384,7 +384,7 @@ class DocumentVersionPageAPIViewTestCase(
 
         self.assertEqual(
             response.data['results'][0]['id'],
-            self.test_document_version_page.id
+            self._test_document_version_page.id
         )
 
         events = self._get_test_events()
@@ -392,11 +392,11 @@ class DocumentVersionPageAPIViewTestCase(
 
     def test_trashed_document_version_page_list_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
