@@ -7,9 +7,13 @@ from mayan.apps.messaging.models import Message
 from mayan.apps.storage.events import event_download_file_created
 from mayan.apps.storage.models import DownloadFile
 
+from ..document_file_actions import (
+    DocumentFileActionAppendNewPages, DocumentFileActionNothing
+)
 from ..events import (
     event_document_version_deleted, event_document_version_edited,
-    event_document_version_exported, event_document_viewed
+    event_document_version_exported, event_document_version_page_created,
+    event_document_version_page_deleted, event_document_viewed
 )
 from ..permissions import (
     permission_document_version_delete, permission_document_version_edit,
@@ -20,8 +24,10 @@ from ..permissions import (
 from .base import (
     GenericDocumentViewTestCase, GenericTransactionDocumentViewTestCase
 )
+from .mixins.document_file_mixins import DocumentFileTestMixin
 from .mixins.document_version_mixins import (
-    DocumentVersionTestMixin, DocumentVersionViewTestMixin
+    DocumentVersionModificationViewTestMixin, DocumentVersionTestMixin,
+    DocumentVersionViewTestMixin
 )
 
 
@@ -32,15 +38,15 @@ class DocumentVersionViewTestCase(
     def test_document_version_active_view_no_permission(self):
         self._create_test_document_version()
 
-        self.test_document.versions.first().active_set()
+        self._test_document.versions.first().active_set()
 
         self._clear_events()
 
         response = self._request_test_document_version_active_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_version.refresh_from_db()
-        self.assertFalse(self.test_document_version.active)
+        self._test_document_version.refresh_from_db()
+        self.assertFalse(self._test_document_version.active)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -48,10 +54,10 @@ class DocumentVersionViewTestCase(
     def test_document_version_active_view_with_access(self):
         self._create_test_document_version()
 
-        self.test_document.versions.first().active_set()
+        self._test_document.versions.first().active_set()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
@@ -60,72 +66,72 @@ class DocumentVersionViewTestCase(
         response = self._request_test_document_version_active_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_document_version.refresh_from_db()
-        self.assertTrue(self.test_document_version.active)
+        self._test_document_version.refresh_from_db()
+        self.assertTrue(self._test_document_version.active)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(events[0].verb, event_document_version_edited.id)
 
     def test_trashed_document_version_active_view_with_access(self):
         self._create_test_document_version()
 
-        self.test_document.versions.first().active_set()
+        self._test_document.versions.first().active_set()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_version_active_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_version.refresh_from_db()
-        self.assertFalse(self.test_document_version.active)
+        self._test_document_version.refresh_from_db()
+        self.assertFalse(self._test_document_version.active)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_delete_single_view_no_permission(self):
+    def test_document_version_single_delete_view_no_permission(self):
         self._create_test_document_version()
 
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
         self._clear_events()
 
-        response = self._request_test_document_version_delete_single_view()
+        response = self._request_test_document_version_single_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count
+            self._test_document.versions.count(), document_version_count
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_delete_single_view_with_access(self):
+    def test_document_version_single_delete_view_with_access(self):
         self._create_test_document_version()
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_delete
         )
 
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
         self._clear_events()
 
-        response = self._request_test_document_version_delete_single_view()
+        response = self._request_test_document_version_single_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count - 1
+            self._test_document.versions.count(), document_version_count - 1
         )
 
         events = self._get_test_events()
@@ -133,43 +139,43 @@ class DocumentVersionViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_version_deleted.id)
 
-    def test_document_version_delete_multiple_view_no_permission(self):
+    def test_document_version_multiple_delete_view_no_permission(self):
         self._create_test_document_version()
 
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
         self._clear_events()
 
-        response = self._request_test_document_version_delete_multiple_view()
+        response = self._request_test_document_version_multiple_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count
+            self._test_document.versions.count(), document_version_count
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_delete_multiple_view_with_access(self):
+    def test_document_version_multiple_delete_view_with_access(self):
         self._create_test_document_version()
 
-        document_version_count = self.test_document.versions.count()
+        document_version_count = self._test_document.versions.count()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_delete
         )
 
         self._clear_events()
 
-        response = self._request_test_document_version_delete_multiple_view()
+        response = self._request_test_document_version_multiple_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(
-            self.test_document.versions.count(), document_version_count - 1
+            self._test_document.versions.count(), document_version_count - 1
         )
 
         events = self._get_test_events()
@@ -177,20 +183,20 @@ class DocumentVersionViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_version_deleted.id)
 
     def test_document_version_edit_view_no_permission(self):
-        document_version_comment = self.test_document_version.comment
+        document_version_comment = self._test_document_version.comment
 
         self._clear_events()
 
         response = self._request_test_document_version_edit_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_version.refresh_from_db()
+        self._test_document_version.refresh_from_db()
         self.assertEqual(
-            self.test_document_version.comment,
+            self._test_document_version.comment,
             document_version_comment
         )
 
@@ -199,48 +205,48 @@ class DocumentVersionViewTestCase(
 
     def test_document_version_edit_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_comment = self.test_document_version.comment
+        document_version_comment = self._test_document_version.comment
 
         self._clear_events()
 
         response = self._request_test_document_version_edit_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_document_version.refresh_from_db()
+        self._test_document_version.refresh_from_db()
         self.assertNotEqual(
-            self.test_document_version.comment,
+            self._test_document_version.comment,
             document_version_comment
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(events[0].verb, event_document_version_edited.id)
 
     def test_trashed_document_version_edit_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_edit
         )
 
-        document_version_comment = self.test_document_version.comment
+        document_version_comment = self._test_document_version.comment
 
-        self.test_document.delete()
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_version_edit_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_version.refresh_from_db()
+        self._test_document_version.refresh_from_db()
         self.assertEqual(
-            self.test_document_version.comment,
+            self._test_document_version.comment,
             document_version_comment
         )
 
@@ -258,7 +264,7 @@ class DocumentVersionViewTestCase(
 
     def test_document_version_list_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
@@ -267,7 +273,7 @@ class DocumentVersionViewTestCase(
         response = self._request_test_document_version_list_view()
         self.assertContains(
             response=response, status_code=200,
-            text=str(self.test_document_version)
+            text=str(self._test_document_version)
         )
 
         events = self._get_test_events()
@@ -275,11 +281,11 @@ class DocumentVersionViewTestCase(
 
     def test_trashed_document_version_list_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_version_list_view()
@@ -299,7 +305,7 @@ class DocumentVersionViewTestCase(
 
     def test_document_version_preview_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
 
@@ -308,24 +314,24 @@ class DocumentVersionViewTestCase(
         response = self._request_test_document_version_preview_view()
         self.assertContains(
             response=response, status_code=200,
-            text=str(self.test_document_version)
+            text=str(self._test_document_version)
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_viewed.id)
 
     def test_trashed_document_version_preview_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_version_preview_view()
@@ -345,7 +351,7 @@ class DocumentVersionViewTestCase(
 
     def test_document_version_print_form_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_print
         )
 
@@ -359,11 +365,11 @@ class DocumentVersionViewTestCase(
 
     def test_trashed_document_version_print_form_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_print
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_version_print_form_view()
@@ -383,7 +389,7 @@ class DocumentVersionViewTestCase(
 
     def test_document_version_print_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_print
         )
 
@@ -397,11 +403,11 @@ class DocumentVersionViewTestCase(
 
     def test_trashed_document_version_print_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_print
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_version_print_view()
@@ -439,7 +445,7 @@ class DocumentVersionExportViewTestCase(
 
     def test_document_version_export_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_export
         )
 
@@ -460,14 +466,14 @@ class DocumentVersionExportViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 3)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, test_download_file)
         self.assertEqual(events[0].verb, event_download_file_created.id)
 
         self.assertEqual(events[1].action_object, test_download_file)
         self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(events[1].target, self.test_document_version)
+        self.assertEqual(events[1].target, self._test_document_version)
         self.assertEqual(events[1].verb, event_document_version_exported.id)
 
         self.assertEqual(events[2].action_object, None)
@@ -477,13 +483,13 @@ class DocumentVersionExportViewTestCase(
 
     def test_trashed_document_version_export_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_document_version_export
         )
 
         download_file_count = DownloadFile.objects.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_version_export_view()
@@ -501,12 +507,12 @@ class DocumentVersionCachePurgeViewTestCase(
     CachePartitionViewTestMixin, GenericDocumentViewTestCase
 ):
     def test_document_version_cache_purge_no_permission(self):
-        self.test_object = self.test_document_version
+        self._test_object = self._test_document_version
         self._inject_test_object_content_type()
 
-        self.test_document_version.version_pages.first().generate_image()
+        self._test_document_version.version_pages.first().generate_image()
 
-        test_document_version_cache_partitions = self.test_document_version.get_cache_partitions()
+        test_document_version_cache_partitions = self._test_document_version.get_cache_partitions()
 
         cache_partition_version_count = CachePartitionFile.objects.filter(
             partition__in=test_document_version_cache_partitions
@@ -527,23 +533,23 @@ class DocumentVersionCachePurgeViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_version_cache_purge_with_access(self):
-        self.test_object = self.test_document_version
+        self._test_object = self._test_document_version
         self._inject_test_object_content_type()
 
         self.grant_access(
-            obj=self.test_document_version,
+            obj=self._test_document_version,
             permission=permission_cache_partition_purge
         )
 
-        self.test_document_version.version_pages.first().generate_image()
+        self._test_document_version.version_pages.first().generate_image()
 
-        test_document_version_cache_partitions = self.test_document_version.get_cache_partitions()
+        test_document_version_cache_partitions = self._test_document_version.get_cache_partitions()
 
         cache_partition_version_count = CachePartitionFile.objects.filter(
             partition__in=test_document_version_cache_partitions
         ).count()
 
-        cache_partitions = self.test_document_version.get_cache_partitions()
+        cache_partitions = self._test_document_version.get_cache_partitions()
 
         self._clear_events()
 
@@ -559,12 +565,223 @@ class DocumentVersionCachePurgeViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
-        self.assertEqual(events[0].action_object, self.test_document_version)
+        self.assertEqual(events[0].action_object, self._test_document_version)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, cache_partitions[0])
         self.assertEqual(events[0].verb, event_cache_partition_purged.id)
 
-        self.assertEqual(events[1].action_object, self.test_document_version)
+        self.assertEqual(events[1].action_object, self._test_document_version)
         self.assertEqual(events[1].actor, self._test_case_user)
         self.assertEqual(events[1].target, cache_partitions[1])
         self.assertEqual(events[1].verb, event_cache_partition_purged.id)
+
+
+class DocumentVersionModificationViewTestCase(
+    DocumentFileTestMixin, DocumentVersionModificationViewTestMixin,
+    DocumentVersionTestMixin, GenericDocumentViewTestCase
+):
+    def test_document_version_action_page_append_view_no_permission(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionNothing.backend_id
+        )
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_append_view()
+        self.assertEqual(response.status_code, 404)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count()
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_document_version_action_page_append_view_with_access(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionNothing.backend_id
+        )
+
+        self.grant_access(
+            obj=self._test_document_version,
+            permission=permission_document_version_edit
+        )
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_append_view()
+        self.assertEqual(response.status_code, 302)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count() + self._test_document_files[1].pages.count()
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 3)
+
+        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(events[0].target, self._test_document_version)
+        self.assertEqual(
+            events[0].verb, event_document_version_page_deleted.id
+        )
+
+        self.assertEqual(events[1].action_object, self._test_document_version)
+        self.assertEqual(events[1].actor, self._test_case_user)
+        self.assertEqual(
+            events[1].target, self._test_document_version.pages[0]
+        )
+        self.assertEqual(
+            events[1].verb, event_document_version_page_created.id
+        )
+        self.assertEqual(events[2].action_object, self._test_document_version)
+        self.assertEqual(events[2].actor, self._test_case_user)
+        self.assertEqual(
+            events[2].target, self._test_document_version.pages[1]
+        )
+        self.assertEqual(
+            events[2].verb, event_document_version_page_created.id
+        )
+
+    def test_trashed_document_version_action_page_append_view_with_access(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionNothing.backend_id
+        )
+
+        self.grant_access(
+            obj=self._test_document_version,
+            permission=permission_document_version_edit
+        )
+
+        self._test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_append_view()
+        self.assertEqual(response.status_code, 404)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count()
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_document_version_action_page_reset_view_no_permission(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionAppendNewPages.backend_id
+        )
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_reset_view()
+        self.assertEqual(response.status_code, 404)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count() + self._test_document_files[1].pages.count()
+        )
+
+        self.assertEqual(
+            self._test_document_version.pages.all()[0].content_object,
+            self._test_document_file_pages[0]
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
+
+    def test_document_version_action_page_reset_view_with_access(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionAppendNewPages.backend_id
+        )
+
+        self.grant_access(
+            obj=self._test_document_version,
+            permission=permission_document_version_edit
+        )
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_reset_view()
+        self.assertEqual(response.status_code, 302)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count()
+        )
+
+        self.assertEqual(
+            self._test_document_version.pages.all()[0].content_object,
+            self._test_document_file_pages[1]
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 3)
+
+        self.assertEqual(events[0].action_object, None)
+        self.assertEqual(events[0].actor, self._test_case_user)
+        self.assertEqual(events[0].target, self._test_document_version)
+        self.assertEqual(
+            events[0].verb, event_document_version_page_deleted.id
+        )
+
+        self.assertEqual(events[1].action_object, None)
+        self.assertEqual(events[1].actor, self._test_case_user)
+        self.assertEqual(events[1].target, self._test_document_version)
+        self.assertEqual(
+            events[1].verb, event_document_version_page_deleted.id
+        )
+
+        self.assertEqual(events[2].action_object, self._test_document_version)
+        self.assertEqual(events[2].actor, self._test_case_user)
+        self.assertEqual(
+            events[2].target, self._test_document_version.pages[0]
+        )
+        self.assertEqual(
+            events[2].verb, event_document_version_page_created.id
+        )
+
+    def test_trashed_document_version_action_page_reset_view_with_access(self):
+        self._upload_test_document_file(
+            action=DocumentFileActionAppendNewPages.backend_id
+        )
+
+        self.grant_access(
+            obj=self._test_document_version,
+            permission=permission_document_version_edit
+        )
+
+        self._test_document.delete()
+
+        self._clear_events()
+
+        response = self._request_test_document_version_action_page_reset_view()
+        self.assertEqual(response.status_code, 404)
+
+        self._test_document_version.refresh_from_db()
+
+        self.assertEqual(
+            self._test_document_version.pages.count(),
+            self._test_document_files[0].pages.count() + self._test_document_files[1].pages.count()
+        )
+
+        self.assertEqual(
+            self._test_document_version.pages.all()[0].content_object,
+            self._test_document_file_pages[0]
+        )
+
+        events = self._get_test_events()
+        self.assertEqual(events.count(), 0)
