@@ -14,7 +14,7 @@ class RecentlyAccessedDocumentViewTestCase(
         self._create_test_document_stub()
 
     def test_recently_accessed_document_list_view_no_permission(self):
-        self.test_document.add_as_recent_document_for_user(
+        self._test_document.add_as_recent_document_for_user(
             user=self._test_case_user
         )
 
@@ -22,46 +22,46 @@ class RecentlyAccessedDocumentViewTestCase(
 
         response = self._request_test_recently_accessed_document_list_view()
         self.assertNotContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_recently_accessed_document_list_view_with_access(self):
-        self.test_document.add_as_recent_document_for_user(
+        self._test_document.add_as_recent_document_for_user(
             user=self._test_case_user
         )
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         self._clear_events()
 
         response = self._request_test_recently_accessed_document_list_view()
         self.assertContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_trashed_recently_accessed_document_list_view_with_access(self):
-        self.test_document.add_as_recent_document_for_user(
+        self._test_document.add_as_recent_document_for_user(
             user=self._test_case_user
         )
-        self.test_document.delete()
+        self._test_document.delete()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         self._clear_events()
 
         response = self._request_test_recently_accessed_document_list_view()
         self.assertNotContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
 
         events = self._get_test_events()
