@@ -46,7 +46,7 @@ class TrashedDocumentAPIViewTestCase(
 
     def test_document_trash_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_trash
+            obj=self._test_document, permission=permission_document_trash
         )
 
         trashed_document_count = Document.trash.count()
@@ -65,15 +65,15 @@ class TrashedDocumentAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_trashed.id)
 
     def test_trashed_document_trash_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_trash
+            obj=self._test_document, permission=permission_document_trash
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         trashed_document_count = Document.trash.count()
         document_count = Document.valid.count()
@@ -90,7 +90,7 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_delete_api_view_no_permission(self):
-        self.test_document.delete()
+        self._test_document.delete()
 
         trashed_document_count = Document.trash.count()
         document_count = Document.valid.count()
@@ -107,9 +107,9 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_delete_api_view_with_access(self):
-        self.test_document.delete()
+        self._test_document.delete()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_trashed_document_delete
         )
 
@@ -129,12 +129,12 @@ class TrashedDocumentAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_type)
+        self.assertEqual(events[0].target, self._test_document_type)
         self.assertEqual(events[0].verb, event_trashed_document_deleted.id)
 
     def test_non_trashed_document_delete_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_trashed_document_delete
         )
 
@@ -153,7 +153,7 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_detail_api_view_no_permission(self):
-        self.test_document.delete()
+        self._test_document.delete()
 
         trashed_document_count = Document.trash.count()
         document_count = Document.valid.count()
@@ -171,9 +171,9 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_detail_api_view_with_access(self):
-        self.test_document.delete()
+        self._test_document.delete()
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         trashed_document_count = Document.trash.count()
@@ -184,7 +184,7 @@ class TrashedDocumentAPIViewTestCase(
         response = self._request_test_trashed_document_detail_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
-            response.data['uuid'], force_text(s=self.test_document.uuid)
+            response.data['uuid'], force_text(s=self._test_document.uuid)
         )
 
         self.assertEqual(Document.trash.count(), trashed_document_count)
@@ -195,7 +195,7 @@ class TrashedDocumentAPIViewTestCase(
 
     def test_non_trashed_document_detail_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         trashed_document_count = Document.trash.count()
@@ -213,7 +213,7 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_list_api_view_no_permission(self):
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -225,9 +225,9 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_list_api_view_with_access(self):
-        self.test_document.delete()
+        self._test_document.delete()
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         self._clear_events()
@@ -236,7 +236,7 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
             response.data['results'][0]['uuid'],
-            force_text(s=self.test_document.uuid)
+            force_text(s=self._test_document.uuid)
         )
 
         events = self._get_test_events()
@@ -244,7 +244,7 @@ class TrashedDocumentAPIViewTestCase(
 
     def test_non_trashed_document_list_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         self._clear_events()
@@ -257,7 +257,7 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_restore_via_get_api_view_no_permission(self):
-        self.test_document.delete()
+        self._test_document.delete()
 
         trashed_document_count = Document.trash.count()
         document_count = Document.valid.count()
@@ -274,10 +274,10 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_restore_via_get_api_view_with_access(self):
-        self.test_document.delete()
+        self._test_document.delete()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_trashed_document_restore
         )
 
@@ -297,7 +297,7 @@ class TrashedDocumentAPIViewTestCase(
 
     def test_non_trashed_document_restore_via_get_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_trashed_document_restore
         )
 
@@ -316,7 +316,7 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_restore_via_post_api_view_no_permission(self):
-        self.test_document.delete()
+        self._test_document.delete()
 
         trashed_document_count = Document.trash.count()
         document_count = Document.valid.count()
@@ -333,10 +333,10 @@ class TrashedDocumentAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_restore_via_post_api_view_with_access(self):
-        self.test_document.delete()
+        self._test_document.delete()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_trashed_document_restore
         )
 
@@ -356,12 +356,12 @@ class TrashedDocumentAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_trashed_document_restored.id)
 
     def test_non_trashed_document_restore_via_post_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_trashed_document_restore
         )
 
@@ -384,7 +384,7 @@ class TrashedDocumentImageAPIViewTestCase(
     TrashedDocumentAPIViewTestMixin, DocumentTestMixin, BaseAPITestCase
 ):
     def test_trashed_document_image_api_view_no_permission(self):
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -395,9 +395,9 @@ class TrashedDocumentImageAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_image_api_view_with_access(self):
-        self.test_document.delete()
+        self._test_document.delete()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
@@ -411,7 +411,7 @@ class TrashedDocumentImageAPIViewTestCase(
 
     def test_non_trashed_document_image_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_view
         )
 
