@@ -11,7 +11,7 @@ class DocumentPreviewWidgetViewTestCase(
 ):
     def test_document_preview_page_carousel_widget_render(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         response = self._request_test_document_preview_view()
