@@ -1,7 +1,8 @@
 from django.conf.urls import url
 
 from .api_views.document_api_views import (
-    APIDocumentDetailView, APIDocumentListView, APIDocumentChangeTypeView,
+    APIDocumentDetailView, APIDocumentChangeTypeView,
+    APIDocumentFileActionListView, APIDocumentListView,
     APIDocumentUploadView
 )
 from .api_views.document_file_api_views import (
@@ -15,7 +16,8 @@ from .api_views.document_type_api_views import (
 )
 from .api_views.document_version_api_views import (
     APIDocumentVersionDetailView, APIDocumentVersionExportView,
-    APIDocumentVersionListView, APIDocumentVersionPageDetailView,
+    APIDocumentVersionListView, APIDocumentVersionModificationBackendListView,
+    APIDocumentVersionModificationView, APIDocumentVersionPageDetailView,
     APIDocumentVersionPageImageView, APIDocumentVersionPageListView
 )
 from .api_views.favorite_document_api_views import (
@@ -49,15 +51,14 @@ from .views.document_file_page_views import (
 from .views.document_type_views import (
     DocumentTypeCreateView, DocumentTypeDeleteView,
     DocumentTypeDeletionPoliciesEditView, DocumentTypeDocumentListView,
-    DocumentTypeEditView, DocumentTypeFileGeneratorEditView,
+    DocumentTypeEditView, DocumentTypeFilenameGeneratorEditView,
     DocumentTypeFilenameCreateView, DocumentTypeFilenameDeleteView,
     DocumentTypeFilenameEditView, DocumentTypeFilenameListView,
     DocumentTypeListView
 )
 from .views.document_version_page_views import (
     DocumentVersionPageDeleteView, DocumentVersionPageListView,
-    DocumentVersionPageListAppendView, DocumentVersionPageListRemapView,
-    DocumentVersionPageListResetView, DocumentVersionPageNavigationFirst,
+    DocumentVersionPageListRemapView, DocumentVersionPageNavigationFirst,
     DocumentVersionPageNavigationLast, DocumentVersionPageNavigationNext,
     DocumentVersionPageNavigationPrevious, DocumentVersionPageRotateLeftView,
     DocumentVersionPageRotateRightView, DocumentVersionPageView,
@@ -68,8 +69,9 @@ from .views.document_version_views import (
     DocumentVersionActiveView, DocumentVersionCreateView,
     DocumentVersionDeleteView, DocumentVersionEditView,
     DocumentVersionExportView, DocumentVersionListView,
-    DocumentVersionPreviewView, DocumentVersionPrintFormView,
-    DocumentVersionPrintView, DocumentVersionTransformationsClearView,
+    DocumentVersionModifyView, DocumentVersionPreviewView,
+    DocumentVersionPrintFormView, DocumentVersionPrintView,
+    DocumentVersionTransformationsClearView,
     DocumentVersionTransformationsCloneView
 )
 from .views.document_views import (
@@ -106,7 +108,7 @@ urlpatterns_document_files = [
     ),
     url(
         regex=r'^documents/files/multiple/delete/$',
-        name='document_file_delete_multiple',
+        name='document_file_multiple_delete',
         view=DocumentFileDeleteView.as_view()
     ),
     url(
@@ -147,7 +149,7 @@ urlpatterns_document_files = [
         regex=r'^documents/files/(?P<document_file_id>\d+)/transformations/clone/$',
         name='document_file_transformations_clone',
         view=DocumentFileTransformationsCloneView.as_view()
-    ),
+    )
 ]
 
 urlpatterns_document_file_pages = [
@@ -211,7 +213,7 @@ urlpatterns_document_file_pages = [
         regex=r'^documents/files/pages/(?P<document_file_page_id>\d+)/reset/$',
         name='document_file_page_view_reset',
         view=DocumentFilePageViewResetView.as_view()
-    ),
+    )
 ]
 
 urlpatterns_document_types = [
@@ -244,7 +246,7 @@ urlpatterns_document_types = [
     url(
         regex=r'^document_types/(?P<document_type_id>\d+)/filename_generator/$',
         name='document_type_filename_generator',
-        view=DocumentTypeFileGeneratorEditView.as_view()
+        view=DocumentTypeFilenameGeneratorEditView.as_view()
     ),
     url(
         regex=r'^document_types/(?P<document_type_id>\d+)/filenames/$',
@@ -265,7 +267,7 @@ urlpatterns_document_types = [
         regex=r'^document_types/filenames/(?P<document_type_filename_id>\d+)/edit/$',
         name='document_type_filename_edit',
         view=DocumentTypeFilenameEditView.as_view()
-    ),
+    )
 ]
 
 urlpatterns_document_version = [
@@ -285,7 +287,7 @@ urlpatterns_document_version = [
     ),
     url(
         regex=r'^documents/versions/(?P<document_version_id>\d+)/delete/$',
-        name='document_version_delete_single',
+        name='document_version_single_delete',
         view=DocumentVersionDeleteView.as_view()
     ),
     url(
@@ -300,9 +302,14 @@ urlpatterns_document_version = [
     ),
     url(
         regex=r'^documents/versions/multiple/delete/$',
-        name='document_version_delete_multiple',
+        name='document_version_multiple_delete',
         view=DocumentVersionDeleteView.as_view()
     ),
+    url(
+        regex=r'^documents/versions/(?P<document_version_id>\d+)/modify/$',
+        name='document_version_modify',
+        view=DocumentVersionModifyView.as_view()
+    ),
     url(
         regex=r'^documents/versions/(?P<document_version_id>\d+)/preview/$',
         name='document_version_preview',
@@ -332,7 +339,7 @@ urlpatterns_document_version = [
         regex=r'^documents/versions/(?P<document_version_id>\d+)/transformations/clone/$',
         name='document_version_transformations_clone',
         view=DocumentVersionTransformationsCloneView.as_view()
-    ),
+    )
 ]
 
 urlpatterns_document_version_pages = [
@@ -346,21 +353,11 @@ urlpatterns_document_version_pages = [
         name='document_version_page_delete',
         view=DocumentVersionPageDeleteView.as_view()
     ),
-    url(
-        regex=r'^documents/versions/(?P<document_version_id>\d+)/pages/append/$',
-        name='document_version_page_list_append',
-        view=DocumentVersionPageListAppendView.as_view()
-    ),
     url(
         regex=r'^documents/versions/(?P<document_version_id>\d+)/pages/remap/$',
         name='document_version_page_list_remap',
         view=DocumentVersionPageListRemapView.as_view()
     ),
-    url(
-        regex=r'^documents/versions/(?P<document_version_id>\d+)/pages/reset/$',
-        name='document_version_page_list_reset',
-        view=DocumentVersionPageListResetView.as_view()
-    ),
     url(
         regex=r'^documents/versions/pages/(?P<document_version_page_id>\d+)/$',
         name='document_version_page_view',
@@ -408,7 +405,7 @@ urlpatterns_document_version_pages = [
         regex=r'^documents/versions/(?P<document_version_page_id>\d+)/reset/$',
         name='document_version_page_view_reset',
         view=DocumentVersionPageViewResetView.as_view()
-    ),
+    )
 ]
 
 urlpatterns_documents = [
@@ -448,7 +445,7 @@ urlpatterns_documents = [
         regex=r'^documents/multiple/type/$',
         name='document_multiple_type_change',
         view=DocumentTypeChangeView.as_view()
-    ),
+    )
 ]
 
 urlpatterns_favorite_documents = [
@@ -472,7 +469,7 @@ urlpatterns_favorite_documents = [
         regex=r'^documents/multiple/remove_from_favorites/$',
         name='document_favorite_remove_multiple',
         view=FavoriteRemoveView.as_view()
-    ),
+    )
 ]
 
 urlpatterns_trashed_documents = [
@@ -509,7 +506,7 @@ urlpatterns_trashed_documents = [
     url(
         regex=r'^trash_can/empty/$', name='trash_can_empty',
         view=EmptyTrashCanView.as_view()
-    ),
+    )
 ]
 
 urlpatterns = []
@@ -523,10 +520,13 @@ urlpatterns.extend(urlpatterns_favorite_documents)
 urlpatterns.extend(urlpatterns_trashed_documents)
 
 api_urls_documents = [
+    url(
+        regex=r'^document_file_actions/$', name='document-file-action-list',
+        view=APIDocumentFileActionListView.as_view()
+    ),
     url(
         regex=r'^documents/$', name='document-list',
         view=APIDocumentListView.as_view()
-
     ),
     url(
         regex=r'^documents/upload/$', name='document-upload',
@@ -617,6 +617,11 @@ api_urls_document_types = [
 ]
 
 api_urls_document_versions = [
+    url(
+        regex=r'^document_version_modification_backends/$',
+        name='documentversionmodificationbackend-list',
+        view=APIDocumentVersionModificationBackendListView.as_view()
+    ),
     url(
         regex=r'^documents/(?P<document_id>[0-9]+)/versions/$',
         name='documentversion-list',
@@ -632,6 +637,11 @@ api_urls_document_versions = [
         view=APIDocumentVersionExportView.as_view(),
         name='documentversion-export'
     ),
+    url(
+        regex=r'^documents/(?P<document_id>[0-9]+)/versions/(?P<document_version_id>[0-9]+)/modify/$',
+        name='documentversion-modify',
+        view=APIDocumentVersionModificationView.as_view()
+    ),
     url(
         regex=r'^documents/(?P<document_id>[0-9]+)/versions/(?P<document_version_id>[0-9]+)/pages/$',
         name='documentversionpage-list',
