@@ -6,18 +6,17 @@ from django.contrib import messages
 from django.contrib.contenttypes.models import ContentType
 from django.urls import reverse
 from django.utils.encoding import force_text
-from django.utils.translation import ugettext_lazy as _, ungettext
+from django.utils.translation import ugettext_lazy as _
 from django.views.generic import RedirectView
 
-from mayan.apps.common.classes import ModelQueryFields
 from mayan.apps.common.settings import setting_home_view
 from mayan.apps.converter.literals import DEFAULT_ROTATION, DEFAULT_ZOOM_LEVEL
 from mayan.apps.converter.transformations import (
     TransformationResize, TransformationRotate, TransformationZoom
 )
+from mayan.apps.databases.classes import ModelQueryFields
 from mayan.apps.views.generics import (
-    FormView, MultipleObjectConfirmActionView, SingleObjectDeleteView,
-    SingleObjectListView, SimpleView
+    FormView, SingleObjectDeleteView, SingleObjectListView, SimpleView
 )
 from mayan.apps.views.mixins import ExternalObjectViewMixin
 from mayan.apps.views.utils import resolve
@@ -26,12 +25,11 @@ from ..forms.document_version_page_forms import (
     DocumentVersionPageForm, DocumentVersionPageMappingFormSet
 )
 from ..icons import (
-    icon_document_version_page_list, icon_document_version_page_list_remap
-)
-from ..links.document_version_page_links import (
-    link_document_version_page_list_remap,
-    link_document_version_page_list_reset
+    icon_document_version_page_delete, icon_document_version_page_list,
+    icon_document_version_page_list_remap, icon_document_version_page_detail
 )
+from ..links.document_version_links import link_document_version_modification
+from ..links.document_version_page_links import link_document_version_page_list_remap
 from ..models.document_version_models import DocumentVersion
 from ..models.document_version_page_models import DocumentVersionPage
 from ..permissions import (
@@ -42,10 +40,6 @@ from ..settings import (
     setting_zoom_percent_step, setting_zoom_max_level,
     setting_zoom_min_level
 )
-from ..tasks import (
-    task_document_version_page_list_append,
-    task_document_version_page_list_reset
-)
 
 __all__ = (
     'DocumentVersionPageListView',
@@ -63,6 +57,7 @@ class DocumentVersionPageDeleteView(SingleObjectDeleteView):
     object_permission = permission_document_version_edit
     pk_url_kwarg = 'document_version_page_id'
     source_queryset = DocumentVersionPage.valid.all()
+    view_icon = icon_document_version_page_delete
 
     def get_extra_context(self):
         return {
@@ -92,13 +87,14 @@ class DocumentVersionPageListView(ExternalObjectViewMixin, SingleObjectListView)
     external_object_permission = permission_document_version_view
     external_object_pk_url_kwarg = 'document_version_id'
     external_object_queryset = DocumentVersion.valid.all()
+    view_icon = icon_document_version_page_list
 
     def get_extra_context(self):
         return {
             'hide_object': True,
             'list_as_items': True,
             'no_results_icon': icon_document_version_page_list,
-            'no_results_main_link': link_document_version_page_list_reset.resolve(
+            'no_results_main_link': link_document_version_modification.resolve(
                 request=self.request, resolved_object=self.external_object
             ),
             'no_results_secondary_links': [
@@ -108,8 +104,8 @@ class DocumentVersionPageListView(ExternalObjectViewMixin, SingleObjectListView)
             ],
             'no_results_text': _(
                 'Document version pages are links to actual content pages. '
-                'Create them using the page remap actions or the page '
-                'reset action.'
+                'Create them using the page remap actions or the version '
+                'modification action.'
             ),
             'no_results_title': _('No document version pages available'),
             'object': self.external_object,
@@ -121,59 +117,12 @@ class DocumentVersionPageListView(ExternalObjectViewMixin, SingleObjectListView)
         return queryset.filter(pk__in=self.external_object.pages.all())
 
 
-class DocumentVersionPageListAppendView(MultipleObjectConfirmActionView):
-    object_permission = permission_document_version_edit
-    pk_url_kwarg = 'document_version_id'
-    source_queryset = DocumentVersion.valid.all()
-    success_message = _(
-        '%(count)d document version queued for page list append.'
-    )
-    success_message_plural = _(
-        '%(count)d document versions queued for page list append.'
-    )
-
-    def get_extra_context(self):
-        queryset = self.object_list
-
-        result = {
-            'message': _(
-                'The current pages will be deleted and then all the '
-                'document file pages will be appended as pages of this '
-                'document version.'
-            ),
-            'title': ungettext(
-                singular='Append all the document file pages to the selected document version?',
-                plural='Append all the document file pages to the selected document versions?',
-                number=queryset.count()
-            )
-        }
-
-        if queryset.count() == 1:
-            result.update(
-                {
-                    'object': queryset.first(),
-                    'title': _(
-                        'Append all the document file pages to document version: %s?'
-                    ) % queryset.first()
-                }
-            )
-
-        return result
-
-    def object_action(self, form, instance):
-        task_document_version_page_list_append.apply_async(
-            kwargs={
-                'document_version_id': instance.pk,
-                'user_id': self.request.user.pk
-            }
-        )
-
-
 class DocumentVersionPageListRemapView(ExternalObjectViewMixin, FormView):
     external_object_permission = permission_document_version_edit
     external_object_pk_url_kwarg = 'document_version_id'
     external_object_queryset = DocumentVersion.valid.all()
     form_class = DocumentVersionPageMappingFormSet
+    view_icon = icon_document_version_page_list_remap
 
     def form_valid(self, form):
         annotated_content_object_list = []
@@ -263,7 +212,10 @@ class DocumentVersionPageListRemapView(ExternalObjectViewMixin, FormView):
                 'source_content_type': content_object_dictionary['content_type'].pk,
                 'source_object_id': content_object_dictionary['object_id'],
                 'source_thumbnail': content_object,
-                'source_label': '{}: {}'.format(content_object_dictionary['content_type'].name, content_object),
+                'source_label': '{}: {}'.format(
+                    content_object_dictionary['content_type'].name,
+                    content_object
+                ),
                 'target_page_number': document_version_page_page_number
             }
 
@@ -279,53 +231,9 @@ class DocumentVersionPageListRemapView(ExternalObjectViewMixin, FormView):
         )
 
 
-class DocumentVersionPageListResetView(MultipleObjectConfirmActionView):
-    object_permission = permission_document_version_edit
-    pk_url_kwarg = 'document_version_id'
-    source_queryset = DocumentVersion.valid.all()
-    success_message = _(
-        '%(count)d document version queued for page list reset.'
-    )
-    success_message_plural = _(
-        '%(count)d document versions queued for page list reset.'
-    )
-
-    def get_extra_context(self):
-        queryset = self.object_list
-
-        result = {
-            'message': _(
-                'The page list will match that of the latest document file.'
-            ),
-            'title': ungettext(
-                singular='Reset the page list of the selected document version?',
-                plural='Reset the page list of the selected document versions?',
-                number=queryset.count()
-            )
-        }
-
-        if queryset.count() == 1:
-            result.update(
-                {
-                    'object': queryset.first(),
-                    'title': _(
-                        'Reset the page list of document version: %s?'
-                    ) % queryset.first()
-                }
-            )
-
-        return result
-
-    def object_action(self, form, instance):
-        task_document_version_page_list_reset.apply_async(
-            kwargs={
-                'document_version_id': instance.pk,
-                'user_id': self.request.user.pk
-            }
-        )
-
-
-class DocumentVersionPageNavigationBase(ExternalObjectViewMixin, RedirectView):
+class DocumentVersionPageNavigationBase(
+    ExternalObjectViewMixin, RedirectView
+):
     external_object_permission = permission_document_version_view
     external_object_pk_url_kwarg = 'document_version_page_id'
     external_object_queryset = DocumentVersionPage.valid.all()
@@ -418,6 +326,7 @@ class DocumentVersionPageView(ExternalObjectViewMixin, SimpleView):
     external_object_pk_url_kwarg = 'document_version_page_id'
     external_object_queryset = DocumentVersionPage.valid.all()
     template_name = 'appearance/generic_form.html'
+    view_icon = icon_document_version_page_detail
 
     def get_extra_context(self):
         zoom = int(self.request.GET.get('zoom', DEFAULT_ZOOM_LEVEL))
