@@ -7,7 +7,7 @@ from .literals import SEARCH_MODEL_NAME_KWARG
 
 class SearchModelAPIViewMixin:
     def get_search_model_name(self):
-        return self.kwargs.get(
+        search_model_name = self.kwargs.get(
             SEARCH_MODEL_NAME_KWARG, self.request.GET.get(
                 '_{}'.format(SEARCH_MODEL_NAME_KWARG), self.request.POST.get(
                     '_{}'.format(SEARCH_MODEL_NAME_KWARG)
@@ -15,6 +15,11 @@ class SearchModelAPIViewMixin:
             )
         )
 
+        if search_model_name:
+            search_model_name = search_model_name.lower()
+
+        return search_model_name
+
     def get_search_model(self):
         try:
             return SearchModel.get(name=self.get_search_model_name())
