@@ -34,7 +34,14 @@ SCOPE_OPERATOR_CHOICES = {
     SCOPE_OPERATOR_NOT: operator.not_
 }
 
-TASK_DEINDEX_INSTANCE_MAX_RETRIES = 20
-TASK_INDEX_INSTANCE_MAX_RETRIES = 20
-TASK_INDEX_RELATED_INSTANCE_M2M_MAX_RETRIES = 20
-TASK_INDEX_SEARCH_MODEL_MAX_RETRIES = 20
+TASK_DEINDEX_INSTANCE_MAX_RETRIES = 40
+TASK_DEINDEX_INSTANCE_RETRY_BACKOFF_MAX = 60
+
+TASK_INDEX_INSTANCE_MAX_RETRIES = 40
+TASK_INDEX_INSTANCE_RETRY_BACKOFF_MAX = 60
+
+TASK_INDEX_INSTANCES_MAX_RETRIES = 40
+TASK_INDEX_INSTANCES_RETRY_BACKOFF_MAX = 60
+
+TASK_INDEX_RELATED_INSTANCE_M2M_MAX_RETRIES = 40
+TASK_INDEX_RELATED_INSTANCE_M2M_RETRY_BACKOFF_MAX = 60
