@@ -1,7 +1,6 @@
 import logging
 
 from django.apps import apps
-from django.db.models.aggregates import Max, Min
 
 from mayan.apps.lock_manager.exceptions import LockError
 from mayan.celery import app
@@ -9,18 +8,21 @@ from mayan.celery import app
 from .classes import SearchBackend, SearchModel
 from .exceptions import DynamicSearchException, DynamicSearchRetry
 from .literals import (
-    TASK_DEINDEX_INSTANCE_MAX_RETRIES, TASK_INDEX_INSTANCE_MAX_RETRIES,
+    TASK_DEINDEX_INSTANCE_MAX_RETRIES,
+    TASK_DEINDEX_INSTANCE_RETRY_BACKOFF_MAX, TASK_INDEX_INSTANCE_MAX_RETRIES,
+    TASK_INDEX_INSTANCE_RETRY_BACKOFF_MAX, TASK_INDEX_INSTANCES_MAX_RETRIES,
+    TASK_INDEX_INSTANCES_RETRY_BACKOFF_MAX,
     TASK_INDEX_RELATED_INSTANCE_M2M_MAX_RETRIES,
-    TASK_INDEX_SEARCH_MODEL_MAX_RETRIES
+    TASK_INDEX_RELATED_INSTANCE_M2M_RETRY_BACKOFF_MAX
 )
-from .settings import setting_indexing_chunk_size
 
 logger = logging.getLogger(name=__name__)
 
 
 @app.task(
     bind=True, ignore_result=True,
-    max_retries=TASK_DEINDEX_INSTANCE_MAX_RETRIES, retry_backoff=True
+    max_retries=TASK_DEINDEX_INSTANCE_MAX_RETRIES, retry_backoff=True,
+    retry_backoff_max=TASK_DEINDEX_INSTANCE_RETRY_BACKOFF_MAX
 )
 def task_deindex_instance(self, app_label, model_name, object_id):
     logger.info('Executing')
@@ -38,32 +40,8 @@ def task_deindex_instance(self, app_label, model_name, object_id):
 
 @app.task(
     bind=True, ignore_result=True,
-    max_retries=TASK_INDEX_SEARCH_MODEL_MAX_RETRIES, retry_backoff=True
-)
-def task_index_search_model(self, search_model_full_name, range_string=None):
-    search_model = SearchModel.get(name=search_model_full_name)
-
-    kwargs = {
-        'range_string': range_string, 'search_model': search_model
-    }
-
-    try:
-        SearchBackend.get_instance().index_search_model(**kwargs)
-    except (DynamicSearchRetry, LockError) as exception:
-        raise self.retry(exc=exception)
-    except Exception as exception:
-        error_message = (
-            'Unexpected error calling `task_index_search_model` with '
-            'keyword arguments {}.'
-        ).format(kwargs)
-
-        logger.error(error_message)
-        raise DynamicSearchException(error_message) from exception
-
-
-@app.task(
-    bind=True, ignore_result=True,
-    max_retries=TASK_INDEX_INSTANCE_MAX_RETRIES, retry_backoff=True
+    max_retries=TASK_INDEX_INSTANCE_MAX_RETRIES, retry_backoff=True,
+    retry_backoff_max=TASK_INDEX_INSTANCE_RETRY_BACKOFF_MAX
 )
 def task_index_instance(
     self, app_label, model_name, object_id, exclude_app_label=None,
@@ -111,10 +89,37 @@ def task_index_instance(
         logger.info('Finished')
 
 
+@app.task(
+    bind=True, ignore_result=True,
+    max_retries=TASK_INDEX_INSTANCES_MAX_RETRIES, retry_backoff=True,
+    retry_backoff_max=TASK_INDEX_INSTANCES_RETRY_BACKOFF_MAX
+)
+def task_index_instances(self, search_model_full_name, id_list):
+    search_model = SearchModel.get(name=search_model_full_name)
+
+    kwargs = {
+        'id_list': id_list, 'search_model': search_model
+    }
+
+    try:
+        SearchBackend.get_instance().index_instances(**kwargs)
+    except (DynamicSearchRetry, LockError) as exception:
+        raise self.retry(exc=exception)
+    except Exception as exception:
+        error_message = (
+            'Unexpected error calling `task_index_instances` with '
+            'keyword arguments {}.'
+        ).format(kwargs)
+
+        logger.error(error_message)
+        raise DynamicSearchException(error_message) from exception
+
+
 @app.task(
     bind=True, ignore_result=True,
     max_retries=TASK_INDEX_RELATED_INSTANCE_M2M_MAX_RETRIES,
-    retry_backoff=True
+    retry_backoff=True,
+    retry_backoff_max=TASK_INDEX_RELATED_INSTANCE_M2M_RETRY_BACKOFF_MAX
 )
 def task_index_related_instance_m2m(
     self, action, instance_app_label, instance_model_name,
@@ -151,16 +156,10 @@ def task_reindex_backend():
     backend.reset()
 
     for search_model in SearchModel.all():
-        queryset = search_model.model._meta.managers_map[search_model.manager_name].all()
-        if queryset:
-            queryset = queryset.aggregate(min_id=Min('id'), max_id=Max('id'))
-            step = setting_indexing_chunk_size.value - 1
-
-            for id_start in range(queryset['min_id'], queryset['max_id'] + 1, step):
-                range_string = '{}-{}'.format(id_start, id_start + step - 1)
-                task_index_search_model.apply_async(
-                    kwargs={
-                        'range_string': range_string,
-                        'search_model_full_name': search_model.get_full_name(),
-                    }
-                )
+        for id_list in search_model.get_id_groups():
+            task_index_instances.apply_async(
+                kwargs={
+                    'id_list': id_list,
+                    'search_model_full_name': search_model.get_full_name(),
+                }
+            )
