@@ -2,7 +2,7 @@ from unittest import skip
 
 from mayan.apps.documents.models.document_models import DocumentSearchResult
 from mayan.apps.documents.permissions import permission_document_view
-from mayan.apps.documents.search import document_search
+from mayan.apps.documents.search import search_model_document
 from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.testing.tests.base import GenericViewTestCase
 
@@ -22,31 +22,31 @@ class AdvancedSearchViewTestCaseMixin(
 
     def setUp(self):
         super().setUp()
-        self.test_document_count = 4
+        self._test_document_count = 4
 
         # Upload many instances of the same test document.
-        for i in range(self.test_document_count):
+        for i in range(self._test_document_count):
             self._upload_test_document()
             self.grant_access(
-                obj=self.test_document, permission=permission_document_view
+                obj=self._test_document, permission=permission_document_view
             )
 
     def test_advanced_search_past_first_page(self):
-        test_document_label = self.test_documents[0].label
+        test_document_label = self._test_documents[0].label
 
         # Make sure all documents are returned by the search
         queryset = self.search_backend.search(
-            search_model=document_search,
+            search_model=search_model_document,
             query={'label': test_document_label},
             user=self._test_case_user
         )
-        self.assertEqual(queryset.count(), self.test_document_count)
+        self.assertEqual(queryset.count(), self._test_document_count)
 
         with self.settings(VIEWS_PAGINATE_BY=2):
             # Functional test for the first page of advanced results
             response = self._request_search_results_view(
                 data={'label': test_document_label}, kwargs={
-                    SEARCH_MODEL_NAME_KWARG: document_search.get_full_name()
+                    SEARCH_MODEL_NAME_KWARG: search_model_document.get_full_name()
                 }
             )
 
@@ -66,7 +66,7 @@ class AdvancedSearchViewTestCaseMixin(
             # Functional test for the second page of advanced results
             response = self._request_search_results_view(
                 data={'label': test_document_label, 'page': 2}, kwargs={
-                    SEARCH_MODEL_NAME_KWARG: document_search.get_full_name()
+                    SEARCH_MODEL_NAME_KWARG: search_model_document.get_full_name()
                 }
             )
             # Total (3 - 4 out of 4) (Page 2 of 2)
@@ -108,17 +108,17 @@ class WhooshAdvancedSearchViewTestCase(
 class SearchViewTestCaseMixin(DocumentTestMixin, SearchViewTestMixin):
     def test_result_view_with_search_mode_in_data(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         response = self._request_search_results_view(
             data={
-                'label': self.test_document.label,
-                '_{}'.format(SEARCH_MODEL_NAME_KWARG): document_search.get_full_name()
+                'label': self._test_document.label,
+                '_{}'.format(SEARCH_MODEL_NAME_KWARG): search_model_document.get_full_name()
             }
         )
         self.assertContains(
-            response=response, status_code=200, text=self.test_document.label
+            response=response, status_code=200, text=self._test_document.label
         )
 
 
@@ -150,16 +150,16 @@ class SearchToolsViewTestCaseMixin(
     def setUp(self):
         super().setUp()
 
-        self.document_search_model = SearchModel.get_for_model(
+        self.search_model_document_model = SearchModel.get_for_model(
             instance=DocumentSearchResult
         )
 
     def test_search_backend_reindex_view_no_permission(self):
         self.search_backend.reset(
-            search_model=self.document_search_model
+            search_model=self.search_model_document_model
         )
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         response = self._request_search_backend_reindex_view()
@@ -167,28 +167,28 @@ class SearchToolsViewTestCaseMixin(
 
     def test_search_backend_reindex_view_artifacts_no_permission(self):
         self.search_backend.reset(
-            search_model=self.document_search_model
+            search_model=self.search_model_document_model
         )
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         response = self._request_search_backend_reindex_view()
         self.assertEqual(response.status_code, 403)
 
         queryset = self.search_backend.search(
-            search_model=self.document_search_model,
-            query={QUERY_PARAMETER_ANY_FIELD: self.test_document.label},
+            search_model=self.search_model_document_model,
+            query={QUERY_PARAMETER_ANY_FIELD: self._test_document.label},
             user=self._test_case_user
         )
         self.assertEqual(queryset.count(), 0)
 
     def test_search_backend_reindex_view_with_permission(self):
         self.search_backend.reset(
-            search_model=self.document_search_model
+            search_model=self.search_model_document_model
         )
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
         self.grant_permission(permission=permission_search_tools)
 
@@ -197,10 +197,10 @@ class SearchToolsViewTestCaseMixin(
 
     def test_search_backend_reindex_view_artifacts_with_permission(self):
         self.search_backend.reset(
-            search_model=self.document_search_model
+            search_model=self.search_model_document_model
         )
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
         self.grant_permission(permission=permission_search_tools)
 
@@ -208,8 +208,8 @@ class SearchToolsViewTestCaseMixin(
         self.assertEqual(response.status_code, 302)
 
         queryset = self.search_backend.search(
-            search_model=self.document_search_model,
-            query={QUERY_PARAMETER_ANY_FIELD: self.test_document.label},
+            search_model=self.search_model_document_model,
+            query={QUERY_PARAMETER_ANY_FIELD: self._test_document.label},
             user=self._test_case_user
         )
         self.assertNotEqual(queryset.count(), 0)
