@@ -1,37 +1,56 @@
 from mayan.apps.appearance.classes import Icon
 
-icon_event_types_subscriptions_list = Icon(
-    driver_name='fontawesome', symbol='list-ol'
-)
-icon_event_types_subscriptions_list = Icon(
-    driver_name='fontawesome-dual', primary_symbol='list-ol',
-    secondary_symbol='rss'
-)
+# Clear
 
-
-icon_events_for_object = Icon(driver_name='fontawesome', symbol='list-ol')
-icon_events_for_object_clear = Icon(
+icon_event_list_clear = Icon(
     driver_name='fontawesome', symbol='broom'
 )
-icon_events_for_object_export = Icon(
-    driver_name='fontawesome', symbol='file-export'
-)
-icon_events_list = Icon(driver_name='fontawesome', symbol='list-ol')
-icon_events_list_clear = Icon(
+icon_object_event_list_clear = Icon(
     driver_name='fontawesome', symbol='broom'
 )
-icon_events_list_export = Icon(
+icon_verb_event_list_clear = Icon(
+    driver_name='fontawesome', symbol='broom'
+)
+
+# Export
+
+icon_event_list_export = Icon(
     driver_name='fontawesome', symbol='file-export'
 )
+icon_object_event_list_export = Icon(
+    driver_name='fontawesome', symbol='file-export'
+)
+icon_verb_event_list_export = Icon(
+    driver_name='fontawesome', symbol='file-export'
+)
+
+# List
+
+icon_event_list = Icon(driver_name='fontawesome', symbol='list-ol')
+icon_object_event_list = Icon(driver_name='fontawesome', symbol='list-ol')
+icon_verb_event_list = Icon(driver_name='fontawesome', symbol='list-ol')
+
+# Notifications
+
+icon_notification_list = Icon(
+    driver_name='fontawesome', symbol='bell'
+)
 icon_notification_mark_read = Icon(
     driver_name='fontawesome', symbol='eye'
 )
 icon_notification_mark_read_all = Icon(
     driver_name='fontawesome', symbol='eye'
 )
-icon_object_event_types_user_subscriptions_list = Icon(
+
+# Subscriptions
+
+icon_event_types_subscriptions_list = Icon(
+    driver_name='fontawesome-dual', primary_symbol='list-ol',
+    secondary_symbol='rss'
+)
+icon_object_event_type_user_subscription_list = Icon(
     driver_name='fontawesome', symbol='rss'
 )
-icon_user_notifications_list = Icon(
-    driver_name='fontawesome', symbol='bell'
+icon_user_object_subscriptions_list = Icon(
+    driver_name='fontawesome', symbol='rss'
 )
