@@ -1,8 +1,8 @@
 from actstream.models import Action
-from rest_framework import serializers
 from rest_framework.reverse import reverse
 
 from mayan.apps.common.serializers import ContentTypeSerializer
+from mayan.apps.rest_api import serializers
 from mayan.apps.rest_api.fields import DynamicSerializerField
 from mayan.apps.user_management.serializers import UserSerializer
 
@@ -45,10 +45,10 @@ class EventTypeSerializer(serializers.Serializer):
         if isinstance(instance, EventType):
             return super().to_representation(instance=instance)
         elif isinstance(instance, StoredEventType):
-            return super().to_representation(instance=instance.get_class())
+            return super().to_representation(instance=instance.event_type)
         elif isinstance(instance, str):
             return super().to_representation(
-                instance=EventType.get(name=instance)
+                instance=EventType.get(id=instance)
             )
 
 
