@@ -58,16 +58,16 @@ class ObjectEventAPITestCase(
 
     def setUp(self):
         super().setUp()
-        self.test_object = self.test_document_type
+        self._test_object = self._test_document_type
 
         content_type = ContentType.objects.get_for_model(
-            model=self.test_object
+            model=self._test_object
         )
 
         self.view_arguments = {
             'app_label': content_type.app_label,
             'model_name': content_type.model,
-            'object_id': self.test_object.pk
+            'object_id': self._test_object.pk
         }
 
     def test_object_event_list_api_view_no_permission(self):
@@ -78,7 +78,7 @@ class ObjectEventAPITestCase(
 
     def test_object_event_list_api_view_with_access(self):
         self.grant_access(
-            obj=self.test_object, permission=permission_events_view
+            obj=self._test_object, permission=permission_events_view
         )
         response = self._request_object_event_list_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
