@@ -21,49 +21,49 @@ class EventClearViewTestCase(
         super().setUp()
         self._create_test_event_type()
         self._create_test_user()
-        self.test_object = self.test_document_type
+        self._test_object = self._test_document_type
 
         content_type = ContentType.objects.get_for_model(
-            model=self.test_object
+            model=self._test_object
         )
 
         self.view_arguments = {
             'app_label': content_type.app_label,
             'model_name': content_type.model,
-            'object_id': self.test_object.pk
+            'object_id': self._test_object.pk
         }
 
         ModelPermission.register(
-            model=self.test_object._meta.model, permissions=(
+            model=self._test_object._meta.model, permissions=(
                 permission_events_clear,
             )
         )
 
         self._clear_events()
 
-    def test_events_list_clear_view_no_permission(self):
+    def test_event_list_clear_view_no_permission(self):
         self._clear_events()
 
-        self._create_test_event(target=self.test_object)
+        self._create_test_event(target=self._test_object)
 
-        response = self._request_test_events_list_clear_view()
+        response = self._request_test_event_list_clear_view()
         self.assertEqual(response.status_code, 302)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0], self.test_event)
+        self.assertEqual(events[0], self._test_event)
 
-    def test_events_list_clear_view_with_access(self):
+    def test_event_list_clear_view_with_access(self):
         self.grant_access(
-            obj=self.test_object, permission=permission_events_clear
+            obj=self._test_object, permission=permission_events_clear
         )
 
         self._clear_events()
 
-        self._create_test_event(target=self.test_object)
+        self._create_test_event(target=self._test_object)
 
-        response = self._request_test_events_list_clear_view()
+        response = self._request_test_event_list_clear_view()
         self.assertEqual(response.status_code, 302)
 
         events = self._get_test_events()
@@ -74,33 +74,33 @@ class EventClearViewTestCase(
         self.assertEqual(events[0].target, self._test_case_user)
         self.assertEqual(events[0].verb, event_events_cleared.id)
 
-    def test_events_for_object_clear_view_no_permission(self):
+    def test_object_event_list_clear_view_no_permission(self):
         self._clear_events()
 
         self._create_test_event(
-            actor=self.test_user, action_object=self.test_object
+            actor=self._test_user, action_object=self._test_object
         )
 
-        response = self._request_events_for_object_clear_view()
+        response = self._request_object_event_list_clear_view()
         self.assertEqual(response.status_code, 302)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0], self.test_event)
+        self.assertEqual(events[0], self._test_event)
 
-    def test_events_for_object_clear_view_with_access(self):
+    def test_object_event_list_clear_view_with_access(self):
         self.grant_access(
-            obj=self.test_object, permission=permission_events_clear
+            obj=self._test_object, permission=permission_events_clear
         )
 
         self._clear_events()
 
         self._create_test_event(
-            actor=self.test_user, action_object=self.test_object
+            actor=self._test_user, action_object=self._test_object
         )
 
-        response = self._request_events_for_object_clear_view()
+        response = self._request_object_event_list_clear_view()
         self.assertEqual(response.status_code, 302)
 
         events = self._get_test_events()
@@ -108,36 +108,36 @@ class EventClearViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_object)
+        self.assertEqual(events[0].target, self._test_object)
         self.assertEqual(events[0].verb, event_events_cleared.id)
 
-    def test_events_by_verb_clear_view_no_permission(self):
+    def test_verb_event_list_clear_view_no_permission(self):
         self._clear_events()
 
         self._create_test_event(
-            actor=self.test_user, action_object=self.test_object
+            actor=self._test_user, action_object=self._test_object
         )
 
-        response = self._request_test_events_by_verb_clear_view()
+        response = self._request_test_verb_event_list_clear_view()
         self.assertEqual(response.status_code, 302)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0], self.test_event)
+        self.assertEqual(events[0], self._test_event)
 
-    def test_events_by_verb_view_clear_with_access(self):
+    def test_verb_event_list_view_clear_with_access(self):
         self.grant_access(
-            obj=self.test_object, permission=permission_events_clear
+            obj=self._test_object, permission=permission_events_clear
         )
 
         self._clear_events()
 
         self._create_test_event(
-            actor=self.test_user, action_object=self.test_object
+            actor=self._test_user, action_object=self._test_object
         )
 
-        response = self._request_test_events_by_verb_clear_view()
+        response = self._request_test_verb_event_list_clear_view()
         self.assertEqual(response.status_code, 302)
 
         events = self._get_test_events()
@@ -159,45 +159,45 @@ class CurrentUserEventClearViewTestCase(
         super().setUp()
         self._create_test_event_type()
         self._create_test_user()
-        self.test_object = self._test_case_user
+        self._test_object = self._test_case_user
 
         content_type = ContentType.objects.get_for_model(
-            model=self.test_object
+            model=self._test_object
         )
 
         self.view_arguments = {
             'app_label': content_type.app_label,
             'model_name': content_type.model,
-            'object_id': self.test_object.pk
+            'object_id': self._test_object.pk
         }
 
     def test_current_user_events_clear_view_no_permission(self):
         self._clear_events()
 
         self._create_test_event(
-            actor=self._test_case_user, action_object=self.test_object
+            actor=self._test_case_user, action_object=self._test_object
         )
 
-        response = self._request_events_for_object_clear_view()
+        response = self._request_object_event_list_clear_view()
         self.assertEqual(response.status_code, 302)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0], self.test_event)
+        self.assertEqual(events[0], self._test_event)
 
     def test_current_user_events_clear_view_with_access(self):
         self.grant_access(
-            obj=self.test_object, permission=permission_events_clear
+            obj=self._test_object, permission=permission_events_clear
         )
 
         self._clear_events()
 
         self._create_test_event(
-            actor=self._test_case_user, action_object=self.test_object
+            actor=self._test_case_user, action_object=self._test_object
         )
 
-        response = self._request_events_for_object_clear_view()
+        response = self._request_object_event_list_clear_view()
         self.assertEqual(response.status_code, 302)
 
         events = self._get_test_events()
