@@ -1,13 +1,11 @@
 from django.contrib.contenttypes.models import ContentType
 
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
-from mayan.apps.testing.tests.base import GenericViewTestCase
 
 from ..permissions import permission_events_view
 
 from .mixins import (
-    EventTestMixin, EventTypeTestMixin, EventViewTestMixin,
-    UserEventViewsTestMixin
+    EventTestMixin, EventTypeTestMixin, EventViewTestMixin
 )
 
 
@@ -21,22 +19,22 @@ class EventsViewTestCase(
         super().setUp()
         self._create_test_event_type()
         self._create_test_user()
-        self.test_object = self.test_document_type
+        self._test_object = self._test_document_type
 
         content_type = ContentType.objects.get_for_model(
-            model=self.test_object
+            model=self._test_object
         )
 
         self.view_arguments = {
             'app_label': content_type.app_label,
             'model_name': content_type.model,
-            'object_id': self.test_object.pk
+            'object_id': self._test_object.pk
         }
 
     def test_event_list_view_no_permission(self):
-        self._create_test_event(target=self.test_object)
+        self._create_test_event(target=self._test_object)
 
-        response = self._request_test_events_list_view()
+        response = self._request_test_event_list_view()
 
         self.assertNotContains(
             response=response, status_code=200,
@@ -44,68 +42,68 @@ class EventsViewTestCase(
         )
 
     def test_event_list_view_with_access(self):
-        self._create_test_event(target=self.test_object)
+        self._create_test_event(target=self._test_object)
 
         self.grant_access(
-            obj=self.test_object, permission=permission_events_view
+            obj=self._test_object, permission=permission_events_view
         )
 
-        response = self._request_test_events_list_view()
+        response = self._request_test_event_list_view()
 
         self.assertContains(
             response=response, status_code=200,
             text=self._test_event_type.label
         )
 
-    def test_events_for_object_view_no_permission(self):
+    def test_object_event_list_view_no_permission(self):
         self._create_test_event(
-            actor=self.test_user, action_object=self.test_object
+            actor=self._test_user, action_object=self._test_object
         )
 
-        response = self._request_events_for_object_view()
+        response = self._request_test_object_event_list_view()
         self.assertNotContains(
             response=response, status_code=200,
             text=self._test_event_type.label
         )
 
-    def test_events_for_object_view_with_access(self):
+    def test_object_event_list_view_with_access(self):
         self._create_test_event(
-            actor=self.test_user, action_object=self.test_object
+            actor=self._test_user, action_object=self._test_object
         )
 
         self.grant_access(
-            obj=self.test_object, permission=permission_events_view
+            obj=self._test_object, permission=permission_events_view
         )
 
-        response = self._request_events_for_object_view()
+        response = self._request_test_object_event_list_view()
         self.assertContains(
             response=response, status_code=200,
             text=self._test_event_type.label
         )
 
-    def test_events_by_verb_view_no_permission(self):
+    def test_verb_event_list_view_no_permission(self):
         self._create_test_event(
-            actor=self.test_user, action_object=self.test_object
+            actor=self._test_user, action_object=self._test_object
         )
 
-        response = self._request_test_events_by_verb_view()
+        response = self._request_test_verb_event_list_view()
         self.assertContains(
-            count=3, response=response, status_code=200,
+            count=2, response=response, status_code=200,
             text=self._test_event_type.label
         )
 
-    def test_events_by_verb_view_with_access(self):
+    def test_verb_event_list_view_with_access(self):
         self._create_test_event(
-            actor=self.test_user, action_object=self.test_object
+            actor=self._test_user, action_object=self._test_object
         )
 
         self.grant_access(
-            obj=self.test_object, permission=permission_events_view
+            obj=self._test_object, permission=permission_events_view
         )
 
-        response = self._request_test_events_by_verb_view()
+        response = self._request_test_verb_event_list_view()
         self.assertContains(
-            count=4, response=response, status_code=200,
+            count=3, response=response, status_code=200,
             text=self._test_event_type.label
         )
 
@@ -120,24 +118,24 @@ class CurrentUserEventsViewTestCase(
         super().setUp()
         self._create_test_event_type()
         self._create_test_user()
-        self.test_object = self._test_case_user
+        self._test_object = self._test_case_user
 
         content_type = ContentType.objects.get_for_model(
-            model=self.test_object
+            model=self._test_object
         )
 
         self.view_arguments = {
             'app_label': content_type.app_label,
             'model_name': content_type.model,
-            'object_id': self.test_object.pk
+            'object_id': self._test_object.pk
         }
 
     def test_current_user_events_view_no_permission(self):
         self._create_test_event(
-            actor=self._test_case_user, action_object=self.test_object
+            actor=self._test_case_user, action_object=self._test_object
         )
 
-        response = self._request_events_for_object_view()
+        response = self._request_test_object_event_list_view()
         self.assertNotContains(
             response=response, status_code=200,
             text=self._test_event_type.label
@@ -145,21 +143,15 @@ class CurrentUserEventsViewTestCase(
 
     def test_current_user_events_view_with_access(self):
         self._create_test_event(
-            actor=self._test_case_user, action_object=self.test_object
+            actor=self._test_case_user, action_object=self._test_object
         )
 
         self.grant_access(
             obj=self._test_case_user, permission=permission_events_view
         )
 
-        response = self._request_events_for_object_view()
+        response = self._request_test_object_event_list_view()
         self.assertContains(
             response=response, status_code=200,
             text=self._test_event_type.label
         )
-
-
-class UserEventViewsTestCase(UserEventViewsTestMixin, GenericViewTestCase):
-    def test_user_event_type_subscription_list_view(self):
-        response = self._request_test_user_event_type_subscription_list_view()
-        self.assertEqual(response.status_code, 200)
