@@ -6,7 +6,6 @@ from mayan.apps.common.classes import PropertyHelper
 
 from .events import event_file_metadata_document_file_finished
 from .exceptions import FileMetadataDriverError
-from .signals import signal_post_document_file_file_metadata_processing
 
 logger = logging.getLogger(name=__name__)
 
@@ -41,11 +40,6 @@ class FileMetadataDriver:
 
                 driver.process(document_file=document_file)
 
-                signal_post_document_file_file_metadata_processing.send(
-                    sender=document_file.__class__,
-                    instance=document_file
-                )
-
                 event_file_metadata_document_file_finished.commit(
                     action_object=document_file.document, actor=user,
                     target=document_file
