@@ -1,19 +1,9 @@
 from django.apps import apps
 
-from mayan.apps.document_indexing.tasks import task_index_instance_document_add
-
 from .settings import setting_auto_process
 
 
-def handler_index_document_file(sender, **kwargs):
-    task_index_instance_document_add.apply_async(
-        kwargs={
-            'document_id': kwargs['instance'].document.pk
-        }
-    )
-
-
-def handler_initialize_new_document_type_settings(sender, instance, **kwargs):
+def handler_initialize_new_document_type_file_metadata_settings(sender, instance, **kwargs):
     DocumentTypeSettings = apps.get_model(
         app_label='file_metadata', model_name='DocumentTypeSettings'
     )
@@ -24,6 +14,6 @@ def handler_initialize_new_document_type_settings(sender, instance, **kwargs):
         )
 
 
-def handler_process_document_file(sender, instance, **kwargs):
+def process_document_file_metadata(sender, instance, **kwargs):
     if instance.document.document_type.file_metadata_settings.auto_process:
         instance.submit_for_file_metadata_processing()
