@@ -1,6 +1,5 @@
 from django.utils.translation import ugettext_lazy as _
 
-from rest_framework import serializers
 from rest_framework.reverse import reverse
 
 from mayan.apps.documents.models import DocumentType
@@ -8,6 +7,7 @@ from mayan.apps.documents.permissions import permission_document_type_edit
 from mayan.apps.documents.serializers.document_serializers import (
     DocumentSerializer
 )
+from mayan.apps.rest_api import serializers
 from mayan.apps.rest_api.relations import (
     FilteredPrimaryKeyRelatedField, MultiKwargHyperlinkedIdentityField
 )
@@ -37,10 +37,11 @@ class SmartLinkConditionSerializer(serializers.HyperlinkedModelSerializer):
     class Meta:
         fields = (
             'enabled', 'expression', 'foreign_document_data', 'inclusion',
-            'id', 'negated', 'operator', 'smart_link_url', 'url'
+            'id', 'negated', 'operator', 'smart_link_id', 'smart_link_url',
+            'url'
         )
         model = SmartLinkCondition
-        read_only_fields = ('id', 'url')
+        read_only_fields = ('id', 'smart_link_id', 'smart_link_url', 'url')
 
 
 class SmartLinkDocumentTypeAddSerializer(serializers.Serializer):
