@@ -3,7 +3,7 @@ from rest_framework import status
 from mayan.apps.documents.permissions import (
     permission_document_type_edit, permission_document_type_view
 )
-from mayan.apps.documents.tests.base import DocumentTestMixin
+from mayan.apps.documents.tests.mixins.document_mixins import DocumentTestMixin
 from mayan.apps.rest_api.tests.base import BaseAPITestCase
 
 from ..events import event_smart_link_created, event_smart_link_edited
@@ -54,7 +54,7 @@ class SmartLinkAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_smart_link)
+        self.assertEqual(events[0].target, self._test_smart_link)
         self.assertEqual(events[0].verb, event_smart_link_created.id)
 
     def test_smart_link_delete_api_view_no_permission(self):
@@ -73,7 +73,7 @@ class SmartLinkAPIViewTestCase(
     def test_smart_link_delete_api_view_with_access(self):
         self._create_test_smart_link()
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_delete
+            obj=self._test_smart_link, permission=permission_smart_link_delete
         )
 
         self._clear_events()
@@ -102,7 +102,7 @@ class SmartLinkAPIViewTestCase(
     def test_smart_link_detail_api_view_with_access(self):
         self._create_test_smart_link()
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_view
+            obj=self._test_smart_link, permission=permission_smart_link_view
         )
 
         self._clear_events()
@@ -125,8 +125,8 @@ class SmartLinkAPIViewTestCase(
         response = self._request_test_smart_link_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_smart_link.refresh_from_db()
-        self.assertEqual(self.test_smart_link.label, TEST_SMART_LINK_LABEL)
+        self._test_smart_link.refresh_from_db()
+        self.assertEqual(self._test_smart_link.label, TEST_SMART_LINK_LABEL)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -134,7 +134,7 @@ class SmartLinkAPIViewTestCase(
     def test_smart_link_edit_api_view_via_patch_with_access(self):
         self._create_test_smart_link()
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_edit
+            obj=self._test_smart_link, permission=permission_smart_link_edit
         )
 
         self._clear_events()
@@ -142,9 +142,9 @@ class SmartLinkAPIViewTestCase(
         response = self._request_test_smart_link_edit_patch_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
         self.assertEqual(
-            self.test_smart_link.label, TEST_SMART_LINK_LABEL_EDITED
+            self._test_smart_link.label, TEST_SMART_LINK_LABEL_EDITED
         )
 
         events = self._get_test_events()
@@ -152,7 +152,7 @@ class SmartLinkAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_smart_link)
+        self.assertEqual(events[0].target, self._test_smart_link)
         self.assertEqual(events[0].verb, event_smart_link_edited.id)
 
     def test_smart_link_edit_api_view_via_put_no_permission(self):
@@ -163,8 +163,8 @@ class SmartLinkAPIViewTestCase(
         response = self._request_test_smart_link_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_smart_link.refresh_from_db()
-        self.assertEqual(self.test_smart_link.label, TEST_SMART_LINK_LABEL)
+        self._test_smart_link.refresh_from_db()
+        self.assertEqual(self._test_smart_link.label, TEST_SMART_LINK_LABEL)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -172,7 +172,7 @@ class SmartLinkAPIViewTestCase(
     def test_smart_link_edit_api_view_via_put_with_access(self):
         self._create_test_smart_link()
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_edit
+            obj=self._test_smart_link, permission=permission_smart_link_edit
         )
 
         self._clear_events()
@@ -180,9 +180,9 @@ class SmartLinkAPIViewTestCase(
         response = self._request_test_smart_link_edit_put_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
         self.assertEqual(
-            self.test_smart_link.label, TEST_SMART_LINK_LABEL_EDITED
+            self._test_smart_link.label, TEST_SMART_LINK_LABEL_EDITED
         )
 
         events = self._get_test_events()
@@ -190,7 +190,7 @@ class SmartLinkAPIViewTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_smart_link)
+        self.assertEqual(events[0].target, self._test_smart_link)
         self.assertEqual(events[0].verb, event_smart_link_edited.id)
 
     def test_smart_link_list_api_view_no_permission(self):
@@ -208,7 +208,7 @@ class SmartLinkAPIViewTestCase(
     def test_smart_link_list_api_view_with_access(self):
         self._create_test_smart_link()
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_view
+            obj=self._test_smart_link, permission=permission_smart_link_view
         )
 
         self._clear_events()
@@ -217,7 +217,7 @@ class SmartLinkAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
             response.data['results'][0]['id'],
-            self.test_smart_link.pk
+            self._test_smart_link.pk
         )
 
         events = self._get_test_events()
@@ -233,21 +233,21 @@ class SmartLinkDocumentTypeAPIViewTestCase(
     def test_smart_link_document_type_add_api_view_no_permission(self):
         self._create_test_smart_link()
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
 
-        test_smart_link_document_types_count = self.test_smart_link.document_types.count()
+        test_smart_link_document_types_count = self._test_smart_link.document_types.count()
 
         self._clear_events()
 
         response = self._request_test_smart_link_document_type_add_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
 
         self.assertEqual(
-            self.test_smart_link.document_types.count(),
+            self._test_smart_link.document_types.count(),
             test_smart_link_document_types_count
         )
 
@@ -257,21 +257,21 @@ class SmartLinkDocumentTypeAPIViewTestCase(
     def test_smart_link_document_type_add_api_view_with_document_type_access(self):
         self._create_test_smart_link()
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
 
-        test_smart_link_document_types_count = self.test_smart_link.document_types.count()
+        test_smart_link_document_types_count = self._test_smart_link.document_types.count()
 
         self._clear_events()
 
         response = self._request_test_smart_link_document_type_add_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
 
         self.assertEqual(
-            self.test_smart_link.document_types.count(),
+            self._test_smart_link.document_types.count(),
             test_smart_link_document_types_count
         )
 
@@ -282,20 +282,20 @@ class SmartLinkDocumentTypeAPIViewTestCase(
         self._create_test_smart_link()
 
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_edit
+            obj=self._test_smart_link, permission=permission_smart_link_edit
         )
 
-        test_smart_link_document_types_count = self.test_smart_link.document_types.count()
+        test_smart_link_document_types_count = self._test_smart_link.document_types.count()
 
         self._clear_events()
 
         response = self._request_test_smart_link_document_type_add_api_view()
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
 
         self.assertEqual(
-            self.test_smart_link.document_types.count(),
+            self._test_smart_link.document_types.count(),
             test_smart_link_document_types_count
         )
 
@@ -305,38 +305,38 @@ class SmartLinkDocumentTypeAPIViewTestCase(
     def test_smart_link_document_type_add_api_view_with_full_access(self):
         self._create_test_smart_link()
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_edit
+            obj=self._test_smart_link, permission=permission_smart_link_edit
         )
 
-        test_smart_link_document_types_count = self.test_smart_link.document_types.count()
+        test_smart_link_document_types_count = self._test_smart_link.document_types.count()
 
         self._clear_events()
 
         response = self._request_test_smart_link_document_type_add_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
 
         self.assertEqual(
-            self.test_smart_link.document_types.count(),
+            self._test_smart_link.document_types.count(),
             test_smart_link_document_types_count + 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_smart_link)
+        self.assertEqual(events[0].target, self._test_smart_link)
         self.assertEqual(events[0].verb, event_smart_link_edited.id)
 
     def test_smart_link_document_type_list_api_view_no_permission(self):
         self._create_test_smart_link()
-        self.test_smart_link.document_types.add(self.test_document_type)
+        self._test_smart_link.document_types.add(self._test_document_type)
 
         self._clear_events()
 
@@ -348,10 +348,10 @@ class SmartLinkDocumentTypeAPIViewTestCase(
 
     def test_smart_link_document_type_list_api_view_with_document_type_access(self):
         self._create_test_smart_link()
-        self.test_smart_link.document_types.add(self.test_document_type)
+        self._test_smart_link.document_types.add(self._test_document_type)
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_view
         )
 
@@ -365,10 +365,10 @@ class SmartLinkDocumentTypeAPIViewTestCase(
 
     def test_smart_link_document_type_list_api_view_with_smart_link_access(self):
         self._create_test_smart_link()
-        self.test_smart_link.document_types.add(self.test_document_type)
+        self._test_smart_link.document_types.add(self._test_document_type)
 
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_view
+            obj=self._test_smart_link, permission=permission_smart_link_view
         )
 
         self._clear_events()
@@ -382,14 +382,14 @@ class SmartLinkDocumentTypeAPIViewTestCase(
 
     def test_smart_link_document_type_list_api_view_with_full_access(self):
         self._create_test_smart_link()
-        self.test_smart_link.document_types.add(self.test_document_type)
+        self._test_smart_link.document_types.add(self._test_document_type)
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_view
         )
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_view
+            obj=self._test_smart_link, permission=permission_smart_link_view
         )
 
         self._clear_events()
@@ -398,7 +398,7 @@ class SmartLinkDocumentTypeAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
             response.data['results'][0]['id'],
-            self.test_document_type.pk
+            self._test_document_type.pk
         )
 
         events = self._get_test_events()
@@ -407,21 +407,21 @@ class SmartLinkDocumentTypeAPIViewTestCase(
     def test_smart_link_document_type_remove_api_view_no_permission(self):
         self._create_test_smart_link(add_test_document_type=True)
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
 
-        test_smart_link_document_types_count = self.test_smart_link.document_types.count()
+        test_smart_link_document_types_count = self._test_smart_link.document_types.count()
 
         self._clear_events()
 
         response = self._request_test_smart_link_document_type_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
 
         self.assertEqual(
-            self.test_smart_link.document_types.count(),
+            self._test_smart_link.document_types.count(),
             test_smart_link_document_types_count
         )
 
@@ -431,21 +431,21 @@ class SmartLinkDocumentTypeAPIViewTestCase(
     def test_smart_link_document_type_remove_api_view_with_document_type_access(self):
         self._create_test_smart_link(add_test_document_type=True)
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
 
-        test_smart_link_document_types_count = self.test_smart_link.document_types.count()
+        test_smart_link_document_types_count = self._test_smart_link.document_types.count()
 
         self._clear_events()
 
         response = self._request_test_smart_link_document_type_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
 
         self.assertEqual(
-            self.test_smart_link.document_types.count(),
+            self._test_smart_link.document_types.count(),
             test_smart_link_document_types_count
         )
 
@@ -456,20 +456,20 @@ class SmartLinkDocumentTypeAPIViewTestCase(
         self._create_test_smart_link(add_test_document_type=True)
 
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_edit
+            obj=self._test_smart_link, permission=permission_smart_link_edit
         )
 
-        test_smart_link_document_types_count = self.test_smart_link.document_types.count()
+        test_smart_link_document_types_count = self._test_smart_link.document_types.count()
 
         self._clear_events()
 
         response = self._request_test_smart_link_document_type_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
 
         self.assertEqual(
-            self.test_smart_link.document_types.count(),
+            self._test_smart_link.document_types.count(),
             test_smart_link_document_types_count
         )
 
@@ -479,31 +479,31 @@ class SmartLinkDocumentTypeAPIViewTestCase(
     def test_smart_link_document_type_remove_api_view_with_full_access(self):
         self._create_test_smart_link(add_test_document_type=True)
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
         self.grant_access(
-            obj=self.test_smart_link, permission=permission_smart_link_edit
+            obj=self._test_smart_link, permission=permission_smart_link_edit
         )
 
-        test_smart_link_document_types_count = self.test_smart_link.document_types.count()
+        test_smart_link_document_types_count = self._test_smart_link.document_types.count()
 
         self._clear_events()
 
         response = self._request_test_smart_link_document_type_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_smart_link.refresh_from_db()
+        self._test_smart_link.refresh_from_db()
 
         self.assertEqual(
-            self.test_smart_link.document_types.count(),
+            self._test_smart_link.document_types.count(),
             test_smart_link_document_types_count - 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_smart_link)
+        self.assertEqual(events[0].target, self._test_smart_link)
         self.assertEqual(events[0].verb, event_smart_link_edited.id)
