@@ -2,6 +2,6 @@ DEFAULT_LOCK_MANAGER_BACKEND = 'mayan.apps.lock_manager.backends.file_lock.FileL
 DEFAULT_LOCK_MANAGER_BACKEND_ARGUMENTS = {}
 DEFAULT_LOCK_MANAGER_DEFAULT_LOCK_TIMEOUT = 30
 
-PURGE_LOCKS_COMMAND = 'purgelocks'
+PURGE_LOCKS_COMMAND = 'lock_manager_purge_locks'
 
 TEST_LOCK_NAME = '_mayan_test_lock'
