@@ -1,12 +1,18 @@
 from mayan.apps.appearance.classes import Icon
 
+icon_global_error_log_entry_list = Icon(
+    driver_name='fontawesome', symbol='exclamation-triangle'
+)
 icon_object_errors = Icon(
     driver_name='fontawesome', symbol='exclamation-triangle'
 )
-icon_object_error_list = Icon(
+icon_object_error_log_entry_delete = Icon(
+    driver_name='fontawesome', symbol='times'
+)
+icon_object_error_log_entry_list = Icon(
     driver_name='fontawesome', symbol='exclamation-triangle'
 )
-icon_object_error_list_clear = Icon(
+icon_object_error_log_entry_list_clear = Icon(
     driver_name='fontawesome-dual', primary_symbol='exclamation-triangle',
     secondary_symbol='times'
 )
