@@ -5,31 +5,31 @@ from django.db.models import Q
 from ..models import UserMailer
 
 from .literals import (
-    TEST_EMAIL_ADDRESS, TEST_EMAIL_FROM_ADDRESS,
-    TEST_USER_MAILER_BACKEND_PATH, TEST_USER_MAILER_LABEL
+    TEST_EMAIL_ADDRESS, TEST_EMAIL_FROM_ADDRESS, TEST_USER_MAILER_LABEL
 )
+from .mailers import TestBackend
 
 
 class DocumentMailerViewTestMixin:
-    def _request_test_document_send_link_single_view(self):
+    def _request_test_document_link_send_single_view(self):
         return self.post(
             viewname='mailer:send_document_link_single', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             },
         )
 
-    def _request_test_document_send_link_multiple_view(self):
+    def _request_test_document_link_send_multiple_view(self):
         return self.post(
             viewname='mailer:send_document_link_multiple', query={
-                'id_list': self.test_document.pk
+                'id_list': self._test_document.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             },
@@ -37,25 +37,25 @@ class DocumentMailerViewTestMixin:
 
 
 class DocumentFileMailerViewTestMixin:
-    def _request_test_document_file_send_link_single_view(self):
+    def _request_test_document_file_link_send_single_view(self):
         return self.post(
             viewname='mailer:send_document_file_link_single', kwargs={
-                'document_file_id': self.test_document_file.pk
+                'document_file_id': self._test_document_file.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             }
         )
 
-    def _request_test_document_file_send_link_multiple_view(self):
+    def _request_test_document_file_link_send_multiple_view(self):
         return self.post(
             viewname='mailer:send_document_file_link_multiple', query={
-                'id_list': self.test_document_file.pk
+                'id_list': self._test_document_file.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             }
@@ -64,10 +64,10 @@ class DocumentFileMailerViewTestMixin:
     def _request_test_document_file_attachment_send_single_view(self):
         return self.post(
             viewname='mailer:send_document_file_attachment_single', kwargs={
-                'document_file_id': self.test_document_file.pk
+                'document_file_id': self._test_document_file.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             }
@@ -76,10 +76,10 @@ class DocumentFileMailerViewTestMixin:
     def _request_test_document_file_attachment_send_multiple_view(self):
         return self.post(
             viewname='mailer:send_document_file_attachment_multiple', query={
-                'id_list': self.test_document_file.pk
+                'id_list': self._test_document_file.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             }
@@ -87,25 +87,25 @@ class DocumentFileMailerViewTestMixin:
 
 
 class DocumentVersionMailerViewTestMixin:
-    def _request_test_document_version_send_link_single_view(self):
+    def _request_test_document_version_link_send_single_view(self):
         return self.post(
             viewname='mailer:send_document_version_link_single', kwargs={
-                'document_version_id': self.test_document_version.pk
+                'document_version_id': self._test_document_version.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             },
         )
 
-    def _request_test_document_version_send_link_multiple_view(self):
+    def _request_test_document_version_link_send_multiple_view(self):
         return self.post(
             viewname='mailer:send_document_version_link_multiple', query={
-                'id_list': self.test_document_version.pk
+                'id_list': self._test_document_version.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             },
@@ -115,10 +115,10 @@ class DocumentVersionMailerViewTestMixin:
         return self.post(
             viewname='mailer:send_document_version_attachment_single',
             kwargs={
-                'document_version_id': self.test_document_version.pk
+                'document_version_id': self._test_document_version.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             }
@@ -128,10 +128,10 @@ class DocumentVersionMailerViewTestMixin:
         return self.post(
             viewname='mailer:send_document_version_attachment_multiple',
             query={
-                'id_list': self.test_document_version.pk
+                'id_list': self._test_document_version.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 ),
                 'user_mailer': self._test_user_mailer.pk
             }
@@ -144,7 +144,7 @@ class MailerTestMixin:
             default=True,
             enabled=True,
             label=TEST_USER_MAILER_LABEL,
-            backend_path=TEST_USER_MAILER_BACKEND_PATH,
+            backend_path=TestBackend.backend_id,
             backend_data=json.dumps(
                 obj={
                     'from': TEST_EMAIL_FROM_ADDRESS
@@ -159,7 +159,7 @@ class MailerViewTestMixin:
 
         response = self.post(
             viewname='mailer:user_mailer_create', kwargs={
-                'class_path': TEST_USER_MAILER_BACKEND_PATH
+                'class_path': TestBackend.backend_id
             }, data={
                 'default': True,
                 'enabled': True,
@@ -210,7 +210,7 @@ class MailerViewTestMixin:
                 'mailer_id': self._test_user_mailer.pk
             }, data={
                 'email': getattr(
-                    self, 'test_email_address', TEST_EMAIL_ADDRESS
+                    self, '_test_email_address', TEST_EMAIL_ADDRESS
                 )
             }
         )
