@@ -8,4 +8,4 @@ class MailerCopyTestCase(MailerTestMixin, ObjectCopyTestMixin, BaseTestCase):
     def setUp(self):
         super().setUp()
         self._create_test_user_mailer()
-        self.test_object = self._test_user_mailer
+        self._test_object = self._test_user_mailer
