@@ -2,6 +2,7 @@ from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.documents.models import Document
 
+from ..icons import icon_document_link_send_single
 from ..permissions import permission_send_document_link
 
 from .base import ObjectLinkMailView
@@ -18,3 +19,4 @@ class MailDocumentLinkView(ObjectLinkMailView):
     title = 'Email document link'
     title_plural = 'Email document links'
     title_document = 'Email link for document: %s'
+    view_icon = icon_document_link_send_single
