@@ -3,13 +3,14 @@ import logging
 from django.utils.translation import ugettext_lazy as _
 
 from mayan.apps.acls.classes import ModelPermission
-from mayan.apps.acls.permissions import permission_acl_edit, permission_acl_view
+from mayan.apps.acls.permissions import (
+    permission_acl_edit, permission_acl_view
+)
 from mayan.apps.common.apps import MayanAppConfig
 from mayan.apps.common.menus import (
     menu_multi_item, menu_object, menu_secondary, menu_topbar
 )
 from mayan.apps.events.classes import EventModelRegistry, ModelEventType
-from mayan.apps.events.permissions import permission_events_view
 from mayan.apps.navigation.classes import SourceColumn
 from mayan.apps.views.html_widgets import TwoStateWidget
 
@@ -21,7 +22,10 @@ from .links import (
     link_message_multiple_mark_unread, link_message_single_mark_read,
     link_message_single_mark_unread
 )
-from .permissions import permission_message_delete, permission_message_view
+from .permissions import (
+    permission_message_delete, permission_message_edit,
+    permission_message_view
+)
 
 logger = logging.getLogger(name=__name__)
 
@@ -29,7 +33,7 @@ logger = logging.getLogger(name=__name__)
 class MessagingApp(MayanAppConfig):
     app_namespace = 'messaging'
     app_url = 'messaging'
-    has_rest_api = False
+    has_rest_api = True
     has_tests = True
     name = 'mayan.apps.messaging'
     verbose_name = _('Messaging')
@@ -48,7 +52,7 @@ class MessagingApp(MayanAppConfig):
         ModelPermission.register(
             model=Message, permissions=(
                 permission_acl_edit, permission_acl_view,
-                permission_events_view, permission_message_delete,
+                permission_message_delete, permission_message_edit,
                 permission_message_view
             )
         )
@@ -92,5 +96,5 @@ class MessagingApp(MayanAppConfig):
         )
 
         menu_topbar.bind_links(
-            links=(link_message_list,), position=99
+            links=(link_message_list,), position=40
         )
