@@ -7,4 +7,4 @@ class MessageModelTestCase(MessageTestMixin, BaseTestCase):
     def test_method_get_absolute_url(self):
         self._create_test_message()
 
-        self.assertTrue(self.test_message.get_absolute_url())
+        self.assertTrue(self._test_message.get_absolute_url())
