@@ -18,19 +18,19 @@ permission_document_metadata_view = namespace.add_permission(
     label=_('View metadata from a document'), name='metadata_document_view'
 )
 
-setup_namespace = PermissionNamespace(
-    label=_('Metadata setup'), name='metadata_setup'
+metadata_type_namespace = PermissionNamespace(
+    label=_('Metadata types'), name='metadata_setup'
 )
 
-permission_metadata_type_edit = setup_namespace.add_permission(
+permission_metadata_type_edit = metadata_type_namespace.add_permission(
     label=_('Edit metadata types'), name='metadata_type_edit'
 )
-permission_metadata_type_create = setup_namespace.add_permission(
+permission_metadata_type_create = metadata_type_namespace.add_permission(
     label=_('Create new metadata types'), name='metadata_type_create'
 )
-permission_metadata_type_delete = setup_namespace.add_permission(
+permission_metadata_type_delete = metadata_type_namespace.add_permission(
     label=_('Delete metadata types'), name='metadata_type_delete'
 )
-permission_metadata_type_view = setup_namespace.add_permission(
+permission_metadata_type_view = metadata_type_namespace.add_permission(
     label=_('View metadata types'), name='metadata_type_view'
 )
