@@ -1,7 +1,6 @@
 from django.core.exceptions import ValidationError as DjangoValidationError
 from django.utils.translation import ugettext_lazy as _
 
-from rest_framework import serializers
 from rest_framework.exceptions import ValidationError
 from rest_framework.reverse import reverse
 
@@ -11,7 +10,7 @@ from mayan.apps.documents.serializers.document_serializers import (
 from mayan.apps.documents.serializers.document_type_serializers import (
     DocumentTypeSerializer
 )
-from mayan.apps.rest_api.serializer_mixins import CreateOnlyFieldSerializerMixin
+from mayan.apps.rest_api import serializers
 from mayan.apps.rest_api.relations import (
     FilteredPrimaryKeyRelatedField, FilteredSimplePrimaryKeyRelatedField
 )
@@ -31,15 +30,15 @@ class MetadataTypeSerializer(serializers.HyperlinkedModelSerializer):
             },
         }
         fields = (
-            'default', 'id', 'label', 'lookup', 'name', 'parser', 'url',
-            'validation'
+            'default', 'id', 'label', 'lookup', 'name', 'parser',
+            'parser_arguments', 'url', 'validation', 'validation_arguments'
         )
         model = MetadataType
         read_only_fields = ('id', 'url')
 
 
 class DocumentTypeMetadataTypeSerializer(
-    CreateOnlyFieldSerializerMixin, serializers.HyperlinkedModelSerializer
+    serializers.HyperlinkedModelSerializer
 ):
     document_type = DocumentTypeSerializer(read_only=True)
     metadata_type = MetadataTypeSerializer(read_only=True)
@@ -87,7 +86,7 @@ class DocumentTypeMetadataTypeSerializer(
 
 
 class DocumentMetadataSerializer(
-    CreateOnlyFieldSerializerMixin, serializers.HyperlinkedModelSerializer
+    serializers.ModelSerializer
 ):
     metadata_type_id = FilteredPrimaryKeyRelatedField(
         help_text=_(
