@@ -29,14 +29,14 @@ class DocumentMetadataAPIViewTestCase(
         super().setUp()
         self._create_test_document_stub()
         self._create_test_metadata_type()
-        self.test_metadata_type.default = TEST_METADATA_TYPE_DEFAULT_VALUE
-        self.test_metadata_type.save()
-        self.test_document_type.metadata.create(
-            metadata_type=self.test_metadata_type, required=False
+        self._test_metadata_type.default = TEST_METADATA_TYPE_DEFAULT_VALUE
+        self._test_metadata_type.save()
+        self._test_document_type.metadata.create(
+            metadata_type=self._test_metadata_type, required=False
         )
 
     def test_document_metadata_create_api_view_no_permission(self):
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
@@ -45,7 +45,7 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count
+            self._test_document.metadata.count(), document_metadata_count
         )
 
         events = self._get_test_events()
@@ -53,11 +53,11 @@ class DocumentMetadataAPIViewTestCase(
 
     def test_document_metadata_create_api_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_add
         )
 
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
@@ -65,7 +65,7 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count
+            self._test_document.metadata.count(), document_metadata_count
         )
 
         events = self._get_test_events()
@@ -73,11 +73,11 @@ class DocumentMetadataAPIViewTestCase(
 
     def test_document_metadata_create_api_view_with_metadata_type_access(self):
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_add
         )
 
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
@@ -85,7 +85,7 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count
+            self._test_document.metadata.count(), document_metadata_count
         )
 
         events = self._get_test_events()
@@ -93,15 +93,15 @@ class DocumentMetadataAPIViewTestCase(
 
     def test_document_metadata_create_api_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_add
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_add
         )
 
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
@@ -109,30 +109,30 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count + 1
+            self._test_document.metadata.count(), document_metadata_count + 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_added.id)
 
     def test_trashed_document_metadata_create_api_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_add
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_add
         )
 
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -140,7 +140,7 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count
+            self._test_document.metadata.count(), document_metadata_count
         )
 
         events = self._get_test_events()
@@ -148,11 +148,11 @@ class DocumentMetadataAPIViewTestCase(
 
     def test_document_metadata_create_default_value_api_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_add
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_add
         )
 
@@ -163,10 +163,10 @@ class DocumentMetadataAPIViewTestCase(
         )
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
-        document_metadata = self.test_document.metadata.first()
+        document_metadata = self._test_document.metadata.first()
         self.assertEqual(response.data['id'], document_metadata.pk)
         self.assertEqual(
-            document_metadata.metadata_type, self.test_metadata_type
+            document_metadata.metadata_type, self._test_metadata_type
         )
         self.assertEqual(
             document_metadata.value, TEST_METADATA_TYPE_DEFAULT_VALUE
@@ -175,9 +175,9 @@ class DocumentMetadataAPIViewTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_added.id)
 
     def test_document_metadata_create_duplicate_api_view(self):
@@ -194,8 +194,8 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_metadata_create_invalid_lookup_value_api_view(self):
-        self.test_metadata_type.lookup = 'invalid,lookup,values,on,purpose'
-        self.test_metadata_type.save()
+        self._test_metadata_type.lookup = 'invalid,lookup,values,on,purpose'
+        self._test_metadata_type.save()
         self.grant_permission(permission=permission_document_metadata_add)
 
         self._clear_events()
@@ -210,7 +210,7 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_delete_api_view_no_permission(self):
         self._create_test_document_metadata()
 
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
@@ -218,7 +218,7 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count
+            self._test_document.metadata.count(), document_metadata_count
         )
 
         events = self._get_test_events()
@@ -227,11 +227,11 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_delete_api_view_with_document_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_remove
         )
 
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
@@ -239,7 +239,7 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count
+            self._test_document.metadata.count(), document_metadata_count
         )
 
         events = self._get_test_events()
@@ -248,11 +248,11 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_delete_api_view_with_metadata_type_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_remove
         )
 
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
@@ -260,7 +260,7 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count
+            self._test_document.metadata.count(), document_metadata_count
         )
 
         events = self._get_test_events()
@@ -269,15 +269,15 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_delete_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_remove
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_remove
         )
 
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
         self._clear_events()
 
@@ -285,31 +285,31 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count - 1
+            self._test_document.metadata.count(), document_metadata_count - 1
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_removed.id)
 
     def test_trashed_document_metadata_delete_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_remove
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_remove
         )
 
-        document_metadata_count = self.test_document.metadata.count()
+        document_metadata_count = self._test_document.metadata.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -317,7 +317,7 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
         self.assertEqual(
-            self.test_document.metadata.count(), document_metadata_count
+            self._test_document.metadata.count(), document_metadata_count
         )
 
         events = self._get_test_events()
@@ -338,7 +338,7 @@ class DocumentMetadataAPIViewTestCase(
         self._create_test_document_metadata()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_view
         )
 
@@ -355,7 +355,7 @@ class DocumentMetadataAPIViewTestCase(
         self._create_test_document_metadata()
 
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_view
         )
 
@@ -370,11 +370,11 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_list_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_view
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_view
         )
 
@@ -384,19 +384,19 @@ class DocumentMetadataAPIViewTestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
             response.data['results'][0]['document']['id'],
-            self.test_document.pk
+            self._test_document.pk
         )
         self.assertEqual(
             response.data['results'][0]['metadata_type']['id'],
-            self.test_metadata_type.pk
+            self._test_metadata_type.pk
         )
         self.assertEqual(
             response.data['results'][0]['value'],
-            self.test_document_metadata.value
+            self._test_document_metadata.value
         )
         self.assertEqual(
             response.data['results'][0]['id'],
-            self.test_document_metadata.pk
+            self._test_document_metadata.pk
         )
 
         events = self._get_test_events()
@@ -405,15 +405,15 @@ class DocumentMetadataAPIViewTestCase(
     def test_trashed_document_metadata_list_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_view
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -426,16 +426,16 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_patch_api_view_no_permission(self):
         self._create_test_document_metadata()
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_patch()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
@@ -444,20 +444,20 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_patch_api_view_document_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_patch()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
@@ -466,20 +466,20 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_patch_api_view_metadata_type_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_patch()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
@@ -488,57 +488,57 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_patch_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_patch()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertNotEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_edited.id)
 
     def test_trashed_document_metadata_patch_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_patch()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
@@ -547,11 +547,11 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_patch_default_value_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
@@ -562,36 +562,36 @@ class DocumentMetadataAPIViewTestCase(
         )
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
             response.data['value'], TEST_METADATA_TYPE_DEFAULT_VALUE
         )
         self.assertEqual(
-            self.test_document_metadata.value,
+            self._test_document_metadata.value,
             TEST_METADATA_TYPE_DEFAULT_VALUE
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_edited.id)
 
     def test_document_metadata_put_api_view_no_permission(self):
         self._create_test_document_metadata()
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_put()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
@@ -600,20 +600,20 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_put_api_view_document_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_put()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
@@ -622,20 +622,20 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_put_api_view_metadata_type_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_put()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
@@ -644,57 +644,57 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_put_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_put()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertNotEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_edited.id)
 
     def test_trashed_document_metadata_put_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
-        document_metadata_value = self.test_document_metadata.value
+        document_metadata_value = self._test_document_metadata.value
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_document_metadata_edit_api_view_via_put()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
-            self.test_document_metadata.value, document_metadata_value
+            self._test_document_metadata.value, document_metadata_value
         )
 
         events = self._get_test_events()
@@ -703,11 +703,11 @@ class DocumentMetadataAPIViewTestCase(
     def test_document_metadata_put_default_value_api_view_with_full_access(self):
         self._create_test_document_metadata()
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
@@ -718,19 +718,19 @@ class DocumentMetadataAPIViewTestCase(
         )
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_document_metadata.refresh_from_db()
+        self._test_document_metadata.refresh_from_db()
         self.assertEqual(
             response.data['value'], TEST_METADATA_TYPE_DEFAULT_VALUE
         )
         self.assertEqual(
-            self.test_document_metadata.value,
+            self._test_document_metadata.value,
             TEST_METADATA_TYPE_DEFAULT_VALUE
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_document_metadata_edited.id)
