@@ -52,7 +52,7 @@ class MetadataTypeAPITestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_metadata_type)
+        self.assertEqual(events[0].target, self._test_metadata_type)
         self.assertEqual(events[0].verb, event_metadata_type_created.id)
 
     def test_metadata_type_delete_api_view_no_permission(self):
@@ -71,7 +71,7 @@ class MetadataTypeAPITestCase(
     def test_metadata_type_delete_api_view_with_access(self):
         self._create_test_metadata_type()
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_delete
         )
 
@@ -99,7 +99,7 @@ class MetadataTypeAPITestCase(
     def test_metadata_type_detail_api_view_with_access(self):
         self._create_test_metadata_type()
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_view
         )
 
@@ -109,7 +109,7 @@ class MetadataTypeAPITestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
         self.assertEqual(
-            response.data['label'], self.test_metadata_type.label
+            response.data['label'], self._test_metadata_type.label
         )
 
         events = self._get_test_events()
@@ -118,7 +118,7 @@ class MetadataTypeAPITestCase(
     def test_metadata_type_patch_api_view_no_permission(self):
         self._create_test_metadata_type()
         metadata_type_values = self._model_instance_to_dictionary(
-            instance=self.test_metadata_type
+            instance=self._test_metadata_type
         )
 
         self._clear_events()
@@ -126,10 +126,10 @@ class MetadataTypeAPITestCase(
         response = self._request_test_metadata_type_edit_api_view_via_patch()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_metadata_type.refresh_from_db()
+        self._test_metadata_type.refresh_from_db()
         self.assertEqual(
             self._model_instance_to_dictionary(
-                instance=self.test_metadata_type
+                instance=self._test_metadata_type
             ), metadata_type_values
         )
 
@@ -139,10 +139,10 @@ class MetadataTypeAPITestCase(
     def test_metadata_type_patch_api_view_with_access(self):
         self._create_test_metadata_type()
         metadata_type_values = self._model_instance_to_dictionary(
-            instance=self.test_metadata_type
+            instance=self._test_metadata_type
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -151,10 +151,10 @@ class MetadataTypeAPITestCase(
         response = self._request_test_metadata_type_edit_api_view_via_patch()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_metadata_type.refresh_from_db()
+        self._test_metadata_type.refresh_from_db()
         self.assertNotEqual(
             self._model_instance_to_dictionary(
-                instance=self.test_metadata_type
+                instance=self._test_metadata_type
             ), metadata_type_values
         )
 
@@ -163,13 +163,13 @@ class MetadataTypeAPITestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_metadata_type)
+        self.assertEqual(events[0].target, self._test_metadata_type)
         self.assertEqual(events[0].verb, event_metadata_type_edited.id)
 
     def test_metadata_type_put_api_view_no_permission(self):
         self._create_test_metadata_type()
         metadata_type_values = self._model_instance_to_dictionary(
-            instance=self.test_metadata_type
+            instance=self._test_metadata_type
         )
 
         self._clear_events()
@@ -177,10 +177,10 @@ class MetadataTypeAPITestCase(
         response = self._request_test_metadata_type_edit_api_view_via_put()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.test_metadata_type.refresh_from_db()
+        self._test_metadata_type.refresh_from_db()
         self.assertEqual(
             self._model_instance_to_dictionary(
-                instance=self.test_metadata_type
+                instance=self._test_metadata_type
             ), metadata_type_values
         )
 
@@ -190,10 +190,10 @@ class MetadataTypeAPITestCase(
     def test_metadata_type_put_api_view_with_access(self):
         self._create_test_metadata_type()
         metadata_type_values = self._model_instance_to_dictionary(
-            instance=self.test_metadata_type
+            instance=self._test_metadata_type
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -202,10 +202,10 @@ class MetadataTypeAPITestCase(
         response = self._request_test_metadata_type_edit_api_view_via_put()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.test_metadata_type.refresh_from_db()
+        self._test_metadata_type.refresh_from_db()
         self.assertNotEqual(
             self._model_instance_to_dictionary(
-                instance=self.test_metadata_type
+                instance=self._test_metadata_type
             ), metadata_type_values
         )
 
@@ -214,7 +214,7 @@ class MetadataTypeAPITestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_metadata_type)
+        self.assertEqual(events[0].target, self._test_metadata_type)
         self.assertEqual(events[0].verb, event_metadata_type_edited.id)
 
     def test_metadata_type_list_api_view_no_permission(self):
@@ -233,7 +233,7 @@ class MetadataTypeAPITestCase(
     def test_metadata_type_list_api_view_with_access(self):
         self._create_test_metadata_type()
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_view
         )
 
@@ -243,7 +243,7 @@ class MetadataTypeAPITestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
             response.data['results'][0]['label'],
-            self.test_metadata_type.label
+            self._test_metadata_type.label
         )
 
         events = self._get_test_events()
@@ -266,14 +266,14 @@ class DocumentTypeMetadataTypeAPITestCase(
         response = self._request_document_type_metadata_type_create_api_view()
 
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
-        self.assertEqual(self.test_document_type.metadata.count(), 0)
+        self.assertEqual(self._test_document_type.metadata.count(), 0)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_type_metadata_type_create_api_view_with_document_type_access(self):
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
 
@@ -282,14 +282,14 @@ class DocumentTypeMetadataTypeAPITestCase(
         response = self._request_document_type_metadata_type_create_api_view()
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-        self.assertEqual(self.test_document_type.metadata.count(), 0)
+        self.assertEqual(self._test_document_type.metadata.count(), 0)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_type_metadata_type_create_api_view_with_metadata_type_access(self):
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -298,18 +298,18 @@ class DocumentTypeMetadataTypeAPITestCase(
         response = self._request_document_type_metadata_type_create_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertEqual(self.test_document_type.metadata.count(), 0)
+        self.assertEqual(self._test_document_type.metadata.count(), 0)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_type_metadata_type_create_api_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -324,9 +324,9 @@ class DocumentTypeMetadataTypeAPITestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_type)
+        self.assertEqual(events[0].target, self._test_document_type)
         self.assertEqual(
             events[0].verb, event_metadata_type_relationship_updated.id
         )
@@ -334,11 +334,11 @@ class DocumentTypeMetadataTypeAPITestCase(
     def test_document_type_metadata_type_create_duplicate_api_view(self):
         self._create_test_document_type_metadata_type()
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -360,7 +360,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         response = self._request_document_type_metadata_type_delete_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertEqual(self.test_document_type.metadata.count(), 1)
+        self.assertEqual(self._test_document_type.metadata.count(), 1)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -369,7 +369,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
 
@@ -378,7 +378,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         response = self._request_document_type_metadata_type_delete_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertEqual(self.test_document_type.metadata.count(), 1)
+        self.assertEqual(self._test_document_type.metadata.count(), 1)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -387,7 +387,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -396,7 +396,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         response = self._request_document_type_metadata_type_delete_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertEqual(self.test_document_type.metadata.count(), 1)
+        self.assertEqual(self._test_document_type.metadata.count(), 1)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -405,11 +405,11 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -418,14 +418,14 @@ class DocumentTypeMetadataTypeAPITestCase(
         response = self._request_document_type_metadata_type_delete_api_view()
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
 
-        self.assertEqual(self.test_document_type.metadata.all().count(), 0)
+        self.assertEqual(self._test_document_type.metadata.all().count(), 0)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_type)
+        self.assertEqual(events[0].target, self._test_document_type)
         self.assertEqual(
             events[0].verb, event_metadata_type_relationship_updated.id
         )
@@ -445,7 +445,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_view
         )
 
@@ -462,7 +462,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_view
         )
 
@@ -478,11 +478,11 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_view
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_view
         )
 
@@ -492,7 +492,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(
             response.data['results'][0]['id'],
-            self.test_document_type_metadata_type.pk
+            self._test_document_type_metadata_type.pk
         )
 
         events = self._get_test_events()
@@ -516,7 +516,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
 
@@ -535,7 +535,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -554,11 +554,11 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -573,9 +573,9 @@ class DocumentTypeMetadataTypeAPITestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_type)
+        self.assertEqual(events[0].target, self._test_document_type)
         self.assertEqual(
             events[0].verb, event_metadata_type_relationship_updated.id
         )
@@ -598,7 +598,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
 
@@ -617,7 +617,7 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -636,11 +636,11 @@ class DocumentTypeMetadataTypeAPITestCase(
         self._create_test_document_type_metadata_type()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_metadata_type_edit
         )
 
@@ -655,9 +655,9 @@ class DocumentTypeMetadataTypeAPITestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_metadata_type)
+        self.assertEqual(events[0].action_object, self._test_metadata_type)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document_type)
+        self.assertEqual(events[0].target, self._test_document_type)
         self.assertEqual(
             events[0].verb, event_metadata_type_relationship_updated.id
         )
