@@ -5,8 +5,9 @@ from mayan.apps.documents.permissions import (
     permission_document_view
 )
 from mayan.apps.documents.search import (
-    document_file_page_search, document_file_search, document_search,
-    document_version_page_search, document_version_search
+    search_model_document, search_model_document_file,
+    search_model_document_file_page, search_model_document_version,
+    search_model_document_version_page
 )
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 from mayan.apps.dynamic_search.literals import SEARCH_MODEL_NAME_KWARG
@@ -29,9 +30,9 @@ class DocumentSearchResultWidgetViewTestCase(
         self._upload_test_document()
         self._create_test_document_metadata()
         self._test_object_permission = permission_document_view
-        self._test_object_text = self.test_document.label
-        self._test_search_model = document_search
-        self._test_search_term_data = {'uuid': self.test_document.uuid}
+        self._test_object_text = self._test_document.label
+        self._test_search_model = search_model_document
+        self._test_search_term_data = {'uuid': self._test_document.uuid}
 
     def test_document_metadata_widget_no_permission(self):
         response = self._request_search_results_view(
@@ -44,13 +45,13 @@ class DocumentSearchResultWidgetViewTestCase(
             status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_metadata_type.label,
+            response=response, text=self._test_metadata_type.label,
             status_code=200
         )
 
     def test_document_metadata_widget_with_metadata_type_access(self):
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_view
         )
 
@@ -63,13 +64,13 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_metadata_type.label,
+            response=response, text=self._test_metadata_type.label,
             status_code=200
         )
 
     def test_document_metadata_widget_with_document_view_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=self._test_object_permission
         )
 
@@ -82,13 +83,13 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_metadata_type.label,
+            response=response, text=self._test_metadata_type.label,
             status_code=200
         )
 
     def test_document_metadata_widget_with_document_metadata_view_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_view
         )
 
@@ -101,17 +102,17 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_metadata_type.label,
+            response=response, text=self._test_metadata_type.label,
             status_code=200
         )
 
     def test_document_metadata_widget_with_all_document_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=self._test_object_permission
         )
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_view
         )
 
@@ -124,16 +125,16 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_metadata_type.label,
+            response=response, text=self._test_metadata_type.label,
             status_code=200
         )
 
     def test_document_metadata_widget_with_metadata_view_and_document_view_access(self):
         self.grant_access(
-            obj=self.test_document, permission=self._test_object_permission
+            obj=self._test_document, permission=self._test_object_permission
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_view
         )
 
@@ -146,21 +147,21 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_metadata_type.label,
+            response=response, text=self._test_metadata_type.label,
             status_code=200
         )
 
     def test_document_metadata_widget_with_full_access(self):
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=self._test_object_permission
         )
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_view
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_view
         )
 
@@ -173,7 +174,7 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertContains(
-            response=response, text=self.test_metadata_type.label,
+            response=response, text=self._test_metadata_type.label,
             status_code=200
         )
 
@@ -183,11 +184,11 @@ class DocumentFileSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = self.test_document_file.filename
+        self._test_object_text = self._test_document_file.filename
         self._test_object_permission = permission_document_file_view
-        self._test_search_model = document_file_search
+        self._test_search_model = search_model_document_file
         self._test_search_term_data = {
-            'document__uuid': self.test_document.uuid
+            'document__uuid': self._test_document.uuid
         }
 
 
@@ -196,11 +197,11 @@ class DocumentFilePageSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = force_text(s=self.test_document_file.pages.first())
+        self._test_object_text = force_text(s=self._test_document_file.pages.first())
         self._test_object_permission = permission_document_file_view
-        self._test_search_model = document_file_page_search
+        self._test_search_model = search_model_document_file_page
         self._test_search_term_data = {
-            'document_file__document__uuid': self.test_document.uuid
+            'document_file__document__uuid': self._test_document.uuid
         }
 
 
@@ -209,11 +210,11 @@ class DocumentVersionSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = force_text(s=self.test_document_version)
+        self._test_object_text = force_text(s=self._test_document_version)
         self._test_object_permission = permission_document_version_view
-        self._test_search_model = document_version_search
+        self._test_search_model = search_model_document_version
         self._test_search_term_data = {
-            'document__uuid': self.test_document.uuid
+            'document__uuid': self._test_document.uuid
         }
 
 
@@ -222,9 +223,9 @@ class DocumentVersionPageSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = force_text(s=self.test_document_version.pages.first())
+        self._test_object_text = force_text(s=self._test_document_version.pages.first())
         self._test_object_permission = permission_document_version_view
-        self._test_search_model = document_version_page_search
+        self._test_search_model = search_model_document_version_page
         self._test_search_term_data = {
-            'document_version__document__uuid': self.test_document.uuid
+            'document_version__document__uuid': self._test_document.uuid
         }
