@@ -2,21 +2,11 @@ import logging
 
 from django.apps import apps
 
-from mayan.apps.document_indexing.tasks import task_index_instance_document_add
-
 from .settings import setting_auto_ocr
 
 logger = logging.getLogger(name=__name__)
 
 
-def handler_index_document_version(sender, **kwargs):
-    task_index_instance_document_add.apply_async(
-        kwargs={
-            'document_id': kwargs['instance'].document_id
-        }
-    )
-
-
 def handler_initialize_new_ocr_settings(sender, instance, **kwargs):
     DocumentTypeOCRSettings = apps.get_model(
         app_label='ocr', model_name='DocumentTypeOCRSettings'
