@@ -2,48 +2,39 @@ from mayan.apps.appearance.classes import Icon
 
 # Document version
 
-icon_document_version_ocr_content_delete_single = Icon(
+icon_document_version_ocr_content_single_delete = Icon(
     driver_name='fontawesome-dual', primary_symbol='font',
     secondary_symbol='times'
 )
-icon_document_version_ocr_content_delete_multiple = icon_document_version_ocr_content_delete_single
-icon_document_version_ocr_content_view = Icon(
+icon_document_version_ocr_content_multiple_delete = icon_document_version_ocr_content_single_delete
+icon_document_version_ocr_content_detail = Icon(
     driver_name='fontawesome', symbol='font'
 )
-icon_document_version_ocr_submit_single = Icon(
+icon_document_version_ocr_single_submit = Icon(
     driver_name='fontawesome-dual', primary_symbol='font',
     secondary_symbol='arrow-right'
 )
-icon_document_version_ocr_submit_multiple = icon_document_version_ocr_submit_single
+icon_document_version_ocr_multiple_submit = icon_document_version_ocr_single_submit
 
 # Document version page
 
-icon_document_version_page_ocr_content_detail_view = Icon(
+icon_document_version_page_ocr_content_detail = Icon(
     driver_name='fontawesome', symbol='font'
 )
-icon_document_version_page_ocr_content_edit_view = Icon(
+icon_document_version_page_ocr_content_edit = Icon(
     driver_name='fontawesome', symbol='font'
 )
-icon_document_version_ocr_download = Icon(
+icon_document_version_ocr_content_download = Icon(
     driver_name='fontawesome-dual', primary_symbol='font',
     secondary_symbol='arrow-down'
 )
-icon_document_version_ocr_errors_list = Icon(
-    driver_name='fontawesome-dual', primary_symbol='font',
-    secondary_symbol='exclamation'
-)
 
 # Document type
 
 icon_document_type_ocr_settings = Icon(
     driver_name='fontawesome', symbol='font'
 )
-icon_document_type_submit = Icon(
+icon_document_type_ocr_submit = Icon(
     driver_name='fontawesome-dual', primary_symbol='font',
     secondary_symbol='arrow-right'
 )
-
-icon_entry_list = Icon(
-    driver_name='fontawesome-dual', primary_symbol='font',
-    secondary_symbol='exclamation'
-)
