@@ -10,7 +10,6 @@ from mayan.apps.lock_manager.exceptions import LockError
 from mayan.celery import app
 
 from .events import event_ocr_document_version_finished
-from .signals import signal_post_document_version_ocr
 
 logger = logging.getLogger(name=__name__)
 
@@ -43,7 +42,9 @@ def task_document_version_ocr_process(self, document_version_id, user_id=None):
             )
         )
     except Exception as exception:
-        document_version.ocr_errors.create(result=exception)
+        document_version.error_log.create(
+            text=str(exception)
+        )
         raise
 
 
@@ -101,7 +102,7 @@ def task_document_version_ocr_finished(
     )
     document_version = DocumentVersion.objects.get(pk=document_version_id)
 
-    document_version.ocr_errors.all().delete()
+    document_version.error_log.all().delete()
 
     User = get_user_model()
 
@@ -115,11 +116,6 @@ def task_document_version_ocr_finished(
             action_object=document_version.document, actor=user,
             target=document_version
         )
-
-        signal_post_document_version_ocr.send(
-            sender=document_version.__class__,
-            instance=document_version
-        )
     except Exception as exception:
         logger.error(
             'Exception in OCR finish for document version: %d; %s',
