@@ -11,7 +11,6 @@ from ..permissions import (
     permission_document_version_ocr_content_view,
     permission_document_version_ocr, permission_document_type_ocr_setup
 )
-from ..utils import get_instance_ocr_content
 
 from .literals import TEST_DOCUMENT_VERSION_OCR_CONTENT
 from .mixins import (
@@ -20,7 +19,7 @@ from .mixins import (
 )
 
 
-class DocumentTypeOCRViewsTestCase(
+class DocumentTypeOCRViewTestCase(
     DocumentTypeOCRViewTestMixin, GenericDocumentViewTestCase
 ):
     auto_upload_test_document = False
@@ -36,7 +35,7 @@ class DocumentTypeOCRViewsTestCase(
 
     def test_document_type_ocr_settings_view_with_access(self):
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_type_ocr_setup
         )
 
@@ -58,7 +57,7 @@ class DocumentTypeOCRViewsTestCase(
 
         self.assertFalse(
             TEST_DOCUMENT_VERSION_OCR_CONTENT in ''.join(
-                self.test_document_version.ocr_content()
+                self._test_document_version.ocr_content()
             )
         )
 
@@ -69,7 +68,7 @@ class DocumentTypeOCRViewsTestCase(
         self._upload_test_document()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_version_ocr
         )
 
@@ -80,23 +79,23 @@ class DocumentTypeOCRViewsTestCase(
 
         self.assertTrue(
             TEST_DOCUMENT_VERSION_OCR_CONTENT in ''.join(
-                self.test_document_version.ocr_content()
+                self._test_document_version.ocr_content()
             )
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(
             events[0].verb, event_ocr_document_version_submitted.id
         )
 
+        self.assertEqual(events[1].action_object, self._test_document)
         self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(events[1].action_object, self.test_document)
-        self.assertEqual(events[1].target, self.test_document_version)
+        self.assertEqual(events[1].target, self._test_document_version)
         self.assertEqual(
             events[1].verb, event_ocr_document_version_finished.id
         )
@@ -105,11 +104,11 @@ class DocumentTypeOCRViewsTestCase(
         self._upload_test_document()
 
         self.grant_access(
-            obj=self.test_document_type,
+            obj=self._test_document_type,
             permission=permission_document_version_ocr
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -118,7 +117,7 @@ class DocumentTypeOCRViewsTestCase(
 
         self.assertFalse(
             TEST_DOCUMENT_VERSION_OCR_CONTENT in ''.join(
-                self.test_document_version.ocr_content()
+                self._test_document_version.ocr_content()
             )
         )
 
@@ -126,140 +125,143 @@ class DocumentTypeOCRViewsTestCase(
         self.assertEqual(events.count(), 0)
 
 
-class DocumentVersionOCRViewsTestCase(
+class DocumentVersionOCRViewTestCase(
     DocumentVersionOCRTestMixin, DocumentVersionOCRViewTestMixin,
     GenericDocumentViewTestCase
 ):
-    def test_document_verions_ocr_content_delete_single_view_no_permission(self):
+    def test_document_verions_ocr_content_single_delete_view_no_permission(self):
         self._create_test_document_version_ocr_content()
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_content_delete_single_view()
+        response = self._request_test_document_version_ocr_content_single_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
             DocumentVersionPageOCRContent.objects.filter(
-                document_version_page=self.test_document_version.pages.first()
+                document_version_page=self._test_document_version.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_ocr_content_delete_single_view_with_access(self):
+    def test_document_version_ocr_content_single_delete_view_with_access(self):
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_version_ocr
+            obj=self._test_document,
+            permission=permission_document_version_ocr
         )
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_content_delete_single_view()
+        response = self._request_test_document_version_ocr_content_single_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertFalse(
             DocumentVersionPageOCRContent.objects.filter(
-                document_version_page=self.test_document_version.pages.first()
+                document_version_page=self._test_document_version.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(
             events[0].verb, event_ocr_document_version_content_deleted.id
         )
 
-    def test_trashed_document_version_ocr_content_delete_single_view_with_access(self):
+    def test_trashed_document_version_ocr_content_single_delete_view_with_access(self):
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_version_ocr
+            obj=self._test_document,
+            permission=permission_document_version_ocr
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_content_delete_single_view()
+        response = self._request_test_document_version_ocr_content_single_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
             DocumentVersionPageOCRContent.objects.filter(
-                document_version_page=self.test_document_version.pages.first()
+                document_version_page=self._test_document_version.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_ocr_content_delete_multiple_view_no_permission(self):
+    def test_document_version_ocr_content_multiple_delete_view_no_permission(self):
         self._create_test_document_version_ocr_content()
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_content_delete_multiple_view()
+        response = self._request_test_document_version_ocr_content_multiple_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
             DocumentVersionPageOCRContent.objects.filter(
-                document_version_page=self.test_document_version.pages.first()
+                document_version_page=self._test_document_version.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_ocr_content_delete_multiple_view_with_access(self):
+    def test_document_version_ocr_content_multiple_delete_view_with_access(self):
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_version_ocr
+            obj=self._test_document,
+            permission=permission_document_version_ocr
         )
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_content_delete_multiple_view()
+        response = self._request_test_document_version_ocr_content_multiple_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertFalse(
             DocumentVersionPageOCRContent.objects.filter(
-                document_version_page=self.test_document_version.pages.first()
+                document_version_page=self._test_document_version.pages.first()
             ).exists()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(
             events[0].verb, event_ocr_document_version_content_deleted.id
         )
 
-    def test_trashed_document_version_ocr_content_delete_multiple_view_with_access(self):
+    def test_trashed_document_version_ocr_content_multiple_delete_view_with_access(self):
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_version_ocr
+            obj=self._test_document, permission=permission_document_version_ocr
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_content_delete_multiple_view()
+        response = self._request_test_document_version_ocr_content_multiple_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
             DocumentVersionPageOCRContent.objects.filter(
-                document_version_page=self.test_document_version.pages.first()
+                document_version_page=self._test_document_version.pages.first()
             ).exists()
         )
 
@@ -271,7 +273,7 @@ class DocumentVersionOCRViewsTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_content_view()
+        response = self._request_test_document_version_ocr_content_detail_view()
         self.assertEqual(response.status_code, 404)
 
         events = self._get_test_events()
@@ -281,13 +283,13 @@ class DocumentVersionOCRViewsTestCase(
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_ocr_content_view
         )
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_content_view()
+        response = self._request_test_document_version_ocr_content_detail_view()
         self.assertContains(
             response=response, text=TEST_DOCUMENT_VERSION_OCR_CONTENT,
             status_code=200
@@ -300,15 +302,15 @@ class DocumentVersionOCRViewsTestCase(
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_ocr_content_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_content_view()
+        response = self._request_test_document_version_ocr_content_detail_view()
         self.assertEqual(response.status_code, 404)
 
         events = self._get_test_events()
@@ -317,11 +319,11 @@ class DocumentVersionOCRViewsTestCase(
     def test_document_version_ocr_submit_view_no_permission(self):
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_submit_single_view()
+        response = self._request_test_document_version_ocr_single_submit_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(
-            ''.join(self.test_document_version.ocr_content()), ''
+            ''.join(self._test_document_version.ocr_content()), ''
         )
 
         events = self._get_test_events()
@@ -329,119 +331,123 @@ class DocumentVersionOCRViewsTestCase(
 
     def test_document_version_ocr_submit_view_with_access(self):
         self.grant_access(
-            permission=permission_document_version_ocr, obj=self.test_document
+            obj=self._test_document,
+            permission=permission_document_version_ocr
         )
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_submit_single_view()
+        response = self._request_test_document_version_ocr_single_submit_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
             TEST_DOCUMENT_VERSION_OCR_CONTENT in ''.join(
-                self.test_document_version.ocr_content()
+                self._test_document_version.ocr_content()
             )
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(
             events[0].verb, event_ocr_document_version_submitted.id
         )
 
+        self.assertEqual(events[1].action_object, self._test_document)
         self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(events[1].action_object, self.test_document)
-        self.assertEqual(events[1].target, self.test_document_version)
+        self.assertEqual(events[1].target, self._test_document_version)
         self.assertEqual(
             events[1].verb, event_ocr_document_version_finished.id
         )
 
     def test_trashed_document_version_ocr_submit_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_version_ocr
+            obj=self._test_document,
+            permission=permission_document_version_ocr
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_submit_single_view()
+        response = self._request_test_document_version_ocr_single_submit_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertFalse(
             TEST_DOCUMENT_VERSION_OCR_CONTENT in ''.join(
-                self.test_document_version.ocr_content()
+                self._test_document_version.ocr_content()
             )
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_ocr_submit_multiple_view_no_permission(self):
+    def test_document_version_ocr_multiple_submit_view_no_permission(self):
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_submit_multiple_view()
+        response = self._request_test_document_version_ocr_multiple_submit_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(
-            ''.join(self.test_document_version.ocr_content()), ''
+            ''.join(self._test_document_version.ocr_content()), ''
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_document_version_ocr_submit_multiple_view_with_access(self):
+    def test_document_version_ocr_multiple_submit_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_version_ocr
+            obj=self._test_document,
+            permission=permission_document_version_ocr
         )
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_submit_multiple_view()
+        response = self._request_test_document_version_ocr_multiple_submit_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
             TEST_DOCUMENT_VERSION_OCR_CONTENT in ''.join(
-                self.test_document_version.ocr_content()
+                self._test_document_version.ocr_content()
             )
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 2)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document)
-        self.assertEqual(events[0].target, self.test_document_version)
+        self.assertEqual(events[0].target, self._test_document_version)
         self.assertEqual(
             events[0].verb, event_ocr_document_version_submitted.id
         )
 
+        self.assertEqual(events[1].action_object, self._test_document)
         self.assertEqual(events[1].actor, self._test_case_user)
-        self.assertEqual(events[1].action_object, self.test_document)
-        self.assertEqual(events[1].target, self.test_document_version)
+        self.assertEqual(events[1].target, self._test_document_version)
         self.assertEqual(
             events[1].verb, event_ocr_document_version_finished.id
         )
 
-    def test_trashed_document_version_ocr_submit_multiple_view_with_access(self):
+    def test_trashed_document_version_ocr_multiple_submit_view_with_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_version_ocr
+            obj=self._test_document,
+            permission=permission_document_version_ocr
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_submit_multiple_view()
+        response = self._request_test_document_version_ocr_multiple_submit_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertFalse(
             TEST_DOCUMENT_VERSION_OCR_CONTENT in ''.join(
-                self.test_document_version.ocr_content()
+                self._test_document_version.ocr_content()
             )
         )
 
@@ -453,7 +459,7 @@ class DocumentVersionOCRViewsTestCase(
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_download_view()
+        response = self._request_test_document_version_ocr_content_download_view()
         self.assertEqual(response.status_code, 404)
 
         events = self._get_test_events()
@@ -465,19 +471,19 @@ class DocumentVersionOCRViewsTestCase(
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_ocr_content_view
         )
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_download_view()
+        response = self._request_test_document_version_ocr_content_download_view()
         self.assertEqual(response.status_code, 200)
 
         self.assert_download_response(
-            response=response, content=(
-                ''.join(get_instance_ocr_content(instance=self.test_document))
-            ),
+            response=response, content=''.join(
+                self._test_document.ocr_content()
+            )
         )
 
         events = self._get_test_events()
@@ -487,59 +493,22 @@ class DocumentVersionOCRViewsTestCase(
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_ocr_content_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
-        response = self._request_test_document_version_ocr_download_view()
-        self.assertEqual(response.status_code, 404)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-    def test_document_version_ocr_error_list_view_no_permission(self):
-        self._clear_events()
-
-        response = self._request_test_document_version_ocr_error_list_view()
-        self.assertEqual(response.status_code, 404)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-    def test_document_version_ocr_error_list_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document, permission=permission_document_version_ocr
-        )
-
-        self._clear_events()
-
-        response = self._request_test_document_version_ocr_error_list_view()
-        self.assertEqual(response.status_code, 200)
-
-        events = self._get_test_events()
-        self.assertEqual(events.count(), 0)
-
-    def test_trashed_document_version_ocr_error_list_view_with_access(self):
-        self.grant_access(
-            obj=self.test_document, permission=permission_document_version_ocr
-        )
-
-        self.test_document.delete()
-
-        self._clear_events()
-
-        response = self._request_test_document_version_ocr_error_list_view()
+        response = self._request_test_document_version_ocr_content_download_view()
         self.assertEqual(response.status_code, 404)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
 
-class DocumentVersionPageOCRViewsTestCase(
+class DocumentVersionPageOCRViewTestCase(
     DocumentVersionOCRTestMixin, DocumentVersionPageOCRViewTestMixin,
     GenericDocumentViewTestCase
 ):
@@ -558,7 +527,7 @@ class DocumentVersionPageOCRViewsTestCase(
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_ocr_content_view
         )
 
@@ -577,11 +546,11 @@ class DocumentVersionPageOCRViewsTestCase(
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_ocr_content_view
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -594,15 +563,15 @@ class DocumentVersionPageOCRViewsTestCase(
     def test_document_version_page_ocr_content_edit_view_no_permission(self):
         self._create_test_document_version_ocr_content()
 
-        test_document_version_page_ocr_content = self.test_document_version_page.ocr_content.content
+        test_document_version_page_ocr_content = self._test_document_version_page.ocr_content.content
         self._clear_events()
 
         response = self._request_test_document_version_page_ocr_content_edit_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_version_page.ocr_content.refresh_from_db()
+        self._test_document_version_page.ocr_content.refresh_from_db()
         self.assertEqual(
-            self.test_document_version_page.ocr_content.content,
+            self._test_document_version_page.ocr_content.content,
             test_document_version_page_ocr_content
         )
 
@@ -613,28 +582,28 @@ class DocumentVersionPageOCRViewsTestCase(
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_ocr_content_edit
         )
 
-        test_document_version_page_ocr_content = self.test_document_version_page.ocr_content.content
+        test_document_version_page_ocr_content = self._test_document_version_page.ocr_content.content
         self._clear_events()
 
         response = self._request_test_document_version_page_ocr_content_edit_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_document_version_page.ocr_content.refresh_from_db()
+        self._test_document_version_page.ocr_content.refresh_from_db()
         self.assertNotEqual(
-            self.test_document_version_page.ocr_content.content,
+            self._test_document_version_page.ocr_content.content,
             test_document_version_page_ocr_content
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
+        self.assertEqual(events[0].action_object, self._test_document)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].action_object, self.test_document_version)
-        self.assertEqual(events[0].target, self.test_document_version_page)
+        self.assertEqual(events[0].target, self._test_document_version_page)
         self.assertEqual(
             events[0].verb, event_ocr_document_version_page_content_edited.id
         )
@@ -643,20 +612,20 @@ class DocumentVersionPageOCRViewsTestCase(
         self._create_test_document_version_ocr_content()
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_version_ocr_content_edit
         )
 
-        test_document_version_page_ocr_content = self.test_document_version_page.ocr_content.content
-        self.test_document.delete()
+        test_document_version_page_ocr_content = self._test_document_version_page.ocr_content.content
+        self._test_document.delete()
         self._clear_events()
 
         response = self._request_test_document_version_page_ocr_content_edit_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document_version_page.ocr_content.refresh_from_db()
+        self._test_document_version_page.ocr_content.refresh_from_db()
         self.assertEqual(
-            self.test_document_version_page.ocr_content.content,
+            self._test_document_version_page.ocr_content.content,
             test_document_version_page_ocr_content
         )
 
