@@ -7,21 +7,20 @@ from .api_views import (
 )
 from .views import (
     DocumentVersionOCRContentDeleteView, DocumentVersionOCRContentView,
-    DocumentVersionOCRDownloadView,
-    DocumentVersionOCRErrorsListView, DocumentVersionPageOCRContentEditView,
+    DocumentVersionOCRDownloadView, DocumentVersionPageOCRContentEditView,
     DocumentVersionPageOCRContentDetailView, DocumentVersionOCRSubmitView,
-    DocumentTypeSettingsEditView, DocumentTypeSubmitView, EntryListView
+    DocumentTypeOCRSettingsEditView, DocumentTypeOCRSubmitView
 )
 
 urlpatterns_document_types = [
     url(
         regex=r'^document_types/submit/$', name='document_type_submit',
-        view=DocumentTypeSubmitView.as_view()
+        view=DocumentTypeOCRSubmitView.as_view()
     ),
     url(
-        regex=r'^document_types/(?P<document_type_id>\d+)/ocr/settings/$',
+        regex=r'^document_types/(?P<document_type_id>\d+)/settings/$',
         name='document_type_ocr_settings',
-        view=DocumentTypeSettingsEditView.as_view()
+        view=DocumentTypeOCRSettingsEditView.as_view()
     )
 ]
 
@@ -33,32 +32,27 @@ urlpatterns_document_versions = [
     ),
     url(
         regex=r'^documents/versions/(?P<document_version_id>\d+)/content/delete/$',
-        name='document_version_ocr_content_delete_single',
+        name='document_version_ocr_content_single_delete',
         view=DocumentVersionOCRContentDeleteView.as_view()
     ),
     url(
         regex=r'^documents/versions/multiple/content/delete/$',
-        name='document_version_ocr_content_delete_multiple',
+        name='document_version_ocr_content_multiple_delete',
         view=DocumentVersionOCRContentDeleteView.as_view()
     ),
     url(
-        regex=r'^documents/versions/(?P<document_version_id>\d+)/ocr/download/$',
-        name='document_version_ocr_download',
+        regex=r'^documents/versions/(?P<document_version_id>\d+)/download/$',
+        name='document_version_ocr_content_download',
         view=DocumentVersionOCRDownloadView.as_view()
     ),
-    url(
-        regex=r'^documents/versions/(?P<document_version_id>\d+)/ocr/errors/$',
-        name='document_version_ocr_error_list',
-        view=DocumentVersionOCRErrorsListView.as_view()
-    ),
     url(
         regex=r'^documents/versions/(?P<document_version_id>\d+)/submit/$',
-        name='document_version_ocr_submit_single',
+        name='document_version_ocr_single_submit',
         view=DocumentVersionOCRSubmitView.as_view()
     ),
     url(
         regex=r'^documents/versions/multiple/submit/$',
-        name='document_version_ocr_submit_multiple',
+        name='document_version_ocr_multiple_submit',
         view=DocumentVersionOCRSubmitView.as_view()
     ),
     url(
@@ -70,8 +64,7 @@ urlpatterns_document_versions = [
         regex=r'^documents/versions/pages/(?P<document_version_page_id>\d+)/content/$',
         name='document_version_page_ocr_content_detail_view',
         view=DocumentVersionPageOCRContentDetailView.as_view()
-    ),
-    url(regex=r'^logs/$', name='entry_list', view=EntryListView.as_view())
+    )
 ]
 
 urlpatterns = []
@@ -98,5 +91,5 @@ api_urls = [
         regex=r'^documents/(?P<document_id>\d+)/versions/(?P<document_version_id>\d+)/pages/(?P<document_version_page_id>\d+)/ocr/$',
         name='document-version-page-ocr-content-detail-view',
         view=APIDocumentVersionPageOCRContentDetailView.as_view()
-    ),
+    )
 ]
