@@ -1,8 +1,7 @@
 from django.contrib.auth.models import Group
 from django.utils.translation import ugettext_lazy as _
 
-from rest_framework import serializers
-
+from mayan.apps.rest_api import serializers
 from mayan.apps.rest_api.relations import FilteredPrimaryKeyRelatedField
 from mayan.apps.user_management.permissions import permission_group_edit
 
