@@ -10,4 +10,4 @@ class QuotaCopyTestCase(
     def setUp(self):
         super().setUp()
         self._create_test_quota_with_mixins()
-        self.test_object = self.test_quota
+        self._test_object = self._test_quota
