@@ -7,4 +7,4 @@ class QuotaModelTestCase(QuotaTestMixin, BaseTestCase):
     def test_method_get_absolute_url(self):
         self._create_test_quota()
 
-        self.assertTrue(self.test_quota.get_absolute_url())
+        self.assertTrue(self._test_quota.get_absolute_url())
