@@ -1,3 +1,4 @@
+from django.conf import settings
 from django.contrib import messages
 from django.http import Http404
 from django.urls import reverse
@@ -7,13 +8,29 @@ from mayan.apps.views.generics import FormView, SingleObjectListView
 
 from .classes import SettingNamespace, Setting
 from .forms import SettingForm
+from .icons import (
+    icon_setting_namespace_detail, icon_setting_namespace_list,
+    icon_setting_edit
+)
 from .permissions import permission_settings_edit, permission_settings_view
 
 
 class SettingEditView(FormView):
     form_class = SettingForm
+    view_icon = icon_setting_edit
     view_permission = permission_settings_edit
 
+    def dispatch(self, request, *args, **kwargs):
+        if settings.COMMON_DISABLE_LOCAL_STORAGE:
+            messages.warning(
+                message=_(
+                    'Local storage is currently disabled, changes to '
+                    'setting values will not be saved or take effect.'
+                ), request=self.request
+            )
+
+        return super().dispatch(request=request, *args, **kwargs)
+
     def form_valid(self, form):
         self.get_object().value = form.cleaned_data['value']
         Setting.save_configuration()
@@ -38,13 +55,14 @@ class SettingEditView(FormView):
 
     def get_post_action_redirect(self):
         return reverse(
-            viewname='settings:namespace_detail', kwargs={
+            viewname='settings:setting_namespace_detail', kwargs={
                 'namespace_name': self.get_object().namespace.name
             }
         )
 
 
 class SettingNamespaceDetailView(SingleObjectListView):
+    view_icon = icon_setting_namespace_detail
     view_permission = permission_settings_view
 
     def get_extra_context(self):
@@ -75,6 +93,7 @@ class SettingNamespaceListView(SingleObjectListView):
         'hide_link': True,
         'title': _('Setting namespaces'),
     }
+    view_icon = icon_setting_namespace_list
     view_permission = permission_settings_view
 
     def get_source_queryset(self):
