@@ -7,6 +7,9 @@ DEFAULT_EMAIL_METADATA_ATTACHMENT_NAME = 'metadata.yaml'
 DEFAULT_EMAIL_POP3_TIMEOUT = 60
 DEFAULT_PERIOD_INTERVAL = 600
 
+REGULAR_EXPRESSION_MATCH_EVERYTHING = '.*'
+REGULAR_EXPRESSION_MATCH_NOTHING = '_^'
+
 SOURCE_UNCOMPRESS_CHOICE_ALWAYS = 'y'
 SOURCE_UNCOMPRESS_CHOICE_NEVER = 'n'
 SOURCE_UNCOMPRESS_CHOICE_ASK = 'a'
