@@ -2,8 +2,8 @@ import json
 
 from django.db.models import Q
 
-from mayan.apps.documents.literals import DOCUMENT_FILE_ACTION_PAGES_NEW
-from mayan.apps.documents.tests.literals import TEST_SMALL_DOCUMENT_PATH
+from mayan.apps.documents.document_file_actions import DocumentFileActionUseNewPages
+from mayan.apps.documents.tests.literals import TEST_FILE_SMALL_PATH
 
 from ...forms import NewDocumentForm
 from ...models import Source
@@ -22,30 +22,30 @@ class DocumentFileUploadViewTestMixin:
     def _request_document_file_upload_get_view(self):
         return self.get(
             viewname='sources:document_file_upload', kwargs={
-                'document_id': self.test_document.pk,
-                'source_id': self.test_source.pk,
+                'document_id': self._test_document.pk,
+                'source_id': self._test_source.pk,
             }
         )
 
     def _request_document_file_upload_post_view(self):
-        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_FILE_SMALL_PATH, mode='rb') as file_object:
             return self.post(
                 viewname='sources:document_file_upload', kwargs={
-                    'document_id': self.test_document.pk,
-                    'source_id': self.test_source.pk,
+                    'document_id': self._test_document.pk,
+                    'source_id': self._test_source.pk,
                 }, data={
-                    'document-action': DOCUMENT_FILE_ACTION_PAGES_NEW,
+                    'document-action': DocumentFileActionUseNewPages.backend_id,
                     'source-file': file_object
                 }
             )
 
     def _request_document_file_upload_no_source_view(self):
-        with open(file=TEST_SMALL_DOCUMENT_PATH, mode='rb') as file_object:
+        with open(file=TEST_FILE_SMALL_PATH, mode='rb') as file_object:
             return self.post(
                 viewname='sources:document_file_upload', kwargs={
-                    'document_id': self.test_document.pk,
+                    'document_id': self._test_document.pk,
                 }, data={
-                    'document-action': DOCUMENT_FILE_ACTION_PAGES_NEW,
+                    'document-action': DocumentFileActionUseNewPages.backend_id,
                     'source-file': file_object
                 }
             )
@@ -55,18 +55,18 @@ class DocumentUploadWizardViewTestMixin:
     def _request_upload_interactive_view(self):
         return self.get(
             viewname='sources:document_upload_interactive', data={
-                'document_type_id': self.test_document_type.pk,
+                'document_type_id': self._test_document_type.pk,
             }
         )
 
-    def _request_upload_wizard_view(self, document_path=TEST_SMALL_DOCUMENT_PATH):
+    def _request_upload_wizard_view(self, document_path=TEST_FILE_SMALL_PATH):
         with open(file=document_path, mode='rb') as file_object:
             return self.post(
                 viewname='sources:document_upload_interactive', kwargs={
-                    'source_id': self.test_source.pk
+                    'source_id': self._test_source.pk
                 }, data={
                     'source-file': file_object,
-                    'document_type_id': self.test_document_type.pk,
+                    'document_type_id': self._test_document_type.pk,
                 }
             )
 
@@ -78,11 +78,11 @@ class InteractiveSourceBackendTestMixin:
 
     def setUp(self):
         super().setUp()
-        self.test_document_form = self.get_test_document_form()
+        self._test_document_form = self.get_test_document_form()
 
     def get_test_document_form(self):
         document_form = NewDocumentForm(
-            data={}, document_type=self.test_document_type
+            data={}, document_type=self._test_document_type
         )
         document_form.full_clean()
 
@@ -110,36 +110,36 @@ class SourceAPIViewTestMixin:
         response = self.post(viewname='rest_api:source-list', data=data)
 
         try:
-            self.test_source = Source.objects.get(~Q(pk__in=pk_list))
+            self._test_source = Source.objects.get(~Q(pk__in=pk_list))
         except Source.DoesNotExist:
-            self.test_source = None
+            self._test_source = None
 
         return response
 
     def _request_test_source_delete_api_view(self):
         return self.delete(
             viewname='rest_api:source-detail', kwargs={
-                'source_id': self.test_source.pk
+                'source_id': self._test_source.pk
             }
         )
 
     def _request_test_source_edit_api_view_via_patch(self):
         return self.patch(
             viewname='rest_api:source-detail', kwargs={
-                'source_id': self.test_source.pk
+                'source_id': self._test_source.pk
             }, data={'label': TEST_SOURCE_LABEL_EDITED}
         )
 
     def _request_test_source_edit_api_view_via_put(self):
         data = {
-            'backend_path': self.test_source.backend_path,
-            'enabled': self.test_source.enabled,
+            'backend_path': self._test_source.backend_path,
+            'enabled': self._test_source.enabled,
             'label': TEST_SOURCE_LABEL_EDITED
         }
 
         return self.put(
             viewname='rest_api:source-detail', kwargs={
-                'source_id': self.test_source.pk
+                'source_id': self._test_source.pk
             }, data=data
         )
 
@@ -162,12 +162,23 @@ class SourceTestMixin:
         total_test_sources = len(self._test_sources)
         label = '{}_{}'.format(TEST_SOURCE_LABEL, total_test_sources)
 
-        self.test_source = Source.objects.create(
+        self._test_source = Source.objects.create(
             backend_path=backend_path or TEST_SOURCE_BACKEND_PATH,
             backend_data=json.dumps(obj=backend_data or {}),
             label=label
         )
-        self._test_sources.append(self.test_source)
+        self._test_sources.append(self._test_source)
+
+
+class SourceDocumentUploadViewTestMixin:
+    def _request_source_document_upload_view_via_get(self):
+        return self.get(
+            viewname='sources:document_upload_interactive', kwargs={
+                'source_id': self._test_source.pk
+            }, data={
+                'document_type_id': self._test_document_type.pk,
+            }
+        )
 
 
 class PeriodicSourceBackendTestMixin(SourceTestMixin):
@@ -214,23 +225,23 @@ class SourceViewTestMixin:
         )
 
         try:
-            self.test_source = Source.objects.get(~Q(pk__in=pk_list))
+            self._test_source = Source.objects.get(~Q(pk__in=pk_list))
         except Source.DoesNotExist:
-            self.test_source = None
+            self._test_source = None
 
         return response
 
     def _request_test_source_delete_view(self):
         return self.post(
             viewname='sources:source_delete', kwargs={
-                'source_id': self.test_source.pk
+                'source_id': self._test_source.pk
             }
         )
 
     def _request_test_source_edit_view(self):
         return self.post(
             viewname='sources:source_edit', kwargs={
-                'source_id': self.test_source.pk
+                'source_id': self._test_source.pk
             }, data={
                 'label': TEST_SOURCE_LABEL_EDITED
             }
@@ -242,13 +253,13 @@ class SourceViewTestMixin:
     def _request_test_source_test_get_view(self):
         return self.get(
             viewname='sources:source_test', kwargs={
-                'source_id': self.test_source.pk
+                'source_id': self._test_source.pk
             }
         )
 
     def _request_test_source_test_post_view(self):
         return self.post(
             viewname='sources:source_test', kwargs={
-                'source_id': self.test_source.pk
+                'source_id': self._test_source.pk
             }
         )
