@@ -13,13 +13,13 @@ class PeriodicSourceBackendTestCase(
     def test_periodic_source_delete(self):
         periodic_task_count = PeriodicTask.objects.count()
 
-        self.test_source.delete()
+        self._test_source.delete()
 
         self.assertEqual(PeriodicTask.objects.count(), periodic_task_count - 1)
 
     def test_periodic_source_save(self):
         periodic_task_count = PeriodicTask.objects.count()
 
-        self.test_source.save()
+        self._test_source.save()
 
         self.assertEqual(PeriodicTask.objects.count(), periodic_task_count)
