@@ -36,7 +36,7 @@ class SANEScannerDocumentUploadWizardViewTestCase(
 
     def test_upload_interactive_view_with_document_type_access(self):
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -53,7 +53,7 @@ class SANEScannerDocumentUploadWizardViewTestCase(
 
     def test_upload_interactive_view_with_source_access(self):
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -70,10 +70,10 @@ class SANEScannerDocumentUploadWizardViewTestCase(
 
     def test_upload_interactive_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -82,7 +82,7 @@ class SANEScannerDocumentUploadWizardViewTestCase(
 
         response = self._request_upload_interactive_view()
         self.assertContains(
-            response=response, text=self.test_source.label, status_code=200
+            response=response, text=self._test_source.label, status_code=200
         )
 
         self.assertEqual(Document.objects.count(), test_document_count)
@@ -105,7 +105,7 @@ class SANEScannerDocumentUploadWizardViewTestCase(
 
     def test_upload_wizard_with_document_type_access(self):
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -122,7 +122,7 @@ class SANEScannerDocumentUploadWizardViewTestCase(
 
     def test_upload_wizard_with_source_access(self):
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -139,10 +139,10 @@ class SANEScannerDocumentUploadWizardViewTestCase(
 
     def test_upload_wizard_with_full_access(self):
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         test_document_count = Document.objects.count()
@@ -162,7 +162,7 @@ class SANEScannerDocumentUploadWizardViewTestCase(
         test_document_version = test_document.version_active
         test_document_version_page = test_document_version.pages.first()
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, test_document)
         self.assertEqual(events[0].verb, event_document_created.id)
@@ -195,7 +195,7 @@ class SANEScannerDocumentFileUploadViewTestCase(
     GenericDocumentViewTestCase
 ):
     def test_document_file_upload_view_no_permission(self):
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
@@ -203,63 +203,63 @@ class SANEScannerDocumentFileUploadViewTestCase(
 
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_view_with_source_access(self):
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_post_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.files.count(), file_count + 1
+            self._test_document.files.count(), file_count + 1
         )
 
         events = self._get_test_events()
@@ -294,92 +294,92 @@ class SANEScannerDocumentFileUploadViewTestCase(
 
     def test_trashed_document_file_upload_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_document_file_upload_post_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
+        self._test_document.refresh_from_db()
         self.assertEqual(
-            self.test_document.files.count(), file_count
+            self._test_document.files.count(), file_count
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_no_source_view_no_permission(self):
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_no_source_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_no_source_view_with_source_access(self):
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_file_upload_no_source_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count + 1)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count + 1)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 4)
@@ -413,22 +413,22 @@ class SANEScannerDocumentFileUploadViewTestCase(
 
     def test_trashed_document_file_upload_no_source_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_document_file_new
+            obj=self._test_document, permission=permission_document_file_new
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_file_new
+            obj=self._test_source, permission=permission_document_file_new
         )
-        file_count = self.test_document.files.count()
+        file_count = self._test_document.files.count()
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_document_file_upload_no_source_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_document.refresh_from_db()
-        self.assertEqual(self.test_document.files.count(), file_count)
+        self._test_document.refresh_from_db()
+        self.assertEqual(self._test_document.files.count(), file_count)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
