@@ -12,6 +12,7 @@ from mayan.apps.documents.permissions import permission_document_create
 from mayan.apps.views.mixins import ExternalObjectViewMixin
 
 from ..forms import NewDocumentForm
+from ..icons import icon_document_create_multiple
 from ..models import Source
 
 from .base import UploadBaseView
@@ -25,6 +26,7 @@ class DocumentUploadInteractiveView(ExternalObjectViewMixin, UploadBaseView):
     external_object_permission = permission_document_create
     document_form = NewDocumentForm
     object_permission = permission_document_create
+    view_icon = icon_document_create_multiple
 
     def forms_valid(self, forms):
         source_backend_instance = self.source.get_backend_instance()
