@@ -27,14 +27,14 @@ class DocumentTagAPIViewTestCase(
         response = self._request_test_document_tag_attach_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_tag not in self.test_document.tags.all())
+        self.assertTrue(self._test_tag not in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_attach_tag_api_view_with_document_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_attach
+            obj=self._test_document, permission=permission_tag_attach
         )
 
         self._clear_events()
@@ -42,14 +42,14 @@ class DocumentTagAPIViewTestCase(
         response = self._request_test_document_tag_attach_api_view()
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-        self.assertTrue(self.test_tag not in self.test_document.tags.all())
+        self.assertTrue(self._test_tag not in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_attach_tag_api_view_with_tag_access(self):
         self.grant_access(
-            obj=self.test_tag, permission=permission_tag_attach
+            obj=self._test_tag, permission=permission_tag_attach
         )
 
         self._clear_events()
@@ -57,17 +57,17 @@ class DocumentTagAPIViewTestCase(
         response = self._request_test_document_tag_attach_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_tag not in self.test_document.tags.all())
+        self.assertTrue(self._test_tag not in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_attach_tag_api_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_attach
+            obj=self._test_document, permission=permission_tag_attach
         )
         self.grant_access(
-            obj=self.test_tag, permission=permission_tag_attach
+            obj=self._test_tag, permission=permission_tag_attach
         )
 
         self._clear_events()
@@ -75,38 +75,38 @@ class DocumentTagAPIViewTestCase(
         response = self._request_test_document_tag_attach_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.assertTrue(self.test_tag in self.test_document.tags.all())
+        self.assertTrue(self._test_tag in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_tag)
+        self.assertEqual(events[0].action_object, self._test_tag)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_tag_attached.id)
 
     def test_trashed_document_attach_tag_api_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_attach
+            obj=self._test_document, permission=permission_tag_attach
         )
         self.grant_access(
-            obj=self.test_tag, permission=permission_tag_attach
+            obj=self._test_tag, permission=permission_tag_attach
         )
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_tag_attach_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_tag not in self.test_document.tags.all())
+        self.assertTrue(self._test_tag not in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_tag_list_api_view_no_permission(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
         self._clear_events()
 
@@ -117,10 +117,10 @@ class DocumentTagAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_tag_list_api_view_with_document_access(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_view
+            obj=self._test_document, permission=permission_tag_view
         )
 
         self._clear_events()
@@ -133,9 +133,9 @@ class DocumentTagAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_tag_list_api_view_with_tag_access(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
-        self.grant_access(obj=self.test_tag, permission=permission_tag_view)
+        self.grant_access(obj=self._test_tag, permission=permission_tag_view)
 
         self._clear_events()
 
@@ -146,31 +146,31 @@ class DocumentTagAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_tag_list_api_view_with_full_access(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_view
+            obj=self._test_document, permission=permission_tag_view
         )
-        self.grant_access(obj=self.test_tag, permission=permission_tag_view)
+        self.grant_access(obj=self._test_tag, permission=permission_tag_view)
 
         self._clear_events()
 
         response = self._request_test_document_tag_list_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
-        self.assertEqual(response.data['results'][0]['label'], self.test_tag.label)
+        self.assertEqual(response.data['results'][0]['label'], self._test_tag.label)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_trashed_document_tag_list_api_view_with_full_access(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_view
+            obj=self._test_document, permission=permission_tag_view
         )
-        self.grant_access(obj=self.test_tag, permission=permission_tag_view)
+        self.grant_access(obj=self._test_tag, permission=permission_tag_view)
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
@@ -181,23 +181,23 @@ class DocumentTagAPIViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_document_tag_remove_api_view_no_permission(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
         self._clear_events()
 
         response = self._request_test_document_tag_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_tag in self.test_document.tags.all())
+        self.assertTrue(self._test_tag in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_tag_remove_api_view_with_document_access(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_remove
+            obj=self._test_document, permission=permission_tag_remove
         )
 
         self._clear_events()
@@ -205,65 +205,65 @@ class DocumentTagAPIViewTestCase(
         response = self._request_test_document_tag_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
-        self.assertTrue(self.test_tag in self.test_document.tags.all())
+        self.assertTrue(self._test_tag in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_tag_remove_api_view_with_tag_access(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
-        self.grant_access(obj=self.test_tag, permission=permission_tag_remove)
+        self.grant_access(obj=self._test_tag, permission=permission_tag_remove)
 
         self._clear_events()
 
         response = self._request_test_document_tag_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_tag in self.test_document.tags.all())
+        self.assertTrue(self._test_tag in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_document_tag_remove_api_view_with_full_access(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_remove
+            obj=self._test_document, permission=permission_tag_remove
         )
-        self.grant_access(obj=self.test_tag, permission=permission_tag_remove)
+        self.grant_access(obj=self._test_tag, permission=permission_tag_remove)
 
         self._clear_events()
 
         response = self._request_test_document_tag_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-        self.assertFalse(self.test_tag in self.test_document.tags.all())
+        self.assertFalse(self._test_tag in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_tag)
+        self.assertEqual(events[0].action_object, self._test_tag)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_tag_removed.id)
 
     def test_trashed_document_tag_remove_api_view_with_full_access(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_remove
+            obj=self._test_document, permission=permission_tag_remove
         )
-        self.grant_access(obj=self.test_tag, permission=permission_tag_remove)
+        self.grant_access(obj=self._test_tag, permission=permission_tag_remove)
 
-        self.test_document.delete()
+        self._test_document.delete()
 
         self._clear_events()
 
         response = self._request_test_document_tag_remove_api_view()
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
-        self.assertTrue(self.test_tag in self.test_document.tags.all())
+        self.assertTrue(self._test_tag in self._test_document.tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
