@@ -1,12 +1,13 @@
 from django.utils.encoding import force_text
 
 from mayan.apps.documents.permissions import (
-    permission_document_file_view, permission_document_version_view,
-    permission_document_view
+    permission_document_view, permission_document_file_view,
+    permission_document_version_view
 )
 from mayan.apps.documents.search import (
-    document_file_page_search, document_file_search, document_search,
-    document_version_page_search, document_version_search
+    search_model_document, search_model_document_file,
+    search_model_document_file_page, search_model_document_version,
+    search_model_document_version_page
 )
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
 from mayan.apps.documents.tests.mixins.document_mixins import DocumentViewTestMixin
@@ -35,112 +36,112 @@ class DocumentTagHTMLWidgetTestCase(
 
         response = self._request_test_document_list_view()
         self.assertNotContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_tag.label, status_code=200
+            response=response, text=self._test_tag.label, status_code=200
         )
 
     def test_document_tags_widget_with_document_view_access(self):
         self._create_test_tag(add_test_document=True)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
 
         response = self._request_test_document_list_view()
         self.assertContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
         self.assertNotContains(
-            response=response, text=force_text(s=self.test_tag), status_code=200
+            response=response, text=force_text(s=self._test_tag), status_code=200
         )
 
     def test_document_tags_widget_with_document_tag_view_access(self):
         self._create_test_tag(add_test_document=True)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_view
+            obj=self._test_document, permission=permission_tag_view
         )
 
         response = self._request_test_document_list_view()
         self.assertNotContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
         self.assertNotContains(
-            response=response, text=force_text(s=self.test_tag), status_code=200
+            response=response, text=force_text(s=self._test_tag), status_code=200
         )
 
     def test_document_tags_widget_with_document_full_access(self):
         self._create_test_tag(add_test_document=True)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_view
+            obj=self._test_document, permission=permission_tag_view
         )
 
         response = self._request_test_document_list_view()
         self.assertContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
         self.assertNotContains(
-            response=response, text=force_text(s=self.test_tag), status_code=200
+            response=response, text=force_text(s=self._test_tag), status_code=200
         )
 
     def test_document_tags_widget_with_document_view_and_tag_view_access(self):
         self._create_test_tag(add_test_document=True)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
         self.grant_access(
-            obj=self.test_tag, permission=permission_tag_view
+            obj=self._test_tag, permission=permission_tag_view
         )
 
         response = self._request_test_document_list_view()
         self.assertContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
         self.assertNotContains(
-            response=response, text=force_text(s=self.test_tag), status_code=200
+            response=response, text=force_text(s=self._test_tag), status_code=200
         )
 
     def test_document_tags_widget_with_tag_access(self):
         self._create_test_tag(add_test_document=True)
 
         self.grant_access(
-            obj=self.test_tag, permission=permission_tag_view
+            obj=self._test_tag, permission=permission_tag_view
         )
 
         response = self._request_test_document_list_view()
         self.assertNotContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_tag.label, status_code=200
+            response=response, text=self._test_tag.label, status_code=200
         )
 
     def test_document_tags_widget_with_full_access(self):
         self._create_test_tag(add_test_document=True)
 
         self.grant_access(
-            obj=self.test_document, permission=permission_document_view
+            obj=self._test_document, permission=permission_document_view
         )
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_view
+            obj=self._test_document, permission=permission_tag_view
         )
         self.grant_access(
-            obj=self.test_tag, permission=permission_tag_view
+            obj=self._test_tag, permission=permission_tag_view
         )
 
         response = self._request_test_document_list_view()
         self.assertContains(
-            response=response, text=self.test_document.label, status_code=200
+            response=response, text=self._test_document.label, status_code=200
         )
         self.assertContains(
-            response=response, text=self.test_tag.label, status_code=200
+            response=response, text=self._test_tag.label, status_code=200
         )
 
 
@@ -155,9 +156,9 @@ class DocumentSearchResultWidgetViewTestCase(
         self._upload_test_document()
         self._create_test_tag(add_test_document=True)
         self._test_object_permission = permission_document_view
-        self._test_object_text = self.test_document.label
-        self._test_search_model = document_search
-        self._test_search_term_data = {'uuid': self.test_document.uuid}
+        self._test_object_text = self._test_document.label
+        self._test_search_model = search_model_document
+        self._test_search_term_data = {'uuid': self._test_document.uuid}
 
     def test_document_tag_widget_no_permission(self):
         response = self._request_search_results_view(
@@ -169,12 +170,12 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_tag.label, status_code=200
+            response=response, text=self._test_tag.label, status_code=200
         )
 
     def test_document_tag_widget_with_tag_type_access(self):
         self.grant_access(
-            obj=self.test_tag, permission=permission_tag_view
+            obj=self._test_tag, permission=permission_tag_view
         )
 
         response = self._request_search_results_view(
@@ -186,12 +187,12 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_tag.label, status_code=200
+            response=response, text=self._test_tag.label, status_code=200
         )
 
     def test_document_tag_widget_with_document_view_access(self):
         self.grant_access(
-            obj=self.test_document, permission=self._test_object_permission
+            obj=self._test_document, permission=self._test_object_permission
         )
 
         response = self._request_search_results_view(
@@ -203,12 +204,12 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_tag.label, status_code=200
+            response=response, text=self._test_tag.label, status_code=200
         )
 
     def test_document_tag_widget_with_document_tag_view_access(self):
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_view
+            obj=self._test_document, permission=permission_tag_view
         )
 
         response = self._request_search_results_view(
@@ -220,15 +221,15 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_tag.label, status_code=200
+            response=response, text=self._test_tag.label, status_code=200
         )
 
     def test_document_tag_widget_with_all_document_access(self):
         self.grant_access(
-            obj=self.test_document, permission=self._test_object_permission
+            obj=self._test_document, permission=self._test_object_permission
         )
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_view
+            obj=self._test_document, permission=permission_tag_view
         )
 
         response = self._request_search_results_view(
@@ -240,15 +241,15 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_tag.label, status_code=200
+            response=response, text=self._test_tag.label, status_code=200
         )
 
     def test_document_tag_widget_with_tag_view_and_document_view_access(self):
         self.grant_access(
-            obj=self.test_document, permission=self._test_object_permission
+            obj=self._test_document, permission=self._test_object_permission
         )
         self.grant_access(
-            obj=self.test_tag, permission=permission_tag_view
+            obj=self._test_tag, permission=permission_tag_view
         )
 
         response = self._request_search_results_view(
@@ -260,19 +261,19 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertNotContains(
-            response=response, text=self.test_tag.label,
+            response=response, text=self._test_tag.label,
             status_code=200
         )
 
     def test_document_tag_widget_with_full_access(self):
         self.grant_access(
-            obj=self.test_document, permission=self._test_object_permission
+            obj=self._test_document, permission=self._test_object_permission
         )
         self.grant_access(
-            obj=self.test_document, permission=permission_tag_view
+            obj=self._test_document, permission=permission_tag_view
         )
         self.grant_access(
-            obj=self.test_tag, permission=permission_tag_view
+            obj=self._test_tag, permission=permission_tag_view
         )
 
         response = self._request_search_results_view(
@@ -284,7 +285,7 @@ class DocumentSearchResultWidgetViewTestCase(
             response=response, text=self._test_object_text, status_code=200
         )
         self.assertContains(
-            response=response, text=self.test_tag.label, status_code=200
+            response=response, text=self._test_tag.label, status_code=200
         )
 
 
@@ -293,11 +294,11 @@ class DocumentFileSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = self.test_document_file.filename
+        self._test_object_text = self._test_document_file.filename
         self._test_object_permission = permission_document_file_view
-        self._test_search_model = document_file_search
+        self._test_search_model = search_model_document_file
         self._test_search_term_data = {
-            'document__uuid': self.test_document.uuid
+            'document__uuid': self._test_document.uuid
         }
 
 
@@ -306,11 +307,11 @@ class DocumentFilePageSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = force_text(s=self.test_document_file.pages.first())
+        self._test_object_text = force_text(s=self._test_document_file.pages.first())
         self._test_object_permission = permission_document_file_view
-        self._test_search_model = document_file_page_search
+        self._test_search_model = search_model_document_file_page
         self._test_search_term_data = {
-            'document_file__document__uuid': self.test_document.uuid
+            'document_file__document__uuid': self._test_document.uuid
         }
 
 
@@ -319,11 +320,11 @@ class DocumentVersionSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = force_text(s=self.test_document_version)
+        self._test_object_text = force_text(s=self._test_document_version)
         self._test_object_permission = permission_document_version_view
-        self._test_search_model = document_version_search
+        self._test_search_model = search_model_document_version
         self._test_search_term_data = {
-            'document__uuid': self.test_document.uuid
+            'document__uuid': self._test_document.uuid
         }
 
 
@@ -332,9 +333,9 @@ class DocumentVersionPageSearchResultWidgetViewTestCase(
 ):
     def setUp(self):
         super().setUp()
-        self._test_object_text = force_text(s=self.test_document_version.pages.first())
+        self._test_object_text = force_text(s=self._test_document_version.pages.first())
         self._test_object_permission = permission_document_version_view
-        self._test_search_model = document_version_page_search
+        self._test_search_model = search_model_document_version_page
         self._test_search_term_data = {
-            'document_version__document__uuid': self.test_document.uuid
+            'document_version__document__uuid': self._test_document.uuid
         }
