@@ -6,7 +6,7 @@ from mayan.apps.documents.events import (
 from mayan.apps.documents.models import Document
 from mayan.apps.documents.permissions import permission_document_create
 from mayan.apps.documents.tests.base import GenericDocumentViewTestCase
-from mayan.apps.sources.tests.mixins.web_form_source_mixins import WebFormSourceTestMixin
+from mayan.apps.sources.tests.mixins.web_form_source_mixins import WebFormSourceBackendTestMixin
 
 from ..events import event_tag_attached
 
@@ -15,7 +15,7 @@ from .mixins import TagTestMixin, TaggedDocumentUploadWizardStepViewTestMixin
 
 class TaggedDocumentUploadViewTestCase(
     TaggedDocumentUploadWizardStepViewTestMixin, TagTestMixin,
-    WebFormSourceTestMixin, GenericDocumentViewTestCase
+    WebFormSourceBackendTestMixin, GenericDocumentViewTestCase
 ):
     auto_upload_test_document = False
 
@@ -23,10 +23,10 @@ class TaggedDocumentUploadViewTestCase(
         self._create_test_tag()
 
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         self._clear_events()
@@ -34,7 +34,7 @@ class TaggedDocumentUploadViewTestCase(
         response = self._request_upload_interactive_document_create_view()
         self.assertEqual(response.status_code, 302)
 
-        self.assertTrue(self.test_tag in Document.objects.first().tags.all())
+        self.assertTrue(self._test_tag in Document.objects.first().tags.all())
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 6)
@@ -44,7 +44,7 @@ class TaggedDocumentUploadViewTestCase(
         test_document_version = test_document.version_active
         test_document_version_page = test_document_version.pages.first()
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, test_document)
         self.assertEqual(events[0].verb, event_document_created.id)
@@ -71,7 +71,7 @@ class TaggedDocumentUploadViewTestCase(
             events[4].verb, event_document_version_page_created.id
         )
 
-        self.assertEqual(events[5].action_object, self.test_tag)
+        self.assertEqual(events[5].action_object, self._test_tag)
         self.assertEqual(events[5].actor, test_document)
         self.assertEqual(events[5].target, test_document)
         self.assertEqual(events[5].verb, event_tag_attached.id)
@@ -81,10 +81,10 @@ class TaggedDocumentUploadViewTestCase(
         self._create_test_tag()
 
         self.grant_access(
-            obj=self.test_document_type, permission=permission_document_create
+            obj=self._test_document_type, permission=permission_document_create
         )
         self.grant_access(
-            obj=self.test_source, permission=permission_document_create
+            obj=self._test_source, permission=permission_document_create
         )
 
         self._clear_events()
@@ -93,10 +93,10 @@ class TaggedDocumentUploadViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_tags[0] in Document.objects.first().tags.all()
+            self._test_tags[0] in Document.objects.first().tags.all()
         )
         self.assertTrue(
-            self.test_tags[1] in Document.objects.first().tags.all()
+            self._test_tags[1] in Document.objects.first().tags.all()
         )
 
         events = self._get_test_events()
@@ -107,7 +107,7 @@ class TaggedDocumentUploadViewTestCase(
         test_document_version = test_document.version_active
         test_document_version_page = test_document_version.pages.first()
 
-        self.assertEqual(events[0].action_object, self.test_document_type)
+        self.assertEqual(events[0].action_object, self._test_document_type)
         self.assertEqual(events[0].actor, self._test_case_user)
         self.assertEqual(events[0].target, test_document)
         self.assertEqual(events[0].verb, event_document_created.id)
@@ -134,12 +134,12 @@ class TaggedDocumentUploadViewTestCase(
             events[4].verb, event_document_version_page_created.id
         )
 
-        self.assertEqual(events[5].action_object, self.test_tags[0])
+        self.assertEqual(events[5].action_object, self._test_tags[0])
         self.assertEqual(events[5].actor, test_document)
         self.assertEqual(events[5].target, test_document)
         self.assertEqual(events[5].verb, event_tag_attached.id)
 
-        self.assertEqual(events[6].action_object, self.test_tags[1])
+        self.assertEqual(events[6].action_object, self._test_tags[1])
         self.assertEqual(events[6].actor, test_document)
         self.assertEqual(events[6].target, test_document)
         self.assertEqual(events[6].verb, event_tag_attached.id)
