@@ -21,35 +21,37 @@ class TagWorkflowActionTestCase(TagTestMixin, ActionTestCase):
         self._clear_events()
 
         action = AttachTagAction(form_data={'tags': Tag.objects.all()})
-        action.execute(context={'document': self.test_document})
+        action.execute(context={'document': self._test_document})
 
-        self.assertEqual(self.test_tag.documents.count(), 1)
-        self.assertTrue(self.test_document in self.test_tag.documents.all())
+        self.assertEqual(self._test_tag.documents.count(), 1)
+        self.assertTrue(
+            self._test_document in self._test_tag.documents.all()
+        )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_tag)
-        self.assertEqual(events[0].actor, self.test_document)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_tag)
+        self.assertEqual(events[0].actor, self._test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_tag_attached.id)
 
     def test_tag_remove_action(self):
-        self.test_tag.attach_to(document=self.test_document)
+        self._test_tag.attach_to(document=self._test_document)
 
         self._clear_events()
 
         action = RemoveTagAction(form_data={'tags': Tag.objects.all()})
-        action.execute(context={'document': self.test_document})
+        action.execute(context={'document': self._test_document})
 
-        self.assertEqual(self.test_tag.documents.count(), 0)
+        self.assertEqual(self._test_tag.documents.count(), 0)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_tag)
-        self.assertEqual(events[0].actor, self.test_document)
-        self.assertEqual(events[0].target, self.test_document)
+        self.assertEqual(events[0].action_object, self._test_tag)
+        self.assertEqual(events[0].actor, self._test_document)
+        self.assertEqual(events[0].target, self._test_document)
         self.assertEqual(events[0].verb, event_tag_removed.id)
 
 
