@@ -96,6 +96,7 @@ class CeleryQueue(AppsModuleLoaderMixin):
         self.default_queue = default_queue
         self.transient = transient
         self.task_types = []
+        self.worker = worker
 
         if name in self.__class__._registry:
             raise NonUniqueError(
@@ -108,22 +109,6 @@ class CeleryQueue(AppsModuleLoaderMixin):
     def __str__(self):
         return force_text(s=self.label)
 
-    def _process_task_dictionary(self, task_dictionary):
-        result = []
-        for worker, tasks in task_dictionary.items():
-            for task in tasks:
-                if task['delivery_info']['routing_key'] == self.name:
-                    task_type = TaskType.get(name=task['name'])
-                    result.append(Task(task_type=task_type, kwargs=task))
-
-        return result
-
-    def add_task_type(self, *args, **kwargs):
-        task_type = TaskType(*args, **kwargs)
-        self.task_types.append(task_type)
-        self.__class__._registry_task_types[task_type.dotted_path] = self
-        return task_type
-
     def _update_celery(self):
         kwargs = {
             'name': self.name, 'exchange': Exchange(self.name),
@@ -133,7 +118,9 @@ class CeleryQueue(AppsModuleLoaderMixin):
         if self.transient:
             kwargs['delivery_mode'] = 1
 
-        celery_app.conf.task_queues.append(Queue(**kwargs))
+        queue_new = Queue(**kwargs)
+        if queue_new not in celery_app.conf.task_queues:
+            celery_app.conf.task_queues.append(queue_new)
 
         if self.default_queue:
             celery_app.conf.task_default_queue = self.name
@@ -143,7 +130,7 @@ class CeleryQueue(AppsModuleLoaderMixin):
                 {
                     task_type.dotted_path: {
                         'queue': self.name
-                    },
+                    }
                 }
             )
 
@@ -153,10 +140,44 @@ class CeleryQueue(AppsModuleLoaderMixin):
                         task_type.name: {
                             'task': task_type.dotted_path,
                             'schedule': task_type.schedule
-                        },
+                        }
                     }
                 )
 
+    def add_task_type(self, *args, **kwargs):
+        task_type = TaskType(*args, **kwargs)
+        self.task_types.append(task_type)
+        self.__class__._registry_task_types[task_type.dotted_path] = self
+        return task_type
+
+    def remove(self):
+        kwargs = {
+            'name': self.name, 'exchange': Exchange(self.name),
+            'routing_key': self.name
+        }
+
+        if self.transient:
+            kwargs['delivery_mode'] = 1
+
+        queue = Queue(**kwargs)
+        if queue in celery_app.conf.task_queues:
+            celery_app.conf.task_queues.remove(queue)
+
+        if self.default_queue:
+            celery_app.conf.task_default_queue = None
+
+        for task_type in self.task_types:
+            celery_app.conf.task_routes.pop(task_type.dotted_path)
+
+            if task_type.schedule:
+                celery_app.conf.beat_schedule.pop(task_type.name)
+
+        self.__class__._registry.pop(self.name, None)
+        if self.name in self.worker._queues:
+            self.worker._queues.remove(self.name)
+
+        del self
+
 
 class Worker:
     _registry = {}
