@@ -7,14 +7,14 @@ class DocumentTemplateSandboxViewTestMixin:
     def _request_document_template_sandbox_get_view(self):
         return self.get(
             viewname='templating:document_template_sandbox', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }
         )
 
     def _request_document_template_sandbox_post_view(self):
         return self.post(
             viewname='templating:document_template_sandbox', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }, data={'template_template': TEST_TEMPLATE}
         )
 
