@@ -3,8 +3,7 @@ from django.contrib.auth.models import Group
 from django.contrib.auth.password_validation import validate_password
 from django.utils.translation import ugettext_lazy as _
 
-from rest_framework import serializers
-
+from mayan.apps.rest_api import serializers
 from mayan.apps.rest_api.relations import FilteredPrimaryKeyRelatedField
 
 from .permissions import permission_user_edit
@@ -101,12 +100,12 @@ class UserSerializer(serializers.HyperlinkedModelSerializer):
 
     def update(self, instance, validated_data):
         if 'password' in validated_data:
-            instance.set_password(validated_data['password'])
+            instance.set_password(raw_password=validated_data['password'])
             validated_data.pop('password')
 
-        instance = super().update(instance, validated_data)
-
-        return instance
+        return super().update(
+            instance=instance, validated_data=validated_data
+        )
 
     def validate(self, data):
         if 'password' in data:
