@@ -16,7 +16,7 @@ from .mixins import (
 )
 
 
-class GroupViewsTestCase(
+class GroupViewTestCase(
     GroupTestMixin, GroupViewTestMixin, GenericViewTestCase
 ):
     def test_group_create_view_no_permission(self):
@@ -49,17 +49,17 @@ class GroupViewsTestCase(
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_group)
+        self.assertEqual(events[0].target, self._test_group)
         self.assertEqual(events[0].verb, event_group_created.id)
 
-    def test_group_delete_single_view_no_permission(self):
+    def test_group_single_delete_view_no_permission(self):
         self._create_test_group()
 
         group_count = Group.objects.count()
 
         self._clear_events()
 
-        response = self._request_test_group_delete_single_view()
+        response = self._request_test_group_single_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(Group.objects.count(), group_count)
@@ -67,17 +67,17 @@ class GroupViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_group_delete_single_view_with_access(self):
+    def test_group_single_delete_view_with_access(self):
         self._create_test_group()
         self.grant_access(
-            obj=self.test_group, permission=permission_group_delete
+            obj=self._test_group, permission=permission_group_delete
         )
 
         group_count = Group.objects.count()
 
         self._clear_events()
 
-        response = self._request_test_group_delete_single_view()
+        response = self._request_test_group_single_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(Group.objects.count(), group_count - 1)
@@ -85,14 +85,14 @@ class GroupViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_group_delete_multiple_view_no_permission(self):
+    def test_group_multiple_delete_view_no_permission(self):
         self._create_test_group()
 
         group_count = Group.objects.count()
 
         self._clear_events()
 
-        response = self._request_test_group_delete_multiple_view()
+        response = self._request_test_group_multiple_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(Group.objects.count(), group_count)
@@ -100,18 +100,18 @@ class GroupViewsTestCase(
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_group_delete_multiple_view_with_access(self):
+    def test_group_multiple_delete_view_with_access(self):
         self._create_test_group()
 
         group_count = Group.objects.count()
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_delete
+            obj=self._test_group, permission=permission_group_delete
         )
 
         self._clear_events()
 
-        response = self._request_test_group_delete_multiple_view()
+        response = self._request_test_group_multiple_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(Group.objects.count(), group_count - 1)
@@ -122,15 +122,15 @@ class GroupViewsTestCase(
     def test_group_edit_view_no_permission(self):
         self._create_test_group()
 
-        group_name = self.test_group.name
+        group_name = self._test_group.name
 
         self._clear_events()
 
         response = self._request_test_group_edit_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_group.refresh_from_db()
-        self.assertEqual(self.test_group.name, group_name)
+        self._test_group.refresh_from_db()
+        self.assertEqual(self._test_group.name, group_name)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -138,25 +138,25 @@ class GroupViewsTestCase(
     def test_group_edit_view_with_access(self):
         self._create_test_group()
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
-        group_name = self.test_group.name
+        group_name = self._test_group.name
 
         self._clear_events()
 
         response = self._request_test_group_edit_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_group.refresh_from_db()
-        self.assertNotEqual(self.test_group.name, group_name)
+        self._test_group.refresh_from_db()
+        self.assertNotEqual(self._test_group.name, group_name)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_group)
+        self.assertEqual(events[0].target, self._test_group)
         self.assertEqual(events[0].verb, event_group_edited.id)
 
     def test_group_list_view_no_permission(self):
@@ -166,7 +166,7 @@ class GroupViewsTestCase(
 
         response = self._request_test_group_list_view()
         self.assertNotContains(
-            response=response, text=self.test_group.name, status_code=200
+            response=response, text=self._test_group.name, status_code=200
         )
 
         events = self._get_test_events()
@@ -176,14 +176,14 @@ class GroupViewsTestCase(
         self._create_test_group()
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_view
+            obj=self._test_group, permission=permission_group_view
         )
 
         self._clear_events()
 
         response = self._request_test_group_list_view()
         self.assertContains(
-            response=response, text=self.test_group.name, status_code=200
+            response=response, text=self._test_group.name, status_code=200
         )
 
         events = self._get_test_events()
@@ -199,17 +199,17 @@ class GroupAddRemoveUserViewTestCase(
         self._create_test_user()
 
     def test_group_user_add_remove_get_view_no_permission(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self._clear_events()
 
         response = self._request_test_group_user_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
 
@@ -217,21 +217,21 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_user_add_remove_get_view_with_user_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
 
         response = self._request_test_group_user_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
 
@@ -239,21 +239,21 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_user_add_remove_get_view_with_group_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
 
         response = self._request_test_group_user_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=200
         )
         self.assertContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
 
@@ -261,24 +261,24 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_user_add_remove_get_view_with_full_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
 
         response = self._request_test_group_user_add_remove_get_view()
         self.assertContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=200
         )
         self.assertContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
 
@@ -292,7 +292,7 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_user not in self.test_group.user_set.all()
+            self._test_user not in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
@@ -300,7 +300,7 @@ class GroupAddRemoveUserViewTestCase(
 
     def test_group_user_add_view_with_user_access(self):
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -309,7 +309,7 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_user not in self.test_group.user_set.all()
+            self._test_user not in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
@@ -317,7 +317,7 @@ class GroupAddRemoveUserViewTestCase(
 
     def test_group_user_add_view_with_group_access(self):
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -326,7 +326,7 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_user not in self.test_group.user_set.all()
+            self._test_user not in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
@@ -334,10 +334,10 @@ class GroupAddRemoveUserViewTestCase(
 
     def test_group_user_add_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -346,19 +346,19 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_user in self.test_group.user_set.all()
+            self._test_user in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_user)
+        self.assertEqual(events[0].action_object, self._test_user)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_group)
+        self.assertEqual(events[0].target, self._test_group)
         self.assertEqual(events[0].verb, event_group_edited.id)
 
     def test_group_user_remove_view_no_permission(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self._clear_events()
 
@@ -366,17 +366,17 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_user in self.test_group.user_set.all()
+            self._test_user in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_view_with_user_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -385,17 +385,17 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_user in self.test_group.user_set.all()
+            self._test_user in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_view_with_group_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -404,20 +404,20 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_user in self.test_group.user_set.all()
+            self._test_user in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_view_with_full_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -426,15 +426,15 @@ class GroupAddRemoveUserViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_user not in self.test_group.user_set.all()
+            self._test_user not in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_user)
+        self.assertEqual(events[0].action_object, self._test_user)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_group)
+        self.assertEqual(events[0].target, self._test_group)
         self.assertEqual(events[0].verb, event_group_edited.id)
 
 
@@ -445,20 +445,20 @@ class SuperUserGroupAddRemoveViewTestCase(
         super().setUp()
         self._create_test_group()
         self._create_test_superuser()
-        self.test_user = self.test_superuser
+        self._test_user = self._test_superuser
 
     def test_group_user_add_remove_get_view_no_permission(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self._clear_events()
 
         response = self._request_test_group_user_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
 
@@ -466,21 +466,21 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_user_add_remove_get_view_with_user_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
 
         response = self._request_test_group_user_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
 
@@ -488,21 +488,21 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_user_add_remove_get_view_with_group_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
 
         response = self._request_test_group_user_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=200
         )
         self.assertContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
 
@@ -510,24 +510,24 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_group_user_add_remove_get_view_with_full_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
 
         response = self._request_test_group_user_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=200
         )
         self.assertContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
 
@@ -541,7 +541,7 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_user not in self.test_group.user_set.all()
+            self._test_user not in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
@@ -549,7 +549,7 @@ class SuperUserGroupAddRemoveViewTestCase(
 
     def test_group_user_add_view_with_user_access(self):
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -558,7 +558,7 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_user not in self.test_group.user_set.all()
+            self._test_user not in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
@@ -566,7 +566,7 @@ class SuperUserGroupAddRemoveViewTestCase(
 
     def test_group_user_add_view_with_group_access(self):
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -575,7 +575,7 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_user not in self.test_group.user_set.all()
+            self._test_user not in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
@@ -583,10 +583,10 @@ class SuperUserGroupAddRemoveViewTestCase(
 
     def test_group_user_add_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -595,14 +595,14 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_user not in self.test_group.user_set.all()
+            self._test_user not in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_view_no_permission(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self._clear_events()
 
@@ -610,17 +610,17 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_user in self.test_group.user_set.all()
+            self._test_user in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_view_with_user_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -629,17 +629,17 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_user in self.test_group.user_set.all()
+            self._test_user in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_view_with_group_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -648,20 +648,20 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_user in self.test_group.user_set.all()
+            self._test_user in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_group_user_remove_view_with_full_access(self):
-        self.test_user.groups.add(self.test_group)
+        self._test_user.groups.add(self._test_group)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -670,7 +670,7 @@ class SuperUserGroupAddRemoveViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_user in self.test_group.user_set.all()
+            self._test_user in self._test_group.user_set.all()
         )
 
         events = self._get_test_events()
@@ -683,22 +683,22 @@ class MetadataLookupIntegrationTestCase(
     def setUp(self):
         super().setUp()
         self._create_test_metadata_type()
-        self.test_document_type.metadata.create(
-            metadata_type=self.test_metadata_type
+        self._test_document_type.metadata.create(
+            metadata_type=self._test_metadata_type
         )
 
     def test_group_list_lookup_render(self):
-        self.test_metadata_type.lookup = '{{ groups }}'
-        self.test_metadata_type.save()
-        self.test_document.metadata.create(
-            metadata_type=self.test_metadata_type
+        self._test_metadata_type.lookup = '{{ groups }}'
+        self._test_metadata_type.save()
+        self._test_document.metadata.create(
+            metadata_type=self._test_metadata_type
         )
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
@@ -706,7 +706,7 @@ class MetadataLookupIntegrationTestCase(
 
         response = self.get(
             viewname='metadata:metadata_edit', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }
         )
 
