@@ -171,7 +171,7 @@ class SuperUserViewTestCase(
             is_superuser=True
         ).count()
         self.grant_access(
-            obj=self.test_superuser, permission=permission_user_delete
+            obj=self._test_superuser, permission=permission_user_delete
         )
 
         self._clear_events()
@@ -188,7 +188,7 @@ class SuperUserViewTestCase(
 
     def test_superuser_detail_view_with_access(self):
         self.grant_access(
-            obj=self.test_superuser, permission=permission_user_view
+            obj=self._test_superuser, permission=permission_user_view
         )
 
         self._clear_events()
@@ -201,10 +201,10 @@ class SuperUserViewTestCase(
 
     def test_superuser_normal_user_detail_view_with_access(self):
         self.grant_access(
-            obj=self.test_superuser, permission=permission_user_view
+            obj=self._test_superuser, permission=permission_user_view
         )
 
-        self.test_user = self.test_superuser
+        self._test_user = self._test_superuser
 
         self._clear_events()
 
@@ -246,7 +246,7 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_user)
+        self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_created.id)
 
     def test_user_delete_view_no_permission(self):
@@ -256,7 +256,7 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
 
         self._clear_events()
 
-        response = self._request_test_user_delete_single_view()
+        response = self._request_test_user_single_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(get_user_model().objects.count(), user_count)
@@ -270,12 +270,12 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
         user_count = get_user_model().objects.count()
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_delete
+            obj=self._test_user, permission=permission_user_delete
         )
 
         self._clear_events()
 
-        response = self._request_test_user_delete_single_view()
+        response = self._request_test_user_single_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(get_user_model().objects.count(), user_count - 1)
@@ -283,14 +283,14 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_user_delete_multiple_view_no_permission(self):
+    def test_user_multiple_delete_view_no_permission(self):
         self._create_test_user()
 
         user_count = get_user_model().objects.count()
 
         self._clear_events()
 
-        response = self._request_test_user_delete_multiple_view()
+        response = self._request_test_user_multiple_delete_view()
         self.assertEqual(response.status_code, 404)
 
         self.assertEqual(get_user_model().objects.count(), user_count)
@@ -298,18 +298,18 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
-    def test_user_delete_multiple_view_with_access(self):
+    def test_user_multiple_delete_view_with_access(self):
         self._create_test_user()
 
         user_count = get_user_model().objects.count()
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_delete
+            obj=self._test_user, permission=permission_user_delete
         )
 
         self._clear_events()
 
-        response = self._request_test_user_delete_multiple_view()
+        response = self._request_test_user_multiple_delete_view()
         self.assertEqual(response.status_code, 302)
 
         self.assertEqual(get_user_model().objects.count(), user_count - 1)
@@ -320,15 +320,15 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
     def test_user_edit_view_no_permission(self):
         self._create_test_user()
 
-        username = self.test_user.username
+        username = self._test_user.username
 
         self._clear_events()
 
         response = self._request_test_user_edit_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_user.refresh_from_db()
-        self.assertEqual(self.test_user.username, username)
+        self._test_user.refresh_from_db()
+        self.assertEqual(self._test_user.username, username)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -336,10 +336,10 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
     def test_user_edit_view_with_access(self):
         self._create_test_user()
 
-        username = self.test_user.username
+        username = self._test_user.username
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -347,15 +347,15 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
         response = self._request_test_user_edit_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_user.refresh_from_db()
-        self.assertNotEqual(self.test_user.username, username)
+        self._test_user.refresh_from_db()
+        self.assertNotEqual(self._test_user.username, username)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_user)
+        self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_edited.id)
 
     def test_user_list_view_no_permission(self):
@@ -365,7 +365,7 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
 
         response = self._request_test_user_list_view()
         self.assertNotContains(
-            response=response, text=self.test_user.username, status_code=200
+            response=response, text=self._test_user.username, status_code=200
         )
 
         events = self._get_test_events()
@@ -375,14 +375,14 @@ class UserViewTestCase(UserViewTestMixin, GenericViewTestCase):
         self._create_test_user()
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_view
+            obj=self._test_user, permission=permission_user_view
         )
 
         self._clear_events()
 
         response = self._request_test_user_list_view()
         self.assertContains(
-            response=response, text=self.test_user.username, status_code=200
+            response=response, text=self._test_user.username, status_code=200
         )
 
         events = self._get_test_events()
@@ -398,17 +398,17 @@ class UserGroupViewTestCase(
         self._create_test_user()
 
     def test_user_group_add_remove_get_view_no_permission(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self._clear_events()
 
         response = self._request_test_user_group_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=404
         )
 
@@ -416,21 +416,21 @@ class UserGroupViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_user_group_add_remove_get_view_with_group_access(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
 
         response = self._request_test_user_group_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=404
         )
         self.assertNotContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=404
         )
 
@@ -438,21 +438,21 @@ class UserGroupViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_user_group_add_remove_get_view_with_user_access(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
 
         response = self._request_test_user_group_add_remove_get_view()
         self.assertNotContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
         self.assertContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=200
         )
 
@@ -460,24 +460,24 @@ class UserGroupViewTestCase(
         self.assertEqual(events.count(), 0)
 
     def test_user_group_add_remove_get_view_with_full_access(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
 
         response = self._request_test_user_group_add_remove_get_view()
         self.assertContains(
-            response=response, text=str(self.test_group),
+            response=response, text=str(self._test_group),
             status_code=200
         )
         self.assertContains(
-            response=response, text=str(self.test_user),
+            response=response, text=str(self._test_user),
             status_code=200
         )
 
@@ -491,7 +491,7 @@ class UserGroupViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_group not in self.test_user.groups.all()
+            self._test_group not in self._test_user.groups.all()
         )
 
         events = self._get_test_events()
@@ -499,7 +499,7 @@ class UserGroupViewTestCase(
 
     def test_user_group_add_view_with_group_access(self):
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -508,7 +508,7 @@ class UserGroupViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_group not in self.test_user.groups.all()
+            self._test_group not in self._test_user.groups.all()
         )
 
         events = self._get_test_events()
@@ -516,7 +516,7 @@ class UserGroupViewTestCase(
 
     def test_user_group_add_view_with_user_access(self):
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -525,7 +525,7 @@ class UserGroupViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_group not in self.test_user.groups.all()
+            self._test_group not in self._test_user.groups.all()
         )
 
         events = self._get_test_events()
@@ -533,10 +533,10 @@ class UserGroupViewTestCase(
 
     def test_user_group_add_view_with_full_access(self):
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -545,19 +545,19 @@ class UserGroupViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_group in self.test_user.groups.all()
+            self._test_group in self._test_user.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_group)
+        self.assertEqual(events[0].action_object, self._test_group)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_user)
+        self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_edited.id)
 
     def test_user_group_remove_view_no_permission(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self._clear_events()
 
@@ -565,17 +565,17 @@ class UserGroupViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_group in self.test_user.groups.all()
+            self._test_group in self._test_user.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_user_group_remove_view_with_group_access(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
 
         self._clear_events()
@@ -584,17 +584,17 @@ class UserGroupViewTestCase(
         self.assertEqual(response.status_code, 404)
 
         self.assertTrue(
-            self.test_group in self.test_user.groups.all()
+            self._test_group in self._test_user.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_user_group_remove_view_with_user_access(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -603,20 +603,20 @@ class UserGroupViewTestCase(
         self.assertEqual(response.status_code, 200)
 
         self.assertTrue(
-            self.test_group in self.test_user.groups.all()
+            self._test_group in self._test_user.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
 
     def test_user_group_remove_view_with_full_access(self):
-        self.test_group.user_set.add(self.test_user)
+        self._test_group.user_set.add(self._test_user)
 
         self.grant_access(
-            obj=self.test_group, permission=permission_group_edit
+            obj=self._test_group, permission=permission_group_edit
         )
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -625,15 +625,15 @@ class UserGroupViewTestCase(
         self.assertEqual(response.status_code, 302)
 
         self.assertTrue(
-            self.test_group not in self.test_user.groups.all()
+            self._test_group not in self._test_user.groups.all()
         )
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
-        self.assertEqual(events[0].action_object, self.test_group)
+        self.assertEqual(events[0].action_object, self._test_group)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_user)
+        self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_edited.id)
 
 
@@ -648,8 +648,8 @@ class UserOptionsViewTestCase(
         response = self._request_test_user_options_view()
         self.assertEqual(response.status_code, 404)
 
-        self.test_user.user_options.refresh_from_db()
-        self.assertFalse(self.test_user.user_options.block_password_change)
+        self._test_user.user_options.refresh_from_db()
+        self.assertFalse(self._test_user.user_options.block_password_change)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 0)
@@ -658,7 +658,7 @@ class UserOptionsViewTestCase(
         self._create_test_user()
 
         self.grant_access(
-            obj=self.test_user, permission=permission_user_edit
+            obj=self._test_user, permission=permission_user_edit
         )
 
         self._clear_events()
@@ -666,41 +666,36 @@ class UserOptionsViewTestCase(
         response = self._request_test_user_options_view()
         self.assertEqual(response.status_code, 302)
 
-        self.test_user.user_options.refresh_from_db()
-        self.assertTrue(self.test_user.user_options.block_password_change)
+        self._test_user.user_options.refresh_from_db()
+        self.assertTrue(self._test_user.user_options.block_password_change)
 
         events = self._get_test_events()
         self.assertEqual(events.count(), 1)
 
         self.assertEqual(events[0].action_object, None)
         self.assertEqual(events[0].actor, self._test_case_user)
-        self.assertEqual(events[0].target, self.test_user)
+        self.assertEqual(events[0].target, self._test_user)
         self.assertEqual(events[0].verb, event_user_edited.id)
 
 
 class MetadataLookupIntegrationTestCase(
     MetadataTypeTestMixin, GenericDocumentViewTestCase
 ):
-    def setUp(self):
-        super().setUp()
-        self._create_test_metadata_type()
-        self.test_document_type.metadata.create(
-            metadata_type=self.test_metadata_type
-        )
+    auto_create_test_metadata_type = True
 
     def test_user_list_lookup_render(self):
-        self.test_metadata_type.lookup = '{{ users }}'
-        self.test_metadata_type.save()
-        self.test_document.metadata.create(
-            metadata_type=self.test_metadata_type
+        self._test_metadata_type.lookup = '{{ users }}'
+        self._test_metadata_type.save()
+        self._test_document.metadata.create(
+            metadata_type=self._test_metadata_type
         )
 
         self.grant_access(
-            obj=self.test_document,
+            obj=self._test_document,
             permission=permission_document_metadata_edit
         )
         self.grant_access(
-            obj=self.test_metadata_type,
+            obj=self._test_metadata_type,
             permission=permission_document_metadata_edit
         )
 
@@ -708,12 +703,13 @@ class MetadataLookupIntegrationTestCase(
 
         response = self.get(
             viewname='metadata:metadata_edit', kwargs={
-                'document_id': self.test_document.pk
+                'document_id': self._test_document.pk
             }
         )
         self.assertContains(
             response=response, text='<option value="{}">{}</option>'.format(
-                self._test_case_user.username, self._test_case_user.username
+                self._test_case_user.get_full_name(),
+                self._test_case_user.get_full_name()
             ), status_code=200
         )
 
