@@ -7,4 +7,4 @@ class WebLinkViewTestCase(WebLinkTestMixin, BaseTestCase):
     def test_method_get_absolute_url(self):
         self._create_test_web_link()
 
-        self.assertTrue(self.test_web_link.get_absolute_url())
+        self.assertTrue(self._test_web_link.get_absolute_url())
