@@ -56,13 +56,11 @@ INSTALLED_APPS = (
     'django.contrib.staticfiles',
     # 3rd party.
     'actstream',
-    'colorful',
     'corsheaders',
     'django_celery_beat',
     'formtools',
     'mathfilters',
     'mptt',
-    'pure_pagination',
     'rest_framework',
     'rest_framework.authtoken',
     'solo',
@@ -126,6 +124,7 @@ INSTALLED_APPS = (
     'mayan.apps.mirroring',
     'mayan.apps.ocr',
     'mayan.apps.redactions',
+    'mayan.apps.signature_captures',
     'mayan.apps.sources',
     'mayan.apps.tags',
     'mayan.apps.web_links',
